@@ -19,68 +19,80 @@
 #define TOTAL_PROGRESS 100
 #endif
 
-void Configurator::initMe(QApplication *pApp)
+void Configurator::initMe ( QApplication *pApp )
 {
-	int iRet = 0;
-	bool bState = false;
-	m_pNewProcess = NULL;
-	m_iCurrentStep = 0;
-	m_qtTime.start();
-	m_iTotalSteps = getCompileSteps();
+	int iRet        = 0;
+	bool bState     = false;
+	m_pNewProcess   = NULL;
+	m_iCurrentStep  = 0; // number of files to compile
+	m_iCompileStep  = 0; // which compile step qdvdauthor or plugins or qrender
+	m_qtTime.start ( );
+	m_iTotalSteps   = getCompileSteps ( );
 	progressBarCompile->setTotalSteps ( TOTAL_PROGRESS );
 
 	// For now we only have included propper support for xine-lib
-	QString qsLib("libxine.so");
-	if (!checkLibraryExists (qsLib))
-		checkVideoXine->setEnabled(false);
+	QString qsLib ( "libxine.so" );
+	if ( ! checkLibraryExists ( qsLib ) )
+		checkVideoXine->setEnabled ( false );
 	// disable VLC support for now.
 //	qsLib = QString ("libvlc.so");
 //	qsLib = QString ("libvlc.a");
-	qsLib = QString ("NoNoNoVLCForBeta1");
-	if (!checkLibraryExists (qsLib))
-		checkVideoVLC->setEnabled(false);
-	qsLib = QString ("mplayer");
+	qsLib = QString ( "NoNoNoVLCForBeta1" );
+	if ( ! checkLibraryExists ( qsLib ) )
+		checkVideoVLC->setEnabled ( false );
+	qsLib = QString ( "mplayer" );
 	QString qsTempFile;
 	qsTempFile = QString ( "/tmp/%1_out.txt" ).arg ( getlogin ( ) );
-	iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg(qsLib).arg ( qsTempFile ) );
-	QFileInfo fileInfo( qsTempFile );
+	iRet = system ( (const char *)QString ( "which %1 > %2 2>/dev/null").arg(qsLib).arg ( qsTempFile ) );
+	QFileInfo fileInfo ( qsTempFile );
 	// Okay we can not find it, so we wont bother asking the user ...
-	if (fileInfo.size() < 5)
-		checkVideoMPlayer->setEnabled(false);
+	if ( fileInfo.size ( ) < 5 )
+		checkVideoMPlayer->setEnabled ( false );
 
-	if (!(checkVideoXine->isEnabled() || checkVideoMPlayer->isEnabled() || checkVideoVLC->isEnabled() ))	{
+	if ( ! ( checkVideoXine->isEnabled    ( ) ||
+	         checkVideoMPlayer->isEnabled ( ) ||
+	         checkVideoVLC->isEnabled     ( ) ) )  {
 		// Okay did not find any media player installed so we choose MPlayer per default.
-		checkVideoMPlayer->setEnabled(true);
-		checkVideoMPlayer->setChecked(true);
+		checkVideoMPlayer->setEnabled ( true );
+		checkVideoMPlayer->setChecked ( true );
 	}
-	if (checkVideoXine->isEnabled())
-		checkVideoXine->setChecked(true);
-	if (checkVideoMPlayer->isEnabled())
-		checkVideoMPlayer->setChecked(true);
-	if (checkVideoVLC->isEnabled())
-		checkVideoVLC->setChecked(true);
+	if ( checkVideoXine->isEnabled    ( ) )
+		checkVideoXine->setChecked    ( true );
+	if ( checkVideoMPlayer->isEnabled ( ) )
+		checkVideoMPlayer->setChecked ( true );
+	if ( checkVideoVLC->isEnabled     ( ) )
+		checkVideoVLC->setChecked     ( true );
 
 	// Last we set the lineEdits to reflect the current environment variables.
-	QString qsInstallDir  ( getenv ( "PREFIX"      ) );
+	QString qsInstallDir  ( getenv  (      "PREFIX" ) );
+	QString qsSystemPath  ( getenv  ( "SYSTEM_PATH" ) );
 	QString qsIncludePath = QString ( QString ( getenv ( "INCLUDEPATH" ) ) + " " + QString ( getenv ( "ADD_INCLUDEDIR" ) ) );
 	if  ( ! qsInstallDir.isEmpty ( ) )
 		editInstallDir->setText ( qsInstallDir );
-	editQtDir->setText(QString ( getenv  ( "QTDIR" ) ) );
-	editLDLibraryPath->setText ( QString ( getenv ( "LD_LIBRARY_PATH" ) ) );
-	editIncludePath->setText   ( QString ( qsIncludePath ) );
+	if  ( ! qsSystemPath.isEmpty ( ) )
+		editSystemPath->setText ( qsSystemPath );
+	else
+		editSystemPath->setText ( editInstallDir->text ( ) );
+
+	editQtDir3->setText ( QString( getenv  ( "QTDIR" ) ) );
+	if ( getenv ( "QTDIR3" ) )
+		editQtDir3->setText ( QString ( getenv ( "QTDIR3" ) ) );
+	editQtDir4->setText         ( QString ( getenv ( "QTDIR4" ) ) );
+	editLDLibraryPath->setText  ( QString ( getenv ( "LD_LIBRARY_PATH" ) ) );
+	editIncludePath->setText    ( QString ( qsIncludePath ) );
 	// Here we check if an executable exists already ...
-	QFileInfo theFile ("../bin/qdvdauthor");
-	if ( (theFile.exists()) && (theFile.size() > 1) ) 
+	QFileInfo theFile ( "../bin/qdvdauthor" );
+	if ( ( theFile.exists ( ) ) && ( theFile.size ( ) > 1 ) )
 		bState = true;
-	buttonExecute->setEnabled( bState );
-	if (bState)	{
+	buttonExecute->setEnabled ( bState );
+	if ( bState )  {
 		// the next check is to see if we can find kdesu
-		if (findGuiSU().isEmpty())
+		if ( findGuiSU ( ).isEmpty ( ) )
 			bState = false;
 	}
-	buttonInstall->setEnabled( bState );
+	buttonInstall->setEnabled ( bState );
 
-	connect( pApp, SIGNAL( aboutToQuit() ), this, SLOT( slotAboutToQuit() ) );
+	connect( pApp, SIGNAL ( aboutToQuit ( ) ), this, SLOT ( slotAboutToQuit ( ) ) );
 }
 
 QString Configurator::findGuiSU()
@@ -105,7 +117,7 @@ QString Configurator::findGuiSU()
 	return qsReturn;
 }
 
-bool Configurator::checkLibraryExists(QString &libName)
+bool Configurator::checkLibraryExists ( QString &libName )
 {
 	// in a shell script it would look like this :
 	// cat /etc/ld.so.conf | while read lib_path
@@ -116,129 +128,154 @@ bool Configurator::checkLibraryExists(QString &libName)
 	// done; 
 	QFileInfo fileInfo;
 	// The standard libraries are not in the ld.so.conf file ?!?!!?
-	fileInfo = QFileInfo (QString ("/lib/") + libName);
-	if (fileInfo.exists())
+	fileInfo = QFileInfo ( QString ( "/lib/" ) + libName );
+	if ( fileInfo.exists ( ) )
 		return true;
-	fileInfo = QFileInfo (editQtDir->text() + QString ("/lib/") + libName);
-	if (fileInfo.exists())
+	fileInfo = QFileInfo ( editQtDir3->text ( ) + QString ( "/lib/" ) + libName );
+	if ( fileInfo.exists ( ) )
 		return true;
-	fileInfo = QFileInfo (QString ("/usr/lib/") + libName);
-	if (fileInfo.exists())
+	fileInfo = QFileInfo ( QString ( "/usr/lib/" ) + libName );
+	if ( fileInfo.exists ( ) )
 		return true;
-	fileInfo  = QFileInfo ("/etc/ld.so.conf");
-	if (fileInfo.exists ())	{
+	fileInfo  = QFileInfo( "/etc/ld.so.conf" );
+	if ( fileInfo.exists ( ) )  {
 		QFile file( "/etc/ld.so.conf" );
 		if ( file.open( IO_ReadOnly ) ) {
 			QTextStream stream( &file );
 			QString libPath;
-			while ( !stream.atEnd() ) {
+			while ( !stream.atEnd ( ) ) {
 //printf ("Seraching for <%s> under <%s> total <%s>\n", (const char *)libName, (const char *)libPath, (const char *)QString (libPath + QString("/") + libName));
-				libPath = stream.readLine();
-				fileInfo = QFileInfo(libPath + QString("/") + libName);
-				if (fileInfo.exists())	{
-					file.close();
+				libPath = stream.readLine ( );
+				fileInfo = QFileInfo ( libPath + QString ( "/" ) + libName );
+				if ( fileInfo.exists ( ) )  {
+					file.close   ( );
 					return true;
 				}
 			}
 		}
-		file.close();
+		file.close ( );
 	}
 
 	return false;
 }
 
-void Configurator::slotCompile()
+void Configurator::slotCompile ( )
 {
-	QCursor myCursor (QCursor::WaitCursor);
+	QCursor myCursor ( QCursor::WaitCursor );
 	int iRet = 0;
 	uint t;
-	m_iTotalSteps = getCompileSteps();
-	tabWidget2->setCurrentPage(2);
-	progressBarCompile->setProgress (0);
-	buttonExecute->setEnabled( false );
-	if (m_pNewProcess)	{
+	m_iTotalSteps = getCompileSteps  ( );
+	tabWidget2->setCurrentPage      ( 2 );
+	progressBarCompile->setProgress ( 0 );
+	buttonExecute->setEnabled ( false );
+	if ( m_pNewProcess )	{
 		if (m_pNewProcess->isRunning())
 			return;
 		else
 			delete m_pNewProcess;
 	}
 
-	m_pNewProcess  = new QProcess ( this );
-	connect( m_pNewProcess, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( m_pNewProcess, SIGNAL(readyReadStderr()), this, SLOT(slotReadFromStderr()) );
-	connect( m_pNewProcess, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
+	m_pNewProcess   =  new QProcess ( this );
+	connect ( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromStdout ( ) ) );
+	connect ( m_pNewProcess, SIGNAL ( readyReadStderr ( ) ), this, SLOT ( slotReadFromStderr ( ) ) );
+	connect ( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited  ( ) ) );
+	m_iCompileStep = 0; // once we get into slotProcessExited we have to decide what to do next.
+	// I.e. 1 == compile qplayer/qslideshow/qdvdauthor
+	//      2 == compile plugins/libjhead
+	//      3 == compile ffmpeg/qrender ( Qt4 )
 	QStringList listEnv;
-	listEnv.append ( QString("QTDIR=%1").arg ( editQtDir->text ( ) ) );
+	QString qsQtDir = editQtDir3->text ( );
+	if ( qsQtDir.isEmpty ( ) )
+		qsQtDir = getenv ( "QTDIR3" );
+	if ( qsQtDir.isEmpty ( ) )
+		qsQtDir = getenv ( "QTDIR"  );
+	listEnv.append ( QString ( "QTDIR=%1" ).arg ( qsQtDir ) );
 	//listEnv.append ( QString ( "PATH=%1/bin" ).arg ( editQtDir->text ( ) ) );
-	if (editInstallDir->text().isEmpty())
-		listEnv.append (QString("PREFIX=/usr"));
+	QString qsPrefix;
+	if ( editInstallDir->text  ( ).isEmpty ( ) )
+		qsPrefix = QString ( "PREFIX=/usr" );
 	else
-		listEnv.append (QString("PREFIX=%1").arg(editInstallDir->text()));
+		qsPrefix = QString ( "PREFIX=%1" ).arg ( editInstallDir->text ( ) );
+	listEnv.append ( qsPrefix );
 
-	if (checkDebug->isOn())
-		listEnv.append (QString("DEBUG_QDVDAUTHOR=debug"));
+	if ( editSystemPath->text ( ).isEmpty ( ) )  {
+		qsPrefix.replace  ( "PREFIX", "SYSTEM_PATH" );
+		listEnv.append    ( qsPrefix );
+	}
+	else
+		listEnv.append ( QString ( "SYSTEM_PATH=%1" ).arg ( editSystemPath->text ( ) ) );
 
-	if (!editLDLibraryPath->text ( ).isEmpty ( ) )
+	if ( checkDebug->isOn  ( ) )
+		listEnv.append ( QString ( "DEBUG_QDVDAUTHOR=debug" ) );
+
+	if ( ! editLDLibraryPath->text ( ).isEmpty ( ) )
 		listEnv.append ( QString("LD_LIBRARY_PATH=%1").arg ( editLDLibraryPath->text ( ) ) );
-	if (!editIncludePath->text ( ).isEmpty ( ) )
+	if ( ! editIncludePath->text ( ).isEmpty ( ) )
 		listEnv.append ( QString("ADD_INCLUDEDIR=%1").arg  ( editIncludePath->text   ( ) ) );
-	if (checkVideoXine->isOn ( ) )
-		 listEnv.append ( "WITH_XINE_SUPPORT=1" );
-	if (checkVideoMPlayer->isOn())
+	if ( checkVideoXine->isOn    ( ) )
+		listEnv.append   ( "WITH_XINE_SUPPORT=1" );
+	if ( checkVideoMPlayer->isOn ( ) )
+		listEnv.append   ( "WITH_MPLAYER_SUPPORT=1" );
+	if ( checkVideoVLC->isOn     ( ) )
+		listEnv.append   ( "WITH_VLC_SUPPORT=1" );
+
+	if ( ! checkVideoXine->isOn ( ) && ! checkVideoMPlayer->isOn ( ) && ! checkVideoVLC->isOn ( ) )
 		 listEnv.append ( "WITH_MPLAYER_SUPPORT=1" );
-	if (checkVideoVLC->isOn())
-		 listEnv.append ( "WITH_VLC_SUPPORT=1" );
 
-	if ( !checkVideoXine->isOn() && !checkVideoMPlayer->isOn() && !checkVideoVLC->isOn() )
-		 listEnv.append ("WITH_MPLAYER_SUPPORT=1");
+	QString qtLib1    ( "libqt-mt.so"  );
+	QString qtLib2    ( "libqt.so"     );
+	if ( checkLibraryExists ( qtLib1 ) )
+		listEnv.append  ( "QT_LIB=qt-mt");
+	else if ( checkLibraryExists ( qtLib2 ) )
+		listEnv.append  ( "QT_LIB=qt" );
 
-	QString qtLib1 ("libqt-mt.so");
-	QString qtLib2 ("libqt.so");
-	if (checkLibraryExists (qtLib1))
-		listEnv.append ("QT_LIB=qt-mt");
-	else if (checkLibraryExists (qtLib2))
-		listEnv.append ("QT_LIB=qt");
+	QString qsPath = getenv ( "PATH" );
+	qsPath = "PATH=" + qsQtDir + "/bin/:" + qsPath;
+	m_qsUsersPath = qsPath;
+	listEnv.append ( qsPath );
 	// This var will tell the qplayer.pro file to not to create qmake_image_collection ...
-	listEnv.append ("QMAKE_IMAGES=yes");
+	listEnv.append ( "QMAKE_IMAGES=yes" );
 
 	// Here we print the newly added environment variables.
-	textOutput->clear();
-	for ( QStringList::Iterator it = listEnv.begin(); it != listEnv.end(); ++it ) {
-		textOutput->append(*it + QString ("\n"));
+	textOutput->clear ( );
+	for ( QStringList::Iterator it = listEnv.begin ( ); it != listEnv.end ( ); ++it )  {
+		textOutput->append ( *it + QString ( "\n" ) );
 	}
 
 	// let us set the env of the calling process rather then just
 	// create our own environment with only the environment we set.
-	for (uint t=0;t<listEnv.count();t++)
-		putenv ((char *)((const char *)listEnv [t]));
+	for ( uint t=0; t<listEnv.count ( ); t++ )
+		putenv ( (char *)( (const char *)listEnv [t] ) );
 
 	// qdvdauthor.pro needs those files to physically be there ... Go figure !
-	iRet = system ("touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer");
+	iRet = system ( "touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer ../bin/qrender" );
 	// Next we should remove the Makefile's so we build with new media engine - support.
-	if (hasMediaEngineSelectionChanged())
-		iRet = system ("rm Makefile ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile");
+	if ( hasMediaEngineSelectionChanged ( ) )
+		iRet = system ( "rm Makefile ../qrender/Makefile ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile" );
 	m_pNewProcess->setWorkingDirectory (QDir ("../"));
 	// And here we generate the make file and compile the application.
-	m_pNewProcess->addArgument (  "qmake" );
-	m_pNewProcess->addArgument ( "all.pro");
+	m_pNewProcess->addArgument ( QString ( "%1/bin/qmake" ).arg ( qsQtDir ) );
+	m_pNewProcess->addArgument ( "all.pro" );
+
 	m_pNewProcess->start ( );
 	// wait for a second until qmake is done ..
 	while ( m_pNewProcess->isRunning ( ) )
 		sleep ( 1 );
 
-	m_pNewProcess->clearArguments();
-	QApplication::setOverrideCursor (myCursor);
+	m_iCompileStep = 1;
+	m_pNewProcess->clearArguments   ( );
+	QApplication::setOverrideCursor ( myCursor );
 
-	m_pNewProcess->addArgument (QString("make"));
-	if (!editMakeOptions->text().isEmpty())	{
+	m_pNewProcess->addArgument   ( QString ( "make" ) );
+	if ( ! editMakeOptions->text ( ).isEmpty ( ) )  {
 		// Here we need to split the line ...
-		QStringList listArgs = QStringList::split(" ", editMakeOptions->text());
-		for (t=0;t<listArgs.count();t++)
-			m_pNewProcess->addArgument (listArgs[t]);
+		QStringList listArgs = QStringList::split ( " ", editMakeOptions->text ( ) );
+		for ( t=0; t<listArgs.count ( ); t++ )
+			m_pNewProcess->addArgument ( listArgs[t] );
 	}
 
-	m_pNewProcess->start ();
-	m_qtTime.restart();
+	m_pNewProcess->start ( &listEnv );
+	m_qtTime.restart     ( );
 }
 
 bool Configurator::hasMediaEngineSelectionChanged()
@@ -318,9 +355,9 @@ void Configurator::slotReadFromStdout()
 
 void Configurator::slotReadFromStderr()
 {
-	static QColor errorColor = QColor (255, 0, 0);
-	QString strError = m_pNewProcess->readStderr ();
-	if (strError.length() < 2)
+	static QColor errorColor = QColor ( 255, 0, 0 );
+	QString strError = m_pNewProcess->readStderr ( );
+	if ( strError.length ( ) < 2 )
 		return;
 	// Okay, I don't know why I get all these QSettings errors. Must be in configurator ...
 	if (strError.find ("QSettings:") > -1)
@@ -328,41 +365,132 @@ void Configurator::slotReadFromStderr()
 
 	QColor stdColor = textOutput->color();
 	if (strError.lower().find ("error") > -1)
-		errorColor = QColor(255, 0, 0);
+		errorColor = QColor ( 255,   0, 0 );
 	else 
-		errorColor = QColor (220,220,0); 
-	textOutput->setColor (errorColor);
-	textOutput->append (strError);
-	textOutput->setColor (stdColor);
+		errorColor = QColor ( 220, 220, 0 );
+	textOutput->setColor ( errorColor );
+	textOutput->append   (   strError );
+	textOutput->setColor (   stdColor );
 }
 
-void Configurator::slotProcessExited()
+void Configurator::slotProcessExited ( )
 {
+	// At this point we have qdvdauthor / qslideshow / qplayer
+	// next are the plugins, libjhead, qrender, and local-ffmpeg
 	bool bState = false;
-	slotReadFromStdout ();
-	slotReadFromStderr ();
+	slotReadFromStdout ( );
+	slotReadFromStderr ( );
+
+	QString qsQtDir = getenv ( "QTDIR" );
+	if ( getenv ( "QTDIR3" ) )
+		qsQtDir = getenv ( "QTDIR3" );
+	if ( ! editQtDir3->text ( ).isEmpty ( ) )
+		qsQtDir = editQtDir3->text  ( );
+
+	QStringList listEnv;
+	QString qsPath = getenv ( "PATH" );
+	qsPath = "PATH=" + qsQtDir + "/bin/:.:" + qsPath;
+	qsPath = m_qsUsersPath;
+	listEnv.append ( qsPath );
+
+	listEnv.append ( QString ( "QTDIR=%1" ).arg ( qsQtDir ) );
+	m_pNewProcess->clearArguments ( );
+	if ( m_iCompileStep == 1 )  {
+		m_iCompileStep = 2;
+		if ( m_pCheckLibJHead->isChecked ( ) )  {
+			m_pNewProcess->setWorkingDirectory ( QDir ( "../addons" ) );
+			m_pNewProcess->addArgument  (    "bash" );
+			//m_pNewProcess->addArgument  (      "-c" ); // SuSe32 does not work
+			m_pNewProcess->addArgument  ( "make.sh" );
+			textOutput->append   ( "Build addons\n" );
+			m_pNewProcess->start ( &listEnv );
+			return;
+		}
+	}
+	if ( m_iCompileStep == 2 )  {
+		m_iCompileStep = 3;
+		if ( m_pCheckPlugins->isChecked ( ) )  {
+			m_pNewProcess->setWorkingDirectory ( QDir ( "../qdvdauthor/plugins" ) );
+			m_pNewProcess->addArgument (    "bash" );
+			//m_pNewProcess->addArgument (      "-c" );
+			m_pNewProcess->addArgument ( "make.sh" );
+			textOutput->append  ( "Build qdvdauthor/plugins\n" );
+			m_pNewProcess->start( &listEnv );
+			return;
+		}
+	}
+
+	if ( m_iCompileStep >= 3 )  {
+		// Adjust environment to Qt 4.x.
+		if ( getenv ( "QTDIR4" ) )
+			qsQtDir = getenv ( "QTDIR4" );
+		if ( ! editQtDir4->text ( ).isEmpty ( ) )
+			qsQtDir = editQtDir4->text  ( );
+		listEnv.clear  ( );
+		qsPath = m_qsUsersPath;
+		qsPath = "PATH=" + qsQtDir + "/bin:" + qsPath.right ( qsPath.length ( ) - 5 );
+
+		listEnv.append ( qsPath );
+ 		listEnv.append ( QString ( "QTDIR=%1" ).arg ( qsQtDir ) );
+		listEnv.append ( "STATIC_FFMPEG=1" );
+	}
+	if ( m_iCompileStep == 3 )  {
+		// qrender will be built as part of the local_=ffmpeg.sh - script.
+		m_iCompileStep  = 0;
+		m_pNewProcess->setWorkingDirectory ( QDir ( "../qrender" ) );
+		if ( m_pCheckQRender->isChecked ( ) && m_pCheckLocalFFMpeg->isChecked ( ) )  {
+			m_pNewProcess->addArgument (            "bash" );
+			//m_pNewProcess->addArgument (              "-c" );// does not work on SoSE 11.0
+			m_pNewProcess->addArgument ( "local_ffmpeg.sh" );
+			textOutput->append   ( "Build static ffmpeg\n" );
+			m_pNewProcess->start ( &listEnv );
+			return;
+		}
+	}
+	if ( m_iCompileStep == 4 )  {
+		m_iCompileStep = 5;
+		m_pNewProcess->clearArguments   ( );
+		m_pNewProcess->setWorkingDirectory ( QDir ( "../qrender" ) );
+		if ( m_pCheckQRender->isChecked ( ) )  {
+			textOutput->append   ( "Build qrender\n" );
+			m_pNewProcess->addArgument ( QString ( "%1/bin/qmake" ).arg ( qsQtDir ) );
+			m_pNewProcess->start ( &listEnv );
+			return;
+		}
+	}
+	if ( m_iCompileStep == 5 )  {
+		m_iCompileStep = 0;
+		m_pNewProcess->clearArguments ( );
+		m_pNewProcess->setWorkingDirectory ( QDir ( "../qrender" ) );
+		if ( m_pCheckQRender->isChecked ( ) )  {
+			m_pNewProcess->addArgument ( "make" );
+			m_pNewProcess->start ( &listEnv );
+			return;
+		}
+	}
+
 	progressBarCompile->setProgress ( TOTAL_PROGRESS );
 	m_iCurrentStep = 0;
 	// And here we check if the executable exists ...
-	QFileInfo theFile ("../bin/qdvdauthor");
-	if ( (theFile.exists()) && (theFile.size() > 1) )
+	QFileInfo theFile ( "../bin/qdvdauthor" );
+	if ( ( theFile.exists ( ) ) && ( theFile.size ( ) > 1 ) )
 		bState = true;
 		
-	buttonExecute->setEnabled( bState );
-	if (bState)	{
-		QApplication::restoreOverrideCursor ();
+	buttonExecute->setEnabled ( bState );
+	if ( bState )  {
+		QApplication::restoreOverrideCursor ( );
 
 		// the next check is to see if we can find kdesu
-		if (findGuiSU().isEmpty())
+		if (findGuiSU ( ).isEmpty ( ) )
 			bState = false;
 	}
-	buttonInstall->setEnabled( bState );
+	buttonInstall->setEnabled ( bState );
 
 	// Exactly the same handling of the title as under slotReadFromStdout
 	uint iElapsedSeconds = (int) ((float)m_qtTime.elapsed()/1000.0);
 	QString qsTimeString ("0 sec");
-	if (iElapsedSeconds < 60 )
-		qsTimeString = QString ("%1 sec").arg(iElapsedSeconds);
+	if ( iElapsedSeconds < 60 )
+		qsTimeString = QString ( "%1 sec" ).arg ( iElapsedSeconds );
 	else	{
 		uint iMinutes, iSeconds;
 		iMinutes = (uint)(iElapsedSeconds / 60.0);
@@ -392,6 +520,14 @@ int Configurator::getCompileSteps ()
 	listGenerated.append ( "../qdvdauthor/.moc"            );
 	listGenerated.append ( "../qdvdauthor/.obj"            );
 
+	if ( m_pCheckQRender->isChecked ( ) )  {
+		listSource.append    ( "../qrender/"     );
+        	listGenerated.append ( "../qrender/.ui"  );
+		listGenerated.append ( "../qrender/.moc" );
+		listGenerated.append ( "../qredner/.obj" );
+		// Note: If we compile ffmpeg, we'll be off by a heck-uf-a-lot
+	}
+
 	// Add the libjhead dependand stuff
 	listSource.append    ( "../addons/jhead/libjhead"      );
         listGenerated.append ( "../addons/jhead/libjhead/.ui"  );
@@ -487,27 +623,29 @@ void Configurator::slotMakeClean()
 		delete m_pNewProcess;
 
 	m_pNewProcess  = new QProcess ( this );
-	connect( m_pNewProcess, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( m_pNewProcess, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
+	connect ( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromStdout ( ) ) );
+	connect ( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited  ( ) ) );
 
-	m_pNewProcess->setWorkingDirectory (QDir (".."));
+	m_pNewProcess->setWorkingDirectory ( QDir ( ".." ) );
 	// And here we generate the make file and compile the application.
-	m_pNewProcess->addArgument (QString("make"));
-	m_pNewProcess->addArgument (QString("clean"));
-	m_pNewProcess->start ();
+	m_pNewProcess->addArgument ( QString ( "make"  ) );
+	m_pNewProcess->addArgument ( QString ( "clean" ) );
+	m_pNewProcess->start ( );
 	iRet = system ( "rm ../bin/qdvdautor; rm ../bin/qslideshow; rm ../bin/qplayer; rm ../bin/configurator; rm ../bin/qrender; rm ../bin/core*");
 	iRet = system ( "rm ../qdvdauthor/i18n/*.qm ../qdvdauthor/CONFIG.h ../qdvdauthor/qplayer/MEDIA_CONFIG.h 2>&1 > /dev/null" );
+	iRet = system ( "../addons/make.sh clean" );
+	iRet = system ( "../qdvdauthor/plugins/make.sh clean" );
 	buttonExecute->setEnabled( false );
 	buttonInstall->setEnabled( false );
 }
 
-void Configurator::slotExecute()
+void Configurator::slotExecute ( )
 {
 	int iRet = 0;
-	iRet = system ("../bin/qdvdauthor &");
+	iRet = system ( "../bin/qdvdauthor &" );
 }
 
-void Configurator::slotInstall()
+void Configurator::slotInstall ( )
 {
 	// Due to security risks it is a major problem to generate a GUI to ask for the root password
 	// and then execute something with root privileges.
@@ -527,102 +665,126 @@ void Configurator::slotInstall()
 	/////////////////////////////////////////////////////////////////////////////////////////////////
 	uint t;
 	bool bCanWriteToInstallDir;
-	QString qsPassword, qsQTDir;
-	QString qsPath = editInstallDir->text();
+	QString qsPassword, qsQTDir, qsQTDir4;
+	QString qsPath = editInstallDir->text ( );
 	
-	if (m_pNewProcess)	{
-		if (m_pNewProcess->isRunning())
+	if ( m_pNewProcess )  {
+		if ( m_pNewProcess->isRunning ( ) )
 			return;
-		else 
+		else
 			delete m_pNewProcess;
+		m_pNewProcess = NULL;
 	}
 	bCanWriteToInstallDir = false;
 	// First we check if we can write to the chosen directory ...
-	QFile file( editInstallDir->text() + QString ("/bin/test_file") );
-	if ( file.open( IO_WriteOnly ) )	{
+	QFile file ( editInstallDir->text ( ) + QString ( "/bin/test_file" ) );
+	if  ( file.open ( IO_WriteOnly ) )  {
 		bCanWriteToInstallDir = true;
-		file.close();
-		file.remove();
+		file.close  ( );
+		file.remove ( );
 	}
 	// Here we give the user a hint ...
-	QDir theDir (qsPath);
+	QDir theDir ( qsPath );
 	
-	for (t=0;t<2;t++)	{
-		if (!theDir.exists())	{
+	for ( t=0; t<2; t++ )  {
+		if ( ! theDir.exists ( ) )  {
 			QMessageBox::warning ( this, "Directory missing.",
-				QString("Could not find the directory \n%1\n"
-					"Please make sure this directory exists first.").arg(qsPath), 
-				QMessageBox::Ok, QMessageBox::NoButton);
+				QString ( "Could not find the directory \n%1\n"
+					  "Please make sure this directory exists first." ).arg ( qsPath ),
+				QMessageBox::Ok, QMessageBox::NoButton );
 			return;
 		}
-		qsPath = editInstallDir->text() + QString ("/bin");
+		qsPath = editInstallDir->text ( ) + QString ( "/bin" );
 		theDir.setPath(qsPath);
 	}
 	// the next check is to see if we can find kdesu
-	QString qsGuiSU = findGuiSU();
-	if (qsGuiSU.isEmpty())
+	QString qsGuiSU = findGuiSU ( );
+	if ( qsGuiSU.isEmpty ( ) )
 		bCanWriteToInstallDir = true;
 
 	m_iTotalSteps  = 24;
-	m_iCurrentStep = 0;
-	tabWidget2->setCurrentPage(2);
-	progressBarCompile->setProgress (0);
+	m_iCurrentStep =  0;
+	tabWidget2->setCurrentPage      ( 2 );
+	progressBarCompile->setProgress ( 0 );
 
-	m_pNewProcess  = new QProcess ( this );
-	connect( m_pNewProcess, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( m_pNewProcess, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
+	m_pNewProcess   =  new QProcess ( this );
+	connect ( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromStdout ( ) ) );
+	connect ( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited  ( ) ) );
 	QStringList listEnv;
 
 	// Here we print the newly added environment variables.
 	// This does not work since we start out in /root after changing to become root to install
 //	m_pNewProcess->setWorkingDirectory (QDir ("../qdvdauthor/"));
 	// Did not know how to handle this in one line so I create another bash script ...
-	qsQTDir = QString (getenv ("QTDIR"));
-	if ( qsQTDir.isEmpty () )
-	  qsQTDir = searchQTDir ();
+	qsQTDir = QString ( getenv ( "QTDIR" ) );
+	if ( getenv ( "QTDIR3" ) )
+		qsQTDir = QString ( getenv ( "QTDIR3" ) );
+	if ( qsQTDir.isEmpty ( ) )
+	  qsQTDir = searchQTDir ( );
 	else
-	  qsQTDir = QString("export QTDIR=%1\n").arg(qsQTDir);
+	  qsQTDir = QString ( "export QTDIR=%1\n" ).arg ( qsQTDir );
 
-	theDir = QDir::current();
-	theDir.cdUp();
-	file.setName("/tmp/make_install.sh");
-	if ( file.open( IO_WriteOnly ) ) {
-		QTextStream stream( &file );
-		stream << "#!/bin/sh\n\n" << qsQTDir << QString ("make -C %1 install").arg(theDir.absPath());
-		file.close();
+	if ( getenv ( "QTDIR4" ) )
+	  qsQTDir4 = getenv ( "QTDIR4" );
+	if ( ! editQtDir4->text ( ).isEmpty ( ) )
+	  qsQTDir4 = editQtDir4->text  ( );
+	if ( qsQTDir4.isEmpty ( ) )
+	  qsQTDir4 = qsQTDir;
+
+	theDir = QDir::current ( );
+	theDir.cdUp  ( );
+	file.setName ( "/tmp/make_install.sh" );
+	if ( file.open ( IO_WriteOnly ) ) {
+		QTextStream stream ( &file );
+		stream << "#!/bin/sh\n\n";//  << qsQTDir << QString ( "make -C %1 install\n" ).arg ( theDir.absPath ( ) );
+		stream << qsQTDir << "\n";
+		stream << "cd " << theDir.absPath ( ) << "\n"; // change into the main QDVDAUthor source dir
+		stream << "cd qdvdauthor; make install; cd ..\n";
+		if ( m_pCheckQPlayer->isChecked   ( ) )
+			stream << "cd qdvdauthor/qplayer; make install; cd ../..\n";
+		if ( m_pCheckQSlideshow->isChecked( ) )
+			stream << "cd qdvdauthor/qslideshow; make install; cd ../..\n";
+		if ( m_pCheckLibJHead->isChecked  ( ) )
+			stream << "cd addons; ./make.sh install; cd ..\n";
+		if ( m_pCheckPlugins->isChecked   ( ) )
+			stream << "cd qdvdauthor/plugins; ./make.sh install; cd ../..\n\n";
+		stream << "export QTDIR=" << qsQTDir4 << "\n";
+		if ( m_pCheckQRender->isChecked   ( ) )
+			stream << "cd qrender; make install; cd ..\n";
+		file.close ( );
 	}
-	chmod ("/tmp/make_install.sh", S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
+	chmod ( "/tmp/make_install.sh", S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
 
 	if (!bCanWriteToInstallDir)	{
-		if (qsGuiSU == QString ("kdesu"))	{
-			m_pNewProcess->addArgument ("kdesu");
-			m_pNewProcess->addArgument ("-n");
-			m_pNewProcess->addArgument ("-t");
-			m_pNewProcess->addArgument ("-c");
+		if ( qsGuiSU == QString ( "kdesu" ) )  {
+			m_pNewProcess->addArgument ( "kdesu" );
+			m_pNewProcess->addArgument (    "-n" );
+			m_pNewProcess->addArgument (    "-t" );
+			m_pNewProcess->addArgument (    "-c" );
 		}
-		else if (qsGuiSU == QString ("xsu"))	{
-			m_pNewProcess->addArgument ("xsu");
-			m_pNewProcess->addArgument ("--username");
-			m_pNewProcess->addArgument ("root");
-			m_pNewProcess->addArgument ("--message");
-			m_pNewProcess->addArgument ("Please type in the root password");
-			m_pNewProcess->addArgument ("--command");
+		else if ( qsGuiSU == QString ( "xsu" ) )   {
+			m_pNewProcess->addArgument (        "xsu" );
+			m_pNewProcess->addArgument ( "--username" );
+			m_pNewProcess->addArgument (       "root" );
+			m_pNewProcess->addArgument (  "--message" );
+			m_pNewProcess->addArgument ( "Please type in the root password");
+			m_pNewProcess->addArgument (  "--command" );
 		}
-		else if (qsGuiSU == QString ("gnomesu"))	{
-			m_pNewProcess->addArgument ("xsu");
-			m_pNewProcess->addArgument ("--username");
-			m_pNewProcess->addArgument ("root");
-			m_pNewProcess->addArgument ("--message");
-			m_pNewProcess->addArgument ("Please type in the root password");
-			m_pNewProcess->addArgument ("--command");
+		else if ( qsGuiSU == QString ( "gnomesu" ) )  {
+			m_pNewProcess->addArgument (        "xsu" );
+			m_pNewProcess->addArgument ( "--username" );
+			m_pNewProcess->addArgument (       "root" );
+			m_pNewProcess->addArgument (  "--message" );
+			m_pNewProcess->addArgument ( "Please type in the root password");
+			m_pNewProcess->addArgument (  "--command" );
 		}
 	}
-	m_pNewProcess->addArgument ("/tmp/make_install.sh");
+	m_pNewProcess->addArgument ( "/tmp/make_install.sh" );
 
-	m_pNewProcess->start ();
+	m_pNewProcess->start ( );
 }
 
-void Configurator::slotOkay()
+void Configurator::slotOkay ( )
 {
 /*	const char *pQtDir = editQtDir->text();
 	setenv ("QTDIR", pQtDir, 1);
@@ -633,9 +795,9 @@ void Configurator::slotOkay()
 	// And here we generate the make file and compile the application.
 	system ("cd ../qdvdauthor; qmake qdvdauthor.pro");
 */
-	if (m_pNewProcess)
-        	m_pNewProcess->tryTerminate();
-	accept ();
+	if ( m_pNewProcess )
+        	m_pNewProcess->tryTerminate ( );
+	accept ( );
 }
 
 void Configurator::slotAboutToQuit()
@@ -756,3 +918,23 @@ QString Configurator::searchQTDir ()
       "\n");
   return qsReturn;
 }
+
+void Configurator::slotQRender( bool bChecked )
+{
+	m_pCheckLocalFFMpeg->setEnabled ( bChecked );
+	editQtDir4->setEnabled ( bChecked );
+}
+
+void Configurator::slotHelpPath()
+{
+  QMessageBox::information ( NULL, tr ( "Paths" ),
+    tr ( "The difference between Prefix, and system path is that prefix defines the dir where the files will be installed and the system path defines the dir where the binary expects the files to be installed.\n"
+         "This is important for people who want to create an rpm package in a different directory then the final install place.\n"
+         "In general you can leave both paths to be the same.\n\n"),
+    QMessageBox::Ok ,  QMessageBox::NoButton );
+}
+
+void Configurator::slotPrefixChanged( const QString &qsNewPrefix )
+{
+  editSystemPath->setText ( qsNewPrefix );
+}
