@@ -10,6 +10,9 @@ fi;
 if [ -e qdvdauthor/qplayer/MEDIA_CONFIG.h ]; then
 	rm qdvdauthor/qplayer/MEDIA_CONFIG.h
 fi;
+if [ -e qrender/ffmpeg ]; then
+	rm qrender/ffmpeg
+fi;
 
 # here we print all *.ui files which are not conform to the Qt 3.1 version requirement
 find . -name "*.ui" -exec grep DOCTYPE {} \; | grep -v 3.1
