@@ -14,5 +14,5 @@ echo
 ls -ll qdvdauthor.tar.bz2
 echo
 
-sftp qdvdauthor@sftp.sourceforge.net
-
+#sftp qdvdauthor@sftp.sourceforge.net
+sftp qdvdauthor,qdvdauthor@web.sourceforge.net
