@@ -26,15 +26,16 @@
 
 #include "global.h"
 #include "xml_dvd.h"
-#include "menupreview.h"
-#include "maskobject.h"
-#include "dialogbutton.h"
+#include "dvdmenu.h"
 #include "menuobject.h"
 #include "textobject.h"
-#include "frameobject.h"
-#include "buttonobject.h"
+#include "maskobject.h"
 #include "qdvdauthor.h"
 #include "imageobject.h"
+#include "menupreview.h"
+#include "frameobject.h"
+#include "dialogbutton.h"
+#include "buttonobject.h"
 #include "sourcefileentry.h"
 #include "structuretoolbar.h"
 
@@ -151,7 +152,7 @@ void ButtonObject::drawContents (QPainter *pPainter, uint iWhichState)
 {
   switch ( iWhichState )  {
   case BACKGROUND_IMG:
-    if ( m_listNormalState[0] )	{
+    if ( m_listNormalState[0] )  {
       m_listNormalState[0]->drawContents ( pPainter );
       m_boundingRect = m_listNormalState [0]->boundingRect ( );
       m_rect = m_listNormalState[0]->rect( );
@@ -576,16 +577,16 @@ bool ButtonObject::readObjects (QDomNode &theNode, MenuPreview *pPreview)
 
       if ( tagName == BUTTON_OBJECT_NORMAL )
 	m_listNormalState.append ( pNewObject );
-      
+
       else if ( tagName == BUTTON_OBJECT_SELECTED )
 	m_listSelectedState.append( pNewObject );
-      
+
       else if ( tagName == BUTTON_OBJECT_HIGHLIGHTED )
 	m_listHighlightedState.append ( pNewObject );
-      
+
       else if ( tagName == MENU_OBJECT )
 	MenuObject::readProjectFile( theNode );
-      
+
       else if ( tagName != BUTTON_OBJECT_MULTIPLE )
 	printf ("Warning : ButtonObject::readObjects -=> wrong XML Node <%s>\nContinuing ...\n", (const char *)tagName);
     }
@@ -718,9 +719,10 @@ bool ButtonObject::createContextMenu (QPoint globalPos)
 	m_pContextMenu->insertItem ( tr ("Delete"),          (QObject *)this, SLOT(slotDelete     ( ) ) );
 	iID = m_pContextMenu->insertItem ( tr ("Moveable"),  (QObject *)this, SLOT(slotMoveable   ( ) ) );
 	m_pContextMenu->insertSeparator ( );
-	m_pContextMenu->insertItem ( tr ("Add Frame"),       (QObject *)this, SLOT(slotAddFrame   ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Image"),       (QObject *)this, SLOT(slotAddImage   ( ) ) );
-	m_pContextMenu->insertItem ( tr ("Add Movie"),       (QObject *)this, SLOT(slotAddMovie   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("To Text"),        (QObject *)this, SLOT(slotToText    ( ) ) );
+	m_pContextMenu->insertItem ( tr ("To Frame"),       (QObject *)this, SLOT(slotToFrame   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("To Image"),       (QObject *)this, SLOT(slotToImage   ( ) ) );
+	m_pContextMenu->insertItem ( tr ("To Movie"),       (QObject *)this, SLOT(slotToMovie   ( ) ) );
 	m_pContextMenu->setItemChecked (iID, m_bMoveable);
 
 	m_pContextMenu->exec(globalPos2, 5);
@@ -943,7 +945,7 @@ int ButtonObject::chapter ( bool bAllEntries )
     actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
   if ( actionList.count() < 1 )
     return iChapterNumber;
-  
+
   // To get the total chapter number you have to add up the SourceFileInfos
   // chapters in the SourceFileEntry that come before the actual SourceFileInfo
   // on which the button points.
@@ -1082,19 +1084,127 @@ void ButtonObject::slotMoveable()
   m_bMoveable = !m_bMoveable;
 }
 
-void ButtonObject::slotAddFrame()
+void ButtonObject::slotToText ( )
 {
+  // Converts the current ButtonObject type to a TextButton
+  DVDMenu *pCurrentMenu = Global::pApp->getCurrentSubMenu ( );
+  if ( ! pCurrentMenu )
+    return;
 
+  MenuPreview *pMenuPreview = pCurrentMenu->getMenuPreview ( );
+  if ( ! pMenuPreview )
+    return;
+
+  MenuObject  *pNewObject = pMenuPreview->createTextObject ( true );
+  if ( ! pNewObject )
+    return;
+
+  pMenuPreview->removeObject ( pNewObject );
+  MenuObject *pOldObject = m_listNormalState[0];
+
+  pNewObject->setRect        (  pOldObject->rect      ( ) );
+  pNewObject->setModifiers   ( *pOldObject->modifiers ( ) );
+
+  m_listNormalState.remove   ( pOldObject );
+  m_listNormalState.append   ( pNewObject );
+
+  emit ( signalUpdatePixmap    ( ) );
+  emit ( signalUpdateStructure ( ) );
+
+  delete pOldObject;
 }
 
-void ButtonObject::slotAddImage()
+void ButtonObject::slotToFrame ( )
 {
+  // Converts the current ButtonObject type to a FrameButton
+  DVDMenu *pCurrentMenu = Global::pApp->getCurrentSubMenu ( );
+  if ( ! pCurrentMenu )
+    return;
 
+  MenuPreview *pMenuPreview = pCurrentMenu->getMenuPreview ( );
+  if ( ! pMenuPreview )
+    return;
+
+  MenuObject  *pNewObject = pMenuPreview->createFrameObject ( true );
+  if ( ! pNewObject )
+    return;
+
+  pMenuPreview->removeObject ( pNewObject );
+  MenuObject *pOldObject = m_listNormalState[0];
+
+  pNewObject->setRect        (  pOldObject->rect      ( ) );
+  pNewObject->setModifiers   ( *pOldObject->modifiers ( ) );
+
+  m_listNormalState.remove   ( pOldObject );
+  m_listNormalState.append   ( pNewObject );
+
+  emit ( signalUpdatePixmap    ( ) );
+  emit ( signalUpdateStructure ( ) );
+
+  delete pOldObject;
 }
 
-void ButtonObject::slotAddMovie() // movie object for the Menu that is ...
+void ButtonObject::slotToImage ( )
 {
+  // Converts the current ButtonObject type to a ImageButton
+  DVDMenu *pCurrentMenu = Global::pApp->getCurrentSubMenu ( );
+  if ( ! pCurrentMenu )
+    return;
 
+  MenuPreview *pMenuPreview = pCurrentMenu->getMenuPreview ( );
+  if ( ! pMenuPreview )
+    return;
+
+  MenuObject  *pNewObject = pMenuPreview->createImageObject ( true );
+  if ( ! pNewObject )
+    return;
+
+  pMenuPreview->removeObject ( pNewObject );
+  MenuObject *pOldObject = m_listNormalState[0];
+
+  pNewObject->setRect        (  pOldObject->rect      ( ) );
+  pNewObject->setModifiers   ( *pOldObject->modifiers ( ) );
+
+  m_listNormalState.remove   ( pOldObject );
+  m_listNormalState.append   ( pNewObject );
+
+  ImageObject *pImage = (ImageObject *)pNewObject;
+  pImage->updatePixmap ( );
+
+  emit ( signalUpdatePixmap    ( ) );
+  emit ( signalUpdateStructure ( ) );
+
+  delete pOldObject;
+}
+
+void ButtonObject::slotToMovie ( ) // movie object for the Menu that is ...
+{
+  // Converts the current ButtonObject type to a MovieButton
+  DVDMenu *pCurrentMenu = Global::pApp->getCurrentSubMenu ( );
+  if ( ! pCurrentMenu )
+    return;
+
+  MenuPreview *pMenuPreview = pCurrentMenu->getMenuPreview ( );
+  if ( ! pMenuPreview )
+    return;
+
+  MenuObject  *pNewObject = pMenuPreview->createMovieObject ( true );
+  if ( ! pNewObject )
+    return;
+
+  pMenuPreview->removeObject ( pNewObject );
+  MenuObject *pOldObject = m_listNormalState[0];
+
+  pNewObject->setRect        (  pOldObject->rect      ( ) );
+  pNewObject->setModifiers   ( *pOldObject->modifiers ( ) );
+
+  m_listNormalState.remove   ( pOldObject );
+  m_listNormalState.append   ( pNewObject );
+
+  emit ( signalUpdatePixmap    ( ) );
+  emit ( signalUpdateStructure ( ) );
+
+  delete pOldObject;
 }
 
 void ButtonObject::setRect ( QRect &theRect )
