@@ -28,7 +28,7 @@
 #include <qdir.h>
 #include <qdom.h>
 
-#include "CONFIG.h"
+#include "global.h"
 #include "utils.h"
 #include "messagebox.h"
 #include "cachethumbs.h"
@@ -495,6 +495,10 @@ void Thumbs::ImageEntry::scanImages ( QObject * ) // load images from cache
   if ( pPlugin )  {
     jhead::JHead::Info *pInfo = pPlugin->getFileInfo ( qsFileName );
     if ( pInfo && pInfo->pThumbnail )  {
+//printf ( "%s::%s : %d > imgDate<%s> vs created<%s>\n", __FILE__, __FUNCTION__, __LINE__, pInfo->imageDate.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ), dateCreated.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ) );
+      if ( pInfo->imageDate.isValid ( ) )
+        dateCreated = pInfo->imageDate;
+
       // Take ownership of the thumbnail
       arrayOfThumbs[0]  = pInfo->pThumbnail;
       pInfo->pThumbnail = NULL;
@@ -759,7 +763,7 @@ bool Thumbs::loadPlugin ( )
   m_pDestroyFunction = NULL;
   m_pPlugin          = NULL;
 
-  QString qsFilePath ( PREFIX_DIRECTORY"/share/qdvdauthor/lib/libjhead.so" );
+  QString qsFilePath ( Global::qsSystemPath + "/share/qdvdauthor/lib/libjhead.so" );
 
   m_pLibrary = dlopen ( qsFilePath.ascii ( ), RTLD_LAZY );
   if ( ! m_pLibrary ) {
