@@ -244,12 +244,13 @@ protected:
   void currentSourceToPreview    ( );
   void allSourcesToPreview       ( );
   void stopThumbing              ( );
-  void play              ( QString );
+  void play              ( Cache::Thumbs::Entry *, QIconViewItem *p=NULL );
   void lock              ( );
   void unlock            ( );
   bool lockDialog        ( );
   void unlockDialog      ( );
   bool isImageDialog     ( );
+  bool isImageDialog     ( QString );
 
   QValueList<QListViewItem *> getSelectedVirtual ( );
 
@@ -261,7 +262,6 @@ protected:
   virtual void newThumbnailRequest ( QIconViewItem * );
   virtual void showBasicMenu       ( const QPoint &  );
   virtual void showContextMenu     ( const QPoint &, QIconViewItem * );
-  virtual void playFromGroup       ( Cache::Thumbs::Entry * );
   virtual GroupView *addGroup      ( SourceFileEntry * );
   virtual QString getDirFilter     ( );
 
