@@ -17,10 +17,12 @@
 #include <qspinbox.h>
 #include <qwmatrix.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qiconview.h>
 #include <qtabwidget.h>
 #include <qpopupmenu.h>
 #include <qpushbutton.h>
+#include <qradiobutton.h>
 #include <qprogressbar.h>
 #include <qapplication.h>
 #include <qinputdialog.h>
@@ -28,6 +30,7 @@
 #include <qtoolbox.h>
 #include <qmessagebox.h>
 
+#include "utils.h"
 #include "global.h"
 #include "previewer.h"
 #include "qdvdauthor.h"
@@ -97,7 +100,7 @@ void DialogImages::initMe ( )
   if ( pGroupTab )
     m_pTabWidget->setTabLabel ( pGroupTab, QString ( "Slideshows" ) );
 
-  m_iMultiThumbNumber = 1;
+// m_iMultiThumbNumber = 1;
   m_iMaxThreads       = 2; // default to 2 worker threads
   if ( getenv ( "MAX_IMG_RENDER_THREADS" ) )  {
     uint iEnv = QString ( getenv ( "MAX_IMG_RENDER_THREADS" ) ).toUInt ( );
@@ -130,11 +133,19 @@ void DialogImages::slotEditGroup ( )
   if ( theDialog.exec ( ) == QDialog::Accepted )  {
     pSlideshow->slideshow_name = theDialog.m_pEditName->text  ( );
     m_pToolbox->setItemLabel ( iIdx, pSlideshow->slideshow_name );
-    pSlideshow->background   = theDialog.background ( );
-    pSlideshow->delay        = theDialog.m_pSpinImageDelay->value    ( );
-    pSlideshow->filter_delay = theDialog.m_pSpinFilterDelay->value   ( );
-    pSlideshow->intro_page   = theDialog.m_pCheckIntroPage->isChecked( );
-    pSlideshow->audio_list   = theDialog.audioList  ( );
+    pSlideshow->background       = theDialog.background ( );
+    pSlideshow->delay            = theDialog.m_pSpinImageDelay->value    ( );
+    pSlideshow->filter_delay     = theDialog.m_pSpinFilterDelay->value   ( );
+    pSlideshow->intro_page       = theDialog.m_pCheckIntroPage->isChecked( );
+    pSlideshow->audio_list       = theDialog.audioList  ( );
+    pSlideshow->validFilterNames = theDialog.filterList ( );
+    pSlideshow->yres             =(theDialog.m_pComboFormat->currentItem ( ) == 0) ? 480 : 576;
+    pSlideshow->xres             = 720;
+
+    bool bChecked = theDialog.m_pRadioImgBkgImg->isChecked ( );
+    QValueList<CXmlSlideshow::filter_struct *>::iterator it = pSlideshow->m_listFilter.begin ( );
+    while ( it != pSlideshow->m_listFilter.end ( ) )
+      (*it++)->bImgBackgroundImg = bChecked;
   }
 }
 
@@ -174,8 +185,9 @@ GroupView *DialogImages::addGroup ( SourceFileEntry *pEntry )
   if ( ! pInfo->pSlideshow )
     return NULL;
 
-  Cache::Thumbs::Entry      *pCache;
-  CXmlSlideshow::img_struct *pXMLImg;
+  Cache::Thumbs::Entry       *pCache;
+  CXmlSlideshow::img_struct  *pXMLImg;
+  CXmlSlideshow::time_object *pXMLObj;
   CXmlSlideshow    *pSlideshow = new CXmlSlideshow;
   *pSlideshow    = *pInfo->pSlideshow;
   pSlideshow->id = (void *)pEntry;
@@ -192,14 +204,17 @@ GroupView *DialogImages::addGroup ( SourceFileEntry *pEntry )
   int t, iCount;
   bool bAlternate = true;
 
-  iCount = pSlideshow->countImg ( );
+  iCount = pSlideshow->count ( );
 //  for ( t=0; t<iCount; t++ )  {
   for ( t=iCount-1; t>=0; t-- )  {
-    pXMLImg = pSlideshow->getImg ( t );
-    if ( ! pXMLImg )
+    pXMLObj = pSlideshow->getTimeObject ( t );
+    if ( ! pXMLObj )
+      continue;
+    if ( ( pXMLObj->node_name != "vid" ) && ( pXMLObj->node_name != "img" ) )
       continue;
 
-    pCache = Global::pThumbsCache->find ( pXMLImg->src, true ); // isImageDialog ( ) );
+    pXMLImg = (CXmlSlideshow::img_struct *)pXMLObj;
+    pCache  = Global::pThumbsCache->find ( pXMLImg->src, isImageDialog ( pXMLImg->src ) );
     if ( ! pCache )
            pCache = Global::pThumbsCache->append ( pXMLImg->src, (QImage *)NULL );
 
@@ -244,7 +259,10 @@ QValueList<CXmlSlideshow *> &DialogImages::getSlideshows ( )
 
 QString DialogImages::getDirFilter ( )
 {
-  return Global::pApp->getImageFilter ( );
+//  return Global::pApp->getImageFilter ( );
+  QString qsImageFilter = Global::pApp->getImageFilter ( );
+  QString qsVidFilter   = Global::pApp->getVidFilter   ( );
+  return qsImageFilter + " " + qsVidFilter;
 }
 
 void DialogImages::slotCheckWorker ( )
@@ -324,9 +342,12 @@ void DialogImages::slotCheckWorker ( )
 
 void DialogImages::newThumbnailRequest ( QIconViewItem *pItem )
 {
+  if ( ! isImageDialog ( pItem->key ( ) ) )
+    return DialogFiles::newThumbnailRequest ( pItem );
+
   ImageScan *pImageScan = new ImageScan ( this,pItem );
   lock   ( );
-  m_listOfImageScansToDo.append         ( pImageScan );
+    m_listOfImageScansToDo.append       ( pImageScan );
   unlock ( );
   if ( m_listOfWorker.count  ( ) < m_iMaxThreads )  {
        m_listOfWorker.append ( new Worker ( this ) );
@@ -511,8 +532,12 @@ void DialogImages::setIconText ( DialogFiles::Thumbs *pThumbs )
     return;
   }
 
-  QString   qsText;
-  QFileInfo fileInfo ( pThumbs->pOwnerItem->key ( ) );
+  QString   qsText, qsFileName;
+  qsFileName = pThumbs->pOwnerItem->key ( );
+  if ( ! isImageDialog ( qsFileName ) )
+    return DialogFiles::setIconText ( pThumbs );
+
+  QFileInfo fileInfo ( qsFileName );
   Cache::Thumbs::ImageEntry *pImageEntry = (Cache::Thumbs::ImageEntry *)pThumbs->pCache;
 
   if ( m_bName )
@@ -637,6 +662,7 @@ void DialogImages::showBasicMenu ( const QPoint &pos )
 void DialogImages::showContextMenu ( const QPoint &pos, QIconViewItem * )
 {
   int t, iID, iIDs[10], iStarRating = -2;
+  bool bVidsSelected = false;
   Thumbs *pThumbs = NULL;
   QPoint globalPos  = pos, globalPos2 = pos;
 
@@ -668,20 +694,29 @@ void DialogImages::showContextMenu ( const QPoint &pos, QIconViewItem * )
            iStarRating  = (int)pThumbs->pCache->iStarRating;
       if ( iStarRating != (int)pThumbs->pCache->iStarRating )
            iStarRating  = -1;
+      if (!isImageDialog ( pThumbs->pCache->qsFileName ) )
+           bVidsSelected= true;
     }
   }
 
   // We first create the menu on the right, non blocking.
   QPopupMenu *pStackMenu  =  new  QPopupMenu     (  this  );
   pStackMenu->insertItem ( tr ( "R&emove" ),        this, SLOT ( slotRemove     ( ) ) );
-  iID = pStackMenu->insertItem ( tr ( "&View ..." ),this, SLOT ( slotView       ( ) ) );
+  iID     = pStackMenu->insertItem ( tr ( "&View ..." ),      this, SLOT ( slotView       ( ) ) );
   pStackMenu->insertSeparator ( );
-  pStackMenu->insertItem ( tr ( "Rotate &90"  ),    this, SLOT ( slotRotate90   ( ) ) );
-  pStackMenu->insertItem ( tr ( "Rotate &180" ),    this, SLOT ( slotRotate180  ( ) ) );
-  pStackMenu->insertItem ( tr ( "Rotate &270" ),    this, SLOT ( slotRotate270  ( ) ) );
-  pStackMenu->insertItem ( tr ( "Rotate &Free" ),   this, SLOT ( slotRotateFree ( ) ) );
+  iIDs[1] = pStackMenu->insertItem ( tr ( "Rotate &90"  ),    this, SLOT ( slotRotate90   ( ) ) );
+  iIDs[2] = pStackMenu->insertItem ( tr ( "Rotate &180" ),    this, SLOT ( slotRotate180  ( ) ) );
+  iIDs[3] = pStackMenu->insertItem ( tr ( "Rotate &270" ),    this, SLOT ( slotRotate270  ( ) ) );
+  iIDs[4] = pStackMenu->insertItem ( tr ( "Rotate &Free" ),   this, SLOT ( slotRotateFree ( ) ) );
   if (  listIcons.count  ( ) > 1 )
     pStackMenu->setItemEnabled ( iID, false );
+
+  if ( bVidsSelected )  {
+    pStackMenu->setItemEnabled ( iIDs[1], false );
+    pStackMenu->setItemEnabled ( iIDs[2], false );
+    pStackMenu->setItemEnabled ( iIDs[3], false );
+    pStackMenu->setItemEnabled ( iIDs[4], false );
+  }
   //globalPos.setY    ( globalPos.y ( ) - 25 );
   globalPos.setX    ( globalPos.x ( ) - pStackMenu->sizeHint ( ).width ( ) - 4 );
   pStackMenu->popup ( globalPos, 3 );
@@ -941,11 +976,13 @@ void DialogImages::accept ( )
 {
   // Here we build the SourceFileEntries from the information in m_pToolbox
   int t;
+  Utils theUtils;
   GroupView       *pGroupView = NULL;
   GroupView::Item *pGroupItem = NULL;
   CXmlSlideshow   *pSlideshow = NULL;
   CXmlSlideshow    tempSlideshow;
   CXmlSlideshow::img_struct *pXmlImg = NULL;
+  CXmlSlideshow::vid_struct *pXmlVid = NULL;
 
   if ( ! m_bCanClose ) {
     if ( QMessageBox::warning ( this, tr ( "Can't close." ), tr ( "Can not close dialog while waiting for MediaScanner to finish.\nDo you want to force Quit ?" ), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
@@ -978,18 +1015,32 @@ void DialogImages::accept ( )
       // We need to clear the objects and re-add them based on what is in the GroupView.
       // For this we create a temp copy to preserve the other image attributes
       if ( pSlideshow )  {
-        Cache::Thumbs::ImageEntry *pCache;
+        Cache::Thumbs::Entry      *pVidCache;
+        Cache::Thumbs::ImageEntry *pImgCache;
         tempSlideshow = *pSlideshow;
         pSlideshow->clearObjects ( );
         while ( pGroupItem )  {
-          pXmlImg       = pSlideshow->addImg ( );
-          pXmlImg->src  = pGroupItem->pCache->qsFileName;
-          pXmlImg->text = pGroupItem->text ( 0 );
-          rescueImageAttributes ( pXmlImg, &tempSlideshow );
-          pCache = (Cache::Thumbs::ImageEntry *)Global::pThumbsCache->find ( pXmlImg->src, true );
-          if ( pCache && pCache->getMatrix ( ) )  {
-            pXmlImg->rotate  = pCache->fRotate;
-            pXmlImg->pMatrix = new QWMatrix ( *pCache->getMatrix ( ) );
+          if ( isImageDialog ( pGroupItem->pCache->qsFileName ) )  {
+            pXmlImg       = pSlideshow->addImg ( );
+            pXmlImg->src  = pGroupItem->pCache->qsFileName;
+            pXmlImg->text = pGroupItem->text ( 0 );
+            rescueImageAttributes ( pXmlImg, &tempSlideshow );
+            pImgCache = (Cache::Thumbs::ImageEntry *)Global::pThumbsCache->find ( pXmlImg->src, true );
+            if ( pImgCache && pImgCache->getMatrix ( ) )  {
+              pXmlImg->rotate  = pImgCache->fRotate;
+              pXmlImg->pMatrix = new QWMatrix ( *pImgCache->getMatrix ( ) );
+            }
+          }
+          else  {
+            pXmlVid       = pSlideshow->addVid ( );
+            pXmlVid->src  = pGroupItem->pCache->qsFileName;
+            pXmlVid->text = pGroupItem->text ( 0 );
+            pVidCache     = Global::pThumbsCache->find ( pXmlVid->src, false );
+            if ( pVidCache )  {
+                 pXmlVid->length = theUtils.getMsFromString ( pVidCache->qsLength );
+                 pXmlVid->fDuration = (float)pXmlVid->length / 1000.0f;
+            }
+            rescueImageAttributes ( pXmlVid, &tempSlideshow );
           }
           // pXmlImg has the following vars ...
           // float fDuration; float fStartTime; float fEndTime; QString text;
