@@ -146,10 +146,10 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   m_pEditStarting1 = m_pEditStarting2;
   m_pEditEnding1   = m_pEditEnding2;
   m_pButtonEdit->setEnabled ( false );
-  
+
   pTab = m_pTabWidget->page ( GEOMETRY_TAB );
   initAudioTab ( NULL, pMenu );
-  
+
   // The following lines will display the [Change Size ...] button.
   QSizePolicy policy (QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
   delete textLabel4;
@@ -165,6 +165,7 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   connect    ( m_pButtonCK, SIGNAL(clicked ()), this, SLOT ( slotSizeDialog     ( ) ) );
   groupBox8->setTitle ("");
   m_pCheckSameAsMenuLength->hide ( );
+  m_pButtonLoop->hide ( );
 
   if (  (  ! pMenu->getInterface ( )->qsPause.isEmpty ( ) ) && 
         (    pMenu->getInterface ( )->qsPause !=  "inf" ) ) 
@@ -200,6 +201,7 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
     m_pTextTitle->setText (tr ("ImageBackground : %1").arg(fileInfo.fileName()));
     setCaption ( fileInfo.fileName () );
     m_pTabWidget->setTabLabel (pTab, "ImageBackground");
+
     // And finally we hide the play buttons etc.
     delete m_pButtonPlay;
     delete m_pButtonStop;
@@ -210,6 +212,15 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
     delete m_pLabelCurrentPos;
     delete m_pFrameControl;
   }
+
+  m_pComboPostCommand->clear ( );
+  m_pComboPostCommand->insertItem ( " jump vmgm menu 1; " );
+
+  if ( ! pMenu->getInterface ( )->qsPre.isEmpty  ( ) )
+    m_pComboPreCommand->setCurrentText ( pMenu->getInterface  ( )->qsPre  );
+  if ( ! pMenu->getInterface ( )->qsPost.isEmpty ( ) )
+    m_pComboPostCommand->setCurrentText ( pMenu->getInterface ( )->qsPost );
+
   // These controls are not used ...
   delete groupBox2;
   resize ( 400, 300 );
@@ -254,7 +265,7 @@ void DialogMovie::initMe ( SourceFileEntry *pSourceFileEntry )
   delete m_pSliderVolume;
   delete m_pLabelCurrentPos;
   delete m_pFrameControl;
-  
+
   connect (m_pComboVideoOut,        SIGNAL( activated(const QString &)), this, SLOT (slotVideoOutChanged(const QString &)));
   connect (m_pComboVideoResolution, SIGNAL( activated(const QString &)), this, SLOT (slotVideoResolutionChanged(const QString &)));
   connect (m_pComboVideoRate,       SIGNAL( activated(const QString &)), this, SLOT (slotVideoRateChanged(const QString &)));
@@ -276,15 +287,15 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
     pEntry  = pDVDAuthor->sourceFileEntry ( t );
     if ( pEntry ) {
       for ( i=0; i<(int)pEntry->listFileInfos.count ( ); i++ ) {
-	if ( pEntry->listFileInfos[i] == pInfo ) {
-	  m_pParentSourceFileEntry = pEntry;
-	  t = pDVDAuthor->sourceFileCount ( ); // exit t and i - loop
-	  break;
-	}
+        if ( pEntry->listFileInfos[i] == pInfo ) {
+          m_pParentSourceFileEntry = pEntry;
+          t = pDVDAuthor->sourceFileCount ( ); // exit t and i - loop
+          break;
+        }
       }
     }
   }
-  
+
   // Okay coming from the SourceToolbar we do not need the Geometry - tab
   QWidget *pGeometry  = m_pTabWidget->page (GEOMETRY_TAB);
   m_pTranscodeTab = m_pTabWidget->page (TRANSCODING_TAB);
@@ -307,11 +318,11 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
   // Here we copy the infos over ...
   m_sourceFileInfo = *pInfo;
   QFileInfo fileInfo(m_sourceFileInfo.qsFileName);
-  
+
   // and now on to initializing the dialog. Length : 00:07:23.123 File : Cool Video.mpg
   m_pTextTitle->setText (tr ("Length : <%1> File : %2").arg(qsReturn).arg(fileInfo.fileName()));
   setCaption ( fileInfo.fileName ( ) );
-  
+
   m_pListBoxChapters->clear ( );
   if ( m_sourceFileInfo.listChapters.count  ( ) == 0 )
     m_pListBoxChapters->insertItem (QString ( "00:00:00.000" ) );
@@ -322,34 +333,34 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
   m_pComboPreCommand->setCurrentText  (m_sourceFileInfo.qsPreCommand);
   m_pComboPostCommand->setCurrentText (m_sourceFileInfo.qsPostCommand);
   m_pSpinBoxPause->setValue           (m_sourceFileInfo.iPause);
-  
+
   m_pSpinBoxTitle->setEnabled  ( false );
   m_pSpinBoxTitleset->setValue ( m_sourceFileInfo.iTitleset );
 
   m_pMediaInterface = MediaCreator::createPreferredWidget (m_pMediaPreview, "ChapterXineWidget", (void *)pExistingMediaEngine);
-  
+
   connect (m_pMediaInterface, SIGNAL(signalNewPosition(int, const QString&)), this, SLOT(slotNewPosition(int, const QString&)));
   QGridLayout *pVideoLayout = new QGridLayout (m_pMediaPreview, 1, 1, 2, 2, "MediaMainLayout");
   pVideoLayout->addWidget (m_pMediaInterface->getWidget(), 0, 0);
   // This is take care of in the polish () function for Xine and not necessary for MPlayer ...
   m_pMediaInterface->initMediaEngine();
-  
+
   m_qsFileName      = m_sourceFileInfo.qsFileName;
   m_pExistingEngine = pExistingMediaEngine;
-  
+
   // This is the new version, where I have a new WidgetControl.
   QGridLayout *pLayout = new QGridLayout      ( m_pFrameControl, 1, 1, 2, 2, "pLayout");
   m_pStartStopControl  = new StartStopControl ( m_pFrameControl );
   m_pStartStopControl->initMe ( m_sourceFileInfo.qsFileName, iThumbnailSize, iLength);
   connect (m_pStartStopControl, SIGNAL (signalSliderValues   ( float, float ) ), this, SLOT ( slotSliderValues   ( float, float ) ) );
   connect (m_pStartStopControl, SIGNAL (signalSliderReleased ( bool ) ),         this, SLOT ( slotSliderReleased ( bool ) ) );
-  
+
   initAudioTab ( &m_sourceFileInfo );
   m_iMovieLength = iLength;
   if ( m_iMovieLength < 1 )
     m_iMovieLength = 1;
   pLayout->addWidget( m_pStartStopControl, 0, 0 );
-  
+
   if ( m_sourceFileInfo.pTranscodeInterface )	{
     if ( m_sourceFileInfo.pTranscodeInterface->iEndingAt == 0 )
       m_sourceFileInfo.pTranscodeInterface->iEndingAt = m_iMovieLength;
@@ -360,24 +371,24 @@ void DialogMovie::initMe ( SourceFileInfo *pInfo, const void *pExistingMediaEngi
     m_pEditStarting1->setText (startingTime.toString(qsFormat));
     m_pEditEnding1  ->setText (endingTime.toString  (qsFormat));
   }
-  
+
   m_pLabelVideoFormat->setText (QString ("%1(%2) %3Hz").arg( pInfo->qsVideoFormat ).arg ( pInfo->qsResolution ).arg ( pInfo->qsFPS ) );
-  
+
   m_pLabelAudioFormat->setText(QString ("%1 %2bit %3").arg( pInfo->qsAudioFormat ).arg( pInfo->qsBits ).arg( pInfo->qsSample ) );
-  
+
   m_pButtonEncodeNow->hide ( );
-  
+
   // Here we init the properties - tab
   initTranscodeTab ( );
   m_pTabWidget->setCurrentPage ( 0 );
-  
+
   // And finally here are the callback functions ...
   connect ( m_pButtonAdd,       SIGNAL( clicked ( ) ), this, SLOT ( slotAddChapter   ( ) ) );
   connect ( m_pButtonImport,    SIGNAL( clicked ( ) ), this, SLOT ( slotImportChapter( ) ) );
   connect ( m_pButtonDel,       SIGNAL( clicked ( ) ), this, SLOT ( slotDelChapters  ( ) ) );
   connect ( m_pButtonAuto,      SIGNAL( clicked ( ) ), this, SLOT ( slotAutoChapters ( ) ) );
   connect ( m_pListBoxChapters, SIGNAL( currentChanged (QListBoxItem *)), this, SLOT (slotCurrentChanged(QListBoxItem *)));
-  
+
   connect (m_pComboVideoOut,        SIGNAL( activated(const QString &)), this, SLOT ( slotVideoOutChanged(const QString &)));
   connect (m_pComboVideoResolution, SIGNAL( activated(const QString &)), this, SLOT ( slotVideoResolutionChanged(const QString &)));
   connect (m_pComboVideoRate,       SIGNAL( activated(const QString &)), this, SLOT ( slotVideoRateChanged(const QString &)));
@@ -412,7 +423,7 @@ void DialogMovie::slotSetMediaInfo ( )
 
   m_pLabelVideoCodec->setText ( pMediaInfo->getCodec (  true ) );
   m_pLabelAudioCodec->setText ( pMediaInfo->getCodec ( false ) );  // Stereo 2.0
-  
+
   if ( bCreatedInfo )
     delete pMediaInfo;
 }
@@ -447,29 +458,38 @@ void DialogMovie::initMe ( MovieObject *pMovieObject )
   m_pButtonEncodeNow = NULL;
   m_pEditStarting1   = m_pEditStarting2;
   m_pEditEnding1     = m_pEditEnding2;
-  
+
   // Set the values .
   m_pEditX->setText (QString ("%1").arg(pMovieObject->rect().x()));
   m_pEditY->setText (QString ("%1").arg(pMovieObject->rect().y()));
   m_pEditWidth ->setText (QString ("%1").arg(pMovieObject->rect().width()));
   m_pEditHeight->setText (QString ("%1").arg(pMovieObject->rect().height()));
-	
+
   qsFormat = QString ("hh:mm:ss.zzz");
-  m_iMovieLength   = -pMovieObject->duration ( ).msecsTo  ( QTime ( ) );
+  m_iMovieLength = -pMovieObject->duration ( ).msecsTo  ( QTime ( ) );
 
-
-  //printf ( "len<%d> == <%s>\n\n\n", m_iMovieLength, pMovieObject->duration().toString().ascii() );
- 
-
-  QTime endingTime =  pMovieObject->offset   ( ).addMSecs ( m_iMovieLength );
   m_pEditStarting2->setText ( pMovieObject->offset ( ).toString ( qsFormat ) );
-  m_pEditEnding2  ->setText ( endingTime.toString  ( qsFormat ) );
-  
-  m_rectGeometry = pMovieObject->rect();
-  m_qsFileName   = pMovieObject->fileName();
+  // m_pEditStarting2 must be set before calling maxEndTime
+  QTime endingTime = maxEndTime ( ); //pMovieObject->offset ( ).addMSecs ( m_iMovieLength );
+  QTime   clipTime ( pMovieObject->offset ( ) );
+  clipTime = clipTime.addMSecs ( m_iMovieLength );
+  if  ( m_iMovieLength > 0 )
+        endingTime = clipTime;
+
+  m_pEditEnding2->setText ( endingTime.toString  ( qsFormat ) );
+
+  m_rectGeometry = pMovieObject->rect     ( );
+  m_qsFileName   = pMovieObject->fileName ( );
   m_pCheckSameAsMenuLength->setChecked ( pMovieObject->isMenuLength ( ) );
   m_pEditEnding2->setEnabled         ( ! pMovieObject->isMenuLength ( ) );
-  
+  m_pButtonLoop->setEnabled          ( ! pMovieObject->isMenuLength ( ) );
+  QString strLoop = "Stretch";
+  if ( pMovieObject->loop ( ) == MovieObject::Loop )
+       strLoop  =  "Loop";
+  else if ( pMovieObject->loop ( ) == MovieObject::Stop )
+       strLoop  =  "Stop";
+  m_pButtonLoop->setText ( strLoop );
+
   Rgba theColor;
   ImageManipulator::colorKeying *pKey;
   ImageManipulator *pMan = &pMovieObject->manipulator ( );
@@ -478,16 +498,21 @@ void DialogMovie::initMe ( MovieObject *pMovieObject )
     theColor.setRgb ( pKey->theColor );
     new ListViewColorItem ( m_pListViewCK, theColor, theColor.toString ( ), QString ("%1").arg(pKey->fDeltaColor ) );
   }
-  
+
   QFileInfo fileInfo(m_qsFileName);
   // and now on to initializing the dialog. Length : 00:07:23.123 File : Cool Video.mpg
   m_pTextTitle->setText ( tr ( "File : %1" ).arg ( fileInfo.fileName ( ) ) );
-  setCaption ( fileInfo.fileName ( ) );
 
   // we'll init the MediaEngine here
   DVDMenu *pDVDMenu = pMovieObject->dvdMenu ( );
   initMediaInterface ( pDVDMenu );
+  QString qsCaption = tr  ( "Menu Length : %1" ).arg ( pDVDMenu->getInterface ( )->timeDuration.toString ( qsFormat ) );
+  setCaption ( qsCaption );
+
   connect ( m_pCheckSameAsMenuLength, SIGNAL ( clicked ( ) ), this, SLOT ( slotSameAsMenuLength ( ) ) );
+  connect ( m_pButtonLoop,    SIGNAL ( clicked   ( ) ), this, SLOT ( slotLoop       ( ) ) );
+  connect ( m_pEditEnding2,   SIGNAL ( lostFocus ( ) ), this, SLOT ( slotCheckEnd   ( ) ) );
+  connect ( m_pEditStarting2, SIGNAL ( lostFocus ( ) ), this, SLOT ( slotCheckStart ( ) ) );
 }
 
 void DialogMovie::initMediaInterface ( DVDMenu *pDVDMenu )
@@ -511,7 +536,7 @@ void DialogMovie::initMediaInterface ( DVDMenu *pDVDMenu )
     }
     fileInfo.setFile (m_qsFileName);
     qsBackgroundName = QString (" : %1 <%2>").arg(fileInfo.fileName()).arg(pDVDMenu->getInterface()->timeDuration.toString(qsFormat));
-    
+
     m_pTextTitle->setText (pDVDMenu->name() + qsBackgroundName);
   }
   // Here we create the MediaInterface (the widget) If the mediaengine in NULL or not ...
@@ -525,14 +550,14 @@ void DialogMovie::initMediaInterface ( DVDMenu *pDVDMenu )
 
   QGridLayout *pLayout = new QGridLayout      ( m_pFrameControl, 1, 1, 2, 2, "pLayout" );
   m_pStartStopControl  = new StartStopControl ( m_pFrameControl );
-  
+
   if ( m_pMovieObject || m_pDVDMenu )
     m_pStartStopControl->initMe ( m_qsFileName, iThumbnailSize );  // get length of movieObject a bit later.
   else
     m_pStartStopControl->initMe ( m_qsFileName, iThumbnailSize, m_iMovieLength );
 
   pLayout->addWidget( m_pStartStopControl, 0, 0 );
-  
+
   QTimer::singleShot ( 500, this, SLOT ( slotInitMediaInterface ( ) ) );
 }
 
@@ -548,7 +573,8 @@ void DialogMovie::slotInitMediaInterface ( )
   pMediaInfo = m_pMediaInterface->getMediaInfo ( );
   if ( ! pMediaInfo )
     return;
-  
+
+  QString qsFormat = QString ("hh:mm:ss.zzz");
   // here we extract some information + the screenshot.
   pMediaInfo->setFileName ( m_qsFileName );
 
@@ -557,9 +583,20 @@ void DialogMovie::slotInitMediaInterface ( )
     long  iMSecOffset = zeroTime.msecsTo ( m_pMovieObject->offset ( ) );
     unsigned long int iMovieLength = pMediaInfo->getLength ( );
     m_pMediaInterface->setScreenshot ( iMSecOffset );
+
+    DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu ( );
+    long iMenuLength  = zeroTime.msecsTo  ( pDVDMenu->getInterface ( )->timeDuration );
+
+    if ( iMenuLength >= (long)iMovieLength )  {
+      m_pCheckSameAsMenuLength->setChecked ( FALSE );
+      m_pCheckSameAsMenuLength->setEnabled ( FALSE );
+      slotSameAsMenuLength ( );
+    }
+
     if ( iMovieLength < 1 )
       iMovieLength = m_iMovieLength;
     m_iMovieLength =   iMovieLength;
+    //m_pEditEnding2->setText ( maxEndTime ( ).toString  ( qsFormat ) );
     m_pStartStopControl->createThumbnails ( m_iMovieLength );
   }
   else if ( m_pDVDMenu ) {
@@ -573,19 +610,18 @@ void DialogMovie::slotInitMediaInterface ( )
     m_pStartStopControl->createThumbnails ( m_iMovieLength );
   }
 
-  QString qsFormat = QString ("hh:mm:ss.zzz");
   QTime   lengthTime;
   lengthTime = lengthTime.addMSecs ( m_iMovieLength );
   QString qsLength = lengthTime.toString ( qsFormat );
 
   m_pTextTitle->setText   ( tr ("Length : <%1> File : %2").arg( qsLength ).arg ( fileInfo.fileName ( ) ) );
-  setCaption ( fileInfo.fileName ( ) );
-    
+//  setCaption ( fileInfo.fileName ( ) );
+
   // next is to set the satrting / ending points ...
   QTimer::singleShot ( 50, this, SLOT ( slotSetStartStop ( ) ) );
   connect ( m_pStartStopControl, SIGNAL ( signalSliderValues ( float, float)), this, SLOT ( slotSliderValues   ( float, float ) ) );
   connect ( m_pStartStopControl, SIGNAL ( signalSliderReleased ( bool ) ),     this, SLOT ( slotSliderReleased ( bool ) ) );
-  connect ( m_pSliderVolume,     SIGNAL ( valueChanged         ( int  ) ),     this, SLOT ( slotNewVolume      ( int ) ) );
+  connect ( m_pSliderVolume,     SIGNAL ( valueChanged         ( int  ) ),     this, SLOT ( slotNewVolume      ( int  ) ) );
 }
 
 void DialogMovie::initAudioTab ( SourceFileInfo *pInfo, DVDMenu *pMenu )
@@ -602,7 +638,7 @@ void DialogMovie::initAudioTab ( SourceFileInfo *pInfo, DVDMenu *pMenu )
 	new QListViewItem ( m_pListViewSubtitles, QString ( "%1" ).arg ( pSubtitle->m_iSubtitleNumber ), pSubtitle->m_qsIso639, theUtils.iso639 ( pSubtitle->m_qsIso639, false ), QString ( "%1" ).arg ( pSubtitle->m_listOfSubtitles.count ( ) ) );
       }
     }
-    
+
     for ( t=0; t<MAX_AUDIO; t++ ) {
       pAudio = pInfo->arrayAudio[t];
       if ( pAudio ) {
@@ -610,7 +646,7 @@ void DialogMovie::initAudioTab ( SourceFileInfo *pInfo, DVDMenu *pMenu )
 	new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( pAudio->iAudioNumber ), pAudio->qsIso639, theUtils.iso639 ( pAudio->qsIso639, false ), pAudio->qsFileName );
       }
     }
-    
+
   }
   else if ( pMenu ) {
     CDVDMenuInterface *pInterface = pMenu->getInterface  ( );
@@ -673,7 +709,7 @@ void DialogMovie::slotAddAudio ( )
   }
   else if ( m_sourceFileInfo.audioCount ( ) > 7 )
     bTooMany = true;
-  
+
   if ( bTooMany ) {
     MessageBox::warning ( this, tr ( "Too many audio files." ), tr ( "DVD spec allows a max of 8 audi channels.\nPlease remove one audio channel first." ) );
     return;
@@ -721,7 +757,7 @@ void DialogMovie::slotAddAudio ( )
       pAudio->iAudioNumber = iFreeAudioTrack;
       m_pDVDMenu->getInterface ( )->listSoundEntries.append ( pAudio );
       m_pDVDMenu->slotUpdateStructure ( );
-      
+
       new QListViewItem ( m_pListViewAudio, QString ( "%1" ).arg ( iFreeAudioTrack ), pAudio->qsIso639, qsLanguage, pAudio->qsFileName );
     }
     return;
@@ -1049,7 +1085,7 @@ void DialogMovie::addSubtitle ( QString qsLang, int iValue, QValueList<Subtitles
     m_pParentSourceFileEntry->arraySubtitleEntries [ iValue ].m_iSubtitleNumber = iValue;
     m_pParentSourceFileEntry->arraySubtitleEntries [ iValue ].m_qsIso639        = qsCode;
   }
-  
+
   QListViewItem *pItem = m_pListViewSubtitles->firstChild ( );
   while ( pItem ) {
     if ( pItem->text( 0 ).toInt ( ) == iValue ) {
@@ -1203,17 +1239,138 @@ void DialogMovie::slotSameAsMenuLength ( )
 {
   bool bMenuLength = m_pCheckSameAsMenuLength->isChecked ( );
   m_pEditEnding2->setEnabled ( ! bMenuLength );
-  if ( ! bMenuLength && m_pMovieObject ) {
-    QTime zeroTime;
-    QTime endingTime = m_pMovieObject->offset ( ).addMSecs ( zeroTime.msecsTo ( m_pMovieObject->duration ( ) ) );
-    m_pEditEnding2->setText ( endingTime.toString  ( "hh:mm:ss.zzz" ) );
+  if ( ! bMenuLength && m_pMovieObject )  {
+    DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu  ( );
+    m_pMovieObject->setDuration ( pDVDMenu->getInterface ( )->timeDuration );
   }
+  m_pEditEnding2->setText   ( maxEndTime (  ).toString  ( "hh:mm:ss.zzz" ) );
+  m_pButtonLoop->setEnabled ( ! bMenuLength );
 
   if ( bMenuLength ) {
     // we should set the stopSlider and the duration of the MovieObject accordingly
   }
 }
 
+void DialogMovie::slotLoop ( )
+{
+  if ( m_pButtonLoop->text ( ) ==  tr ( "Loop" ) )
+       m_pButtonLoop->setText ( tr ( "Stretch" ) );
+  else if ( m_pButtonLoop->text ( ) == tr ( "Stretch" ) )
+       m_pButtonLoop->setText ( tr ( "Stop" ) );
+  else
+       m_pButtonLoop->setText ( tr ( "Loop" ) );
+}
+
+QTime DialogMovie::maxEndTime ( )
+{
+  QTime movieTime, endingTime, startTime, duration, zeroTime;
+  // Only used with MovieObject
+  if ( ! m_pMovieObject )
+    return endingTime;
+
+  DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu  ( );
+  movieTime = zeroTime.addMSecs ( m_iMovieLength );
+  startTime = QTime::fromString ( m_pEditStarting2->text ( ) );
+  duration  = m_pMovieObject->duration ( );
+  if ( ! pDVDMenu )
+    return movieTime;
+
+  // if the duration of the movie exceeds the length of the DVDMenu, we'll have to cut back.
+  if ( ( m_pCheckSameAsMenuLength->isChecked ( ) ) ||
+       ( duration > pDVDMenu->getInterface ( )->timeDuration ) )
+         duration = pDVDMenu->getInterface ( )->timeDuration;
+
+  endingTime = m_pMovieObject->offset    ( ).addMSecs ( zeroTime.msecsTo ( duration ) );
+  endingTime = endingTime.addMSecs ( zeroTime.msecsTo ( startTime ) );
+  // Now that we have the theoretical end time let us check if the movieLength is long enough
+  if ( endingTime > movieTime )
+       endingTime = movieTime;
+
+  return endingTime;
+}
+
+QTime DialogMovie::duration ( )
+{
+  QTime duration, startTime, endTime;
+  if ( ! m_pMovieObject )
+    return duration;
+
+  startTime = QTime::fromString ( m_pEditStarting2->text ( ) );
+  endTime   = QTime::fromString ( m_pEditEnding2->text   ( ) );
+  duration  = duration.addMSecs ( startTime.msecsTo  ( endTime ) );
+  return duration;
+}
+
+void DialogMovie::slotCheckStart ( )
+{
+  // This function is only called after m_pEditStarting2 lost focus
+  if ( ! m_pMovieObject )
+    return;
+
+  bool bEnable = false;
+  DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu  ( );
+  if ( m_pCheckSameAsMenuLength->isChecked ( ) )  {
+    QTime zeroTime;
+    QTime startTime = QTime::fromString    ( m_pEditStarting2->text ( ) );
+    QTime endTime = pDVDMenu->getInterface ( )->timeDuration;
+    QTime maxTime = maxEndTime ( );
+    if  ( endTime > maxTime )
+          endTime = maxTime;
+
+    endTime = endTime.addMSecs ( zeroTime.msecsTo ( startTime ) );
+    if  ( endTime > maxTime )  {
+          // Exception handling, set new end / start times based on max possible range.
+          QTime duration;
+          duration  = duration.addMSecs ( startTime.msecsTo ( endTime ) );
+          endTime   = maxTime;
+          startTime = endTime.addMSecs ( duration.msecsTo ( zeroTime ) );
+          m_pEditStarting2->setText ( startTime.toString ( "hh:mm:ss.zzz" ) );
+    }
+    m_pEditEnding2->setText ( endTime.toString ( "hh:mm:ss.zzz" ) );
+  }
+  else  {
+    // Here we have to ensure the start time is not > the end time.
+    QTime startTime = QTime::fromString    ( m_pEditStarting2->text ( ) );
+    QTime endTime   = QTime::fromString    ( m_pEditEnding2->text   ( ) );
+    if ( startTime > endTime )  {
+         startTime = endTime;
+      startTime = startTime.addSecs ( -1 );
+      m_pEditStarting2->setText ( startTime.toString ( "hh:mm:ss.zzz" ) );
+    }
+    if ( duration ( ) < pDVDMenu->getInterface ( )->timeDuration )
+         bEnable   =    true;
+  }
+  setStartStop ( true );
+  m_pButtonLoop->setEnabled ( bEnable );
+}
+
+void DialogMovie::slotCheckEnd ( )
+{
+  // Should only be called after m_pEditStarting2 lost focus
+  if ( ! m_pMovieObject )
+    return;
+
+  bool bEnable  = false;
+  QTime maxTime = maxEndTime ( );
+  QTime newTime = QTime::fromString ( m_pEditEnding2->text ( ) );
+  if   ( newTime.isValid ( ) )  {
+    if ( newTime > maxTime )
+         newTime = maxTime; 
+  }
+  else
+    newTime = maxTime;
+
+  if ( ! m_pCheckSameAsMenuLength->isChecked    ( ) )  {
+    DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu ( );
+    if ( duration ( ) < pDVDMenu->getInterface  ( )->timeDuration )
+         bEnable   =    true;
+  }
+
+  m_pEditEnding2->setText ( newTime.toString ( "hh:mm:ss.zzz" ) );
+  setStartStop ( false );
+  m_pButtonLoop->setEnabled ( bEnable );
+}
+
 void DialogMovie::slotSetSelectedItem ( )
 {
   // Called from the timer. Else if set directly in a callback function it won't select the right thing.
@@ -1879,7 +2036,7 @@ void DialogMovie::slotSliderReleased ( bool bStartSlider )
       QRegExp rx ( "<[^>]*>" );
       QString qsCurrentTime =  m_pLabelCurrentPos->text ( );
       qsCurrentTime.replace ( rx, "" );
-      
+
       long  iMSecOffset     = theUtils.getMsFromString ( qsCurrentTime );
       m_pMediaInterface->setScreenshot ( iMSecOffset );
     }
@@ -1894,9 +2051,26 @@ void DialogMovie::slotSliderValues (float fStart, float fEnd)
   QString qsFormat ("hh:mm:ss.zzz");
   startTime = startTime.addMSecs ( (int)(fStart * m_iMovieLength ) );
   endTime   = endTime.addMSecs   ( (int)(fEnd   * m_iMovieLength ) );
-  m_pEditAdd      ->setText ( startTime.toString ( qsFormat ) );
-  m_pEditStarting1->setText ( startTime.toString ( qsFormat ) );
-  m_pEditEnding1  ->setText ( endTime.toString   ( qsFormat ) );
+  if ( ! m_pMovieObject )
+         m_pEditAdd->setText ( startTime.toString ( qsFormat ) );
+  m_pEditStarting1 ->setText ( startTime.toString ( qsFormat ) );
+  m_pEditEnding1   ->setText ( endTime.toString   ( qsFormat ) );
+
+  if ( m_pMovieObject )  {
+    DVDMenu *pDVDMenu = m_pMovieObject->dvdMenu ( );
+//    QTime zeroTime;
+    bool bEnable = true;
+    QColor theColor = m_pEditX->paletteBackgroundColor ( ); // default background color
+    if ( duration ( ) > pDVDMenu->getInterface ( )->timeDuration )  {
+      theColor = QColor ( 255, 150, 150 );
+      bEnable  = false;
+    }
+    m_pCheckSameAsMenuLength->setEnabled ( true );
+    m_pCheckSameAsMenuLength->setChecked ( ! bEnable );
+    m_pButtonLoop->setEnabled ( bEnable );
+    m_pEditEnding2->setPaletteBackgroundColor ( theColor );
+    m_pEditEnding2->setEnabled ( bEnable );
+  }
 
   // For now we disable auto transcoding of only the start slider is moved ...
   //	if ( ( fStart > 0.0001 ) || ( fEnd < 0.9999) )	{
@@ -1974,38 +2148,42 @@ void DialogMovie::accept ()
 	QTime     startingTime, endingTime, duration, zeroTime;
 
 	if ( m_pDVDMenu )  {
+	  CDVDMenuInterface *pInterface = m_pDVDMenu->getInterface   ( );
+	  startingTime = QTime::fromString ( m_pEditStarting1->text  ( ) );
 	  int iSubMenu = m_pSpinBoxTitle->value ( );
 	  if ( ( ( iSubMenu == 0 ) ) && // Check that the selected SubMenuNumber is valid.
-	       ( m_pDVDMenu->getInterface ( )->qsMenuName != VMGM_LABEL ) ) {
+	       ( pInterface->qsMenuName != VMGM_LABEL ) ) {
 	    if ( MessageBox::warning ( this, tr ( "Invalid SubMenu number" ), tr ( "Invalid SubMenu number\nDo you want to assign the menu to SubMenu number 1 instead ?" ), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::Yes )
 	      iSubMenu =  1;
 	    else
 	      iSubMenu = -1;
 	  }
-	  
-	  CDVDMenuInterface *pInterface = m_pDVDMenu->getInterface   ( );
-	  startingTime = QTime::fromString ( m_pEditStarting1->text  ( ) );
-	  endingTime   = QTime::fromString ( m_pEditEnding1->text    ( ) );
+
+	  endingTime   = QTime::fromString ( m_pEditEnding1->text ( ) );
 	  if ( m_pSpinBoxPause->value ( ) == -1 )
 	    pInterface->qsPause = "inf";
 	  else 
 	    pInterface->qsPause = QString ("%1").arg ( m_pSpinBoxPause->value  ( ) );
-         
-	  if ( m_pDVDMenu->getInterface ( )->qsMovieFileName.isEmpty ( ) )
+	  if ( ! m_pComboPreCommand->currentText ( ).isEmpty  ( ) )
+	    pInterface->qsPre   = m_pComboPreCommand->currentText  ( );
+	  if ( ! m_pComboPostCommand->currentText ( ).isEmpty ( ) )
+	    pInterface->qsPost  = m_pComboPostCommand->currentText ( );
+
+	  if ( pInterface->qsMovieFileName.isEmpty ( ) )
 		startingTime = QTime ( );
 	  // Here we hande the start/stop time.
-	  if ( startingTime.isValid ( ) )	{
+	  if ( startingTime.isValid ( ) )       {
 	    pInterface->timeOffset = startingTime;
-	    if (endingTime.isValid  ( ) )	{
-	      int iMSecs = startingTime.msecsTo  ( endingTime );
-	      duration   = duration.addMSecs     ( iMSecs     );
+	    if ( endingTime.isValid  ( ) )       {
+	      int iMSecs = startingTime.msecsTo ( endingTime );
+	      duration   = duration.addMSecs    ( iMSecs     );
 	      pInterface->timeDuration = duration;
 	    }
 	  }
 	  if ( pInterface->bIsSubMenu )  {
 	       pInterface->iMenu     = iSubMenu;
 	       pInterface->iTitleset = m_pSpinBoxTitleset->value ( );
-	  }		
+	  }
 	}
 	else if ( m_pMovieObject )	{
 		// Here we handle MovieObjects. Check out if we have set Color Keying.
@@ -2013,7 +2191,6 @@ void DialogMovie::accept ()
 		ListViewColorItem *pItem;
 		float  fDelta;
 		Rgba   theColor;
-
 		// First we should remove all entries in the color Key
 		ImageManipulator *pMan= &m_pMovieObject->manipulator();
 		for (t=0;t<pMan->listColorKeys.count();t++)
@@ -2103,6 +2280,6 @@ void DialogMovie::accept ()
 		m_sourceFileInfo.pTranscodeInterface->iEndingAt     = 0;
 	}
 
-	QDialog::accept ();
+	QDialog::accept ( );
 }
 
