@@ -1,5 +1,11 @@
+
 /****************************************************************************
-** menu.h file.
+** execute.cpp file.
+**
+**   Created : 
+**        by : Varol Okan 
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This file handles the user input to generate a DVD menu.
 ** Please note that this is work in progress and depends also on the
@@ -7,11 +13,11 @@
 ** Future versions of dvdauthor might need changes to this file.
 **
 *****************************************************************************/
-
-#include <unistd.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <stdlib.h>
+#ifdef QDVD_LINUX 
+#include <unistd.h>
+#endif
 
 #include "execute.h"
 #include "global.h"
@@ -33,11 +39,10 @@
 #include <qsplitter.h>
 #include <qfiledialog.h>
 
-
-// Add another button, to keep the GUI open, rather then close it.
-// Add another text line with the command executed on the top
-// Add text, close ins x seconds ...
-
+#include "win32.h"
+#include "utils.h"
+#include "messagebox.h"
+#include "errormessages.h"
 
 Execute::Execute ( QObject * parent, const char * name)
 	: QProcess (parent, name)
@@ -175,7 +180,7 @@ int Execute::startCommand ()
 		file.close();
 	}
 	// And here we grant read/write/execute permission.
-	chmod ((const char *)QString(Global::qsTempPath + QString("/execute.sh")), S_IEXEC | S_IRUSR | S_IWRITE);
+	chmod ((const char *)QString(Global::qsTempPath + QString("/execute.sh")), S_IEXEC | S_IRUSR | S_IWRITE | S_IROTH | S_IXOTH | S_IWOTH );
 	// Increase the command counter ...
 	m_iCurrentCommand ++;
 	// Set the script to execute ...
@@ -285,6 +290,11 @@ MyDialog::MyDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
 	QSpacerItem* spacer = new QSpacerItem( 310, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	layout2->addItem( spacer );
 
+	buttonAnalyze = new QPushButton( this, "buttonAnalyze" );
+	buttonAnalyze->setAutoDefault  ( true  );
+	//buttonAnalyze->setEnabled      ( false );
+	layout2->addWidget             ( buttonAnalyze );
+
 	buttonExport = new QPushButton( this, "buttonExport" );
 	buttonExport->setAutoDefault( TRUE );
 	layout2->addWidget( buttonExport );
@@ -336,11 +346,12 @@ MyDialog::MyDialog( QWidget* parent, const char* name, bool modal, WFlags fl )
 	clearWState( WState_Polished );
 
 	// signals and slots connections
-	connect( buttonExport, SIGNAL( clicked() ),     this, SLOT( slotExport() ) );
-	connect( buttonPlay,   SIGNAL( clicked() ),     this, SLOT( slotPlay() ) );
-	connect( buttonOk,     SIGNAL( clicked() ),     this, SLOT( accept() ) );
-	connect( buttonCancel, SIGNAL( clicked() ),     this, SLOT( reject() ) );
-	connect( checkKeepOpen,SIGNAL( toggled(bool) ), this, SLOT( slotKeepOpen(bool) ) );
+	connect( buttonAnalyze, SIGNAL( clicked ( ) ),     this, SLOT( slotAnalyze ( ) ) );
+	connect( buttonExport,  SIGNAL( clicked ( ) ),     this, SLOT( slotExport  ( ) ) );
+	connect( buttonPlay,    SIGNAL( clicked ( ) ),     this, SLOT( slotPlay    ( ) ) );
+	connect( buttonOk,      SIGNAL( clicked ( ) ),     this, SLOT( accept      ( ) ) );
+	connect( buttonCancel,  SIGNAL( clicked ( ) ),     this, SLOT( reject      ( ) ) );
+	connect( checkKeepOpen, SIGNAL( toggled ( bool ) ),this, SLOT( slotKeepOpen( bool ) ) );
 
 	char *pCheckClosed = getenv ( "QDVD_KEEPDLGOPEN" );
 	if (  pCheckClosed )
@@ -381,6 +392,8 @@ void MyDialog::languageChange()
 	buttonHelp->setText( tr( "&Help" ) );
 	buttonHelp->setAccel( QKeySequence( tr( "F1" ) ) );
 	checkKeepOpen->setText( tr( "Keep Open" ) );
+	buttonAnalyze->setText( tr( "&Analyze log" ) );
+	buttonAnalyze->setAccel( QKeySequence( QString::null ) );
 	buttonExport->setText( tr( "&Export" ) );
 	buttonExport->setAccel( QKeySequence( QString::null ) );
 	buttonPlay->setText( tr( "&Play" ) );
@@ -406,34 +419,78 @@ void MyDialog::slotTimerDone ()
 	editCloseText->setText (tr ("Status : Close dialog in %1 seconds.").arg (m_iSeconds - iCounter + 1));
 }
 
+void MyDialog::slotAnalyze ( )
+{
+  // this function will scan through the output and report 
+  // the most common error messages.
+
+  ErrorMessages errors;
+  int t, iErrorCounter = 0;
+  QSize dialogSize ( 700, 500 );
+  QString qsHTML, qsCaption;
+  QString qsOutputText = textOutput->text( );
+
+  qsHTML  = "<TABLE WIDTH=\"100%\" ><TR><TD BGCOLOR=\"#9A3CFF\"><FONT SIZE=+2><B><CENTER>"; 
+  qsHTML += tr ( "Please note this dialog only displays <B>KNOWN</B> errors.<P>" );
+  qsHTML += "</CENTER></B></FONT>";
+  qsHTML += tr ( "If the DVD still fails to build consider sending the file created through " );
+  qsHTML += tr ( "[<FONT COLOR=WHITE>Tools -> feedback</FONT>] to the author of QDVDAuthor." );
+  qsHTML += "</TD></TR></TABLE><HR>";
+  for ( t=0; t<errors.count ( );t++ ) {
+    if ( qsOutputText.find ( errors.errorString ( t ) ) > -1 ) {
+      iErrorCounter ++;
+      qsHTML += errors.helpMessage ( t );
+    }
+  }
+
+  if ( iErrorCounter == 0 ) {
+    qsHTML = tr ( "<P><FONT COLOR=DARKGREEN>Did not find any known error.</FONT><P>" );
+    qsCaption = tr ( "No errors found." );
+  }
+  else if ( iErrorCounter == 1 )
+    qsCaption = tr ( "Found 1 error" );
+  else
+    qsCaption = tr ( "Found %1 errors" ).arg ( iErrorCounter );
+  MessageBox::html ( NULL, qsCaption, qsHTML, dialogSize  );
+
+}
+
 void MyDialog::processingFinished (int iSeconds)
 {
-	// We're done, timer stuff now ok
-	m_bDoneProcessing = true;
-	QString qsStorage = Global::qsTempPath + QString ("/") + Global::qsProjectName + QString ("/output.txt");
-	saveOutput (qsStorage);
-	// Start the timer if the checkbox is clear
-	if (!checkKeepOpen->isChecked())        {
-		startTimer(iSeconds);
-	}
-	// First we check if qplayer is there and executable ...
-	QFileInfo fileInfo (Global::qsExternalPlayer);
-	if (!fileInfo.exists())
-		return;
-	// next we check if it is executable ...
-	if (!fileInfo.isExecutable())
-		return;
-	// last we check if there has been something clreated to play at all ...
-	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.BUP"));
-	if (!fileInfo.exists())
-		return;
-	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.IFO"));
-	if (!fileInfo.exists())
-		return;
-	fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.VOB"));
-	if (!fileInfo.exists())
-		return;
-	buttonPlay->setEnabled(true);
+  buttonAnalyze->setEnabled ( true );
+  // We're done, timer stuff now ok
+  m_bDoneProcessing = true;
+  QString qsStorage = Global::qsTempPath + QString ("/") + Global::qsProjectName + QString ("/output.txt");
+  saveOutput (qsStorage);
+  // Start the timer if the checkbox is clear
+  if (!checkKeepOpen->isChecked())        {
+    startTimer(iSeconds);
+  }
+  // First we check if qplayer is there and executable ...
+  QString qsPlayer = Global::qsExternalPlayer;
+  QFileInfo fileInfo    ( qsPlayer );
+  
+  if ( !fileInfo.exists ( ) ) {
+    Utils theUtils;
+    qsPlayer = theUtils.checkForExe( qsPlayer );
+    if ( qsPlayer.isEmpty ( ) )
+      return;
+    fileInfo.setFile ( qsPlayer );
+  }
+  // next we check if it is executable ...
+  if (!fileInfo.isExecutable())
+    return;
+  // last we check if there has been something clreated to play at all ...
+  fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.BUP"));
+  if (!fileInfo.exists())
+    return;
+  fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.IFO"));
+  if (!fileInfo.exists())
+    return;
+  fileInfo.setFile(Global::qsProjectPath + QString ("/VIDEO_TS/VIDEO_TS.VOB"));
+  if (!fileInfo.exists())
+    return;
+  buttonPlay->setEnabled(true);
 }
 
 // The next three are related to the Keep Open countdown
@@ -473,8 +530,20 @@ void MyDialog::slotKeepOpen (bool bKeepOpen)
 
 void MyDialog::slotPlay ()
 {
-	if ( system (QString ("%1 dvd:/%2/VIDEO_TS/ &").arg(Global::qsExternalPlayer).arg(Global::qsProjectPath)) == -1 )
-		return; // error
+  QString qsCommand, qsPlayer, qsFullPath;
+  Utils theUtils;
+  QDir thePath ( Global::qsProjectPath );
+
+  qsPlayer = Global::qsExternalPlayer;
+
+  qsPlayer = theUtils.checkForExe( qsPlayer );
+  if ( qsPlayer.isEmpty ( ) )
+    qsPlayer = Global::qsExternalPlayer;
+
+  qsCommand = QString ( "%1 dvd:/%2/VIDEO_TS/ &" ).arg ( qsPlayer ).arg ( thePath.absPath ( ) );
+
+  if ( system ( qsCommand.ascii ( ) ) == -1 )
+    return; // error
 	
 }
 
@@ -499,130 +568,3 @@ void MyDialog::saveOutput (QString qsFileName)
 	}
 }
 
-/*
-this implementation was complicated, and used a script anyhow and would not handle E.g.:
-cd ../configurator; make. The make command would be executed in the current path not under ../configurator.
-int Execute::system( QString &commandString, QStringList *pListEnv)
-{
-	// Should work just as the system () call. 
-	// The only difference is that this call is non blocking ...
-	// NOTE : commandString could hold multiple commands.
-	if (m_pDialog)
-		delete m_pDialog;
-	m_pDialog = new MyDialog ();
-	m_pDialog->show();
-	connect( this, SIGNAL(readyReadStderr()), this, SLOT(slotReadFromStderr()) );
-	connect( this, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( this, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
-	m_pDialog->editCommandText->setText (QString ("cmd> ") + commandString);
-	// Okay first we get the number of commands in this string.
-	m_commandList = QStringList::split(";", commandString);
-	m_iCurrentCommand = 0;
-	if (pListEnv)
-		m_listEnvironment = *pListEnv;
-	
-	// Here we generate a simple shell script to execute the commands under the shell. 
-	// QProcess is currently not flexible enough.
-	QFile file("/tmp/execute.sh");
-	if ( file.open( IO_WriteOnly ) ) {
-		QTextStream stream( &file );
-stream << "#!/bin/bash\n\n" << "$*\n" << "echo $* > /tmp/" << getlogin() << "_out.txt";
-		file.close();
-	}
-	chmod ("/tmp/execute.sh", S_IEXEC | S_IRUSR | S_IWRITE);
-	// slotProcessExited handles the the command list.
-	slotProcessExited ();
-	// return to the calling process (thread)
-	return 0;
-}
-void Execute::slotProcessExited ()
-{
-	if (m_pDialog)	{
-		slotReadFromStdout();
-		slotReadFromStderr();
-	}
-	else
-		printf ("<%s><%s>\n", (const char *)readStdout(), (const char *)readStderr());
-	
-	m_bHasFinished = false;
-	// Get the current command to be executed, and split the single commands into their arguments.
-	clearArguments ();
-	if (m_iCurrentCommand < (int) m_commandList.count ())	{
-		addArgument (QString ("/tmp/execute.sh"));
-		QStringList argumentList = QStringList::split(" ", m_commandList[m_iCurrentCommand++]);
-		// Here we add all arguments ...
-		for (uint i=0;i<argumentList.count();i++)
-			addArgument (argumentList[i]);
-		// and here we execute the sub-command.
-		start (&m_listEnvironment);
-	}
-	else	{ // and here we start the timer to close the GUI after set amount of seconds.
-               m_pDialog->processingFinished (m_iSeconds);
-		m_bHasFinished = true;
-	}
-}
-*/
-
-
-
-/*
-the following implementation would block the whole process until the execution was terminated.
-void Execute::slotProcessExited ()
-{
-	if (m_pDialog)	{
-		slotReadFromStdout();
-		slotReadFromStderr();
-	}
-	else
-		printf ("<%s><%s>\n", (const char *)readStdout(), (const char *)readStderr());
-	// and here we start the timer to close the GUI after set amount of seconds.
-       m_pDialog->processingFinished (m_iSeconds);
-}
-int Execute::system( QString &commandString, QStringList *listEnv)
-{
-	int iReturn=0;
-	// Should work just as the system () call. After calling this function,
-	// it will only return, when the process has terminated.
-	// NOTE : commandString could hold multiple commands.
-	if (m_pDialog)
-		delete m_pDialog;
-
-	m_pDialog = new MyDialog ();
-	m_pDialog->show();
-	connect( this, SIGNAL(readyReadStderr()), this, SLOT(slotReadFromStderr()) );
-	connect( this, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( this, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
-	m_pDialog->editCommandText->setText (QString ("cmd> ") + commandString);
-	// Okay first we get the number of commands in this string.
-	QStringList commandList = QStringList::split(";", commandString);
-	for (uint t=0;t<commandList.count();t++)	{
-		// And here we split the single commands into their arguments.
-		clearArguments ();
-		QStringList argumentList = QStringList::split(" ", commandList[t]);
-		// Here we add all arguments ...
-		for (uint i=0;i<argumentList.count();i++)
-			addArgument (argumentList[i]);
-		// and here we execute the sub-command.
-		iReturn = execute (listEnv);
-		if (iReturn < 0)
-			return iReturn;
-	}
-	return iReturn;
-}
-
-	
-int Execute::execute (QStringList *listEnv)
-{
-	m_pDialog->stopTimer ();
-	uint iWaitedAlready = 0;
-	// This call is internal only. All arguments have already been set.
-	// Here we start the action.
-	start (listEnv);
-	int iTest;
-	while (isRunning () && (m_iMaxWait > iWaitedAlready) )	{
-		sleep (1);
-		iWaitedAlready ++;
-	}
-	return exitStatus ();
-}
-*/
