@@ -68,11 +68,11 @@ void DVDAuthor::cleanSourceFileEntris ()
     delete m_listNewEntries[t];
   }
   m_listNewEntries.clear ();
-  
+
   for ( t=0; t<m_listPlayMultiple.count ( ); t++ )
     delete m_listPlayMultiple[t];
   m_listPlayMultiple.clear ( );
-}  
+}
 
 /**
  * export will open a QFileDialog for selecting the dvdauthor xml file and will export
@@ -82,7 +82,7 @@ void DVDAuthor::cleanSourceFileEntris ()
 bool DVDAuthor::exportXml ()
 {
   QString qsFileName = QFileDialog::getSaveFileName (Global::qsCurrentPath, QObject::tr ("Xml files (*.xml *.XML)"));
-  
+
   return createXml ( qsFileName );
 }
 
@@ -150,7 +150,7 @@ bool DVDAuthor::createXml ( QString &qsFileName )
     return createNoMenuDVD ( qsFileName );
 
   m_listOfAllMenus.prepend ( m_pDVDAuthor->getVMGMenu ( ) );
-  
+
   populateListOfTitlesets   (            ); // create m_listTitlesets from SourceFileInfos
   stowMenusAway             (            );
   createJumpTable           (            );
@@ -185,7 +185,7 @@ bool DVDAuthor::populateListOfTitlesets ()
     for ( t=0; t<listButtonMovies.count ( ); t++ )  {
       pEntry = listButtonMovies[t];
       if ( pEntry->listFileInfos.count ( ) < 1 )
-	continue;
+        continue;
 
       bFound = false;
       // At this point we have already ensured that all videos in a SourceFileEntry
@@ -221,7 +221,7 @@ bool DVDAuthor::populateListOfTitlesets ()
 
     //2)  // At this point we have all movies tucked away in m_listTitlesets ...
           // In the second step we handle the button action and generate the JumpTable entries
-	
+
     // Determine JumpTable per titleset
     // also set buttonAction
 
@@ -268,13 +268,14 @@ bool DVDAuthor::stowMenusAway ()
       pTitleset = findTitleset ( iSetByUser );
       if ( pTitleset ) {
 	// Okay we found the same titleset, now let's make sure it has the same format ...
-	if ( pTitleset->qsFormat ==  qsFormat ) {
+	if ( ( qsFormat ==  pTitleset->qsFormat ) &&
+	     ( pTitleset->listMenus.count ( ) < MAX_MENUS_PER_TITLESET ) )  {
 	  pTitleset->listMenus.append ( pMenu );
 	  bFound = true;
 	}
 	else {
 	  // Error format mismatch ...
-	  // The only remedy is to check all menus in this Titleset 
+	  // The only remedy is to check all menus in this Titleset
 	  // and check if any of these has been set by the user as well.
 	  bool bAlsoSetByUser = false;
 	  for ( t=0; t<pTitleset->listMenus.count ( ); t++ ) {
@@ -633,11 +634,11 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
  
   // main DVDAuthorXML - object
   CXmlDVDAuthor::titles_struct *pTitle;
-  CXmlDVDAuthor           xmlDvdauthor;
-  QValueList<DVDMenu *>   listDVDMenus = m_pDVDAuthor->getSubMenus();
-  CDVDMenuInterface      *pInterface   = m_pDVDAuthor->getVMGMenu ()->getInterface();
-  ExportTitleset         *pExpTitleset;
-  int                     iMaxTitlesetNumber;
+  CXmlDVDAuthor         xmlDvdauthor;
+  QValueList<DVDMenu *> listDVDMenus = m_pDVDAuthor->getSubMenus ( );
+  CDVDMenuInterface    *pInterface   = m_pDVDAuthor->getVMGMenu  ( )->getInterface ( );
+  ExportTitleset       *pExpTitleset;
+  int                   iMaxTitlesetNumber;
 
   // First we create the main menu ...
   xmlDvdauthor.m_dvdauthor.dest = Global::qsProjectPath;
@@ -657,11 +658,15 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   //	if ( g2 eq 3 ) jump titleset 3 menu entry root;
   //	jump title 1; <!-- nothig there, just start the first title // -->
   //	}</pre>
-  pPgc = pXMLMenu->addPgc ();
+  pPgc = pXMLMenu->addPgc ( );
+
   // the following line will add the actual VMGMenu
   addToMenu ( pPgc, m_pDVDAuthor->getVMGMenu ( ) );
   pPgc->entry = QString ("title");
-  qsPre  = QString (" { if ( g4 gt 0 ) button=g4; \n");
+  qsPre  = QString (" {" );
+  if ( ! pInterface->qsPre.isEmpty ( ) )
+    qsPre += pInterface->qsPre;
+  qsPre += QString ( " if ( g4 gt 0 ) button=g4; \n");
   qsPre += QString ("\t   if ( g2 gt 0 )  { \n");
   for (t=0;t<m_listTitlesets.count();t++) {
     pExpTitleset = m_listTitlesets[t];
@@ -675,8 +680,13 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   if ( m_bInsertComments )
     qsPre += QString (" <!-- nothing there, just start the first title // -->\n");
   qsPre   += QString ("\t\t}\n\t} ");
-  pPgc->pre.value  = qsPre;
-  pPgc->post.value = QString (" { g4=button; g2=0; jump vmgm menu 1; } ");
+  pPgc->pre.value     = qsPre;
+  pPgc->post.value    = QString (" { g4=button; g2=0; " );
+  if ( ! pInterface->qsPost.isEmpty ( ) )
+    pPgc->post.value += pInterface->qsPost;
+  else
+    pPgc->post.value += QString ( "jump vmgm menu 1;" );
+  pPgc->post.value   += QString ( " } ");
 
   CXmlDVDAuthor::vob_struct *pVob = NULL;
   for (t=0;t<pInterface->listIntroVobs.count ( );t++ ) {
@@ -702,13 +712,13 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
     pXMLTitleset = xmlDvdauthor.m_dvdauthor.addTitleset();
     // check if we found an empty titleset.
     if ( pExpTitleset ) {
-      
+
       addToMenu ( pXMLTitleset, pExpTitleset );
-      
+
       // Next we insert all Menus ...
       for ( i=0; i<pExpTitleset->listMenus.count ( ); i++ )
 	addToMenu( pXMLTitleset, pExpTitleset->listMenus[i] );
-      
+
       // Next we insert all SourceFileInfos ...
       for ( i=0; i<pExpTitleset->listSourceFileEntries.count ( ); i++ )
 	addToTitleset ( pXMLTitleset, pExpTitleset->listSourceFileEntries[i] );
@@ -1076,6 +1086,12 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::menus_struct *pXMLMenu, DVDMenu *pMen
   addToAudio ( pXMLMenu, pMenu );
 
   pPgc = getPgc ( pXMLMenu, pMenu );
+
+  if ( ! pInterface->qsPre.isEmpty ( ) && pPgc->pre.value.isEmpty ( ) )
+    pPgc->pre.value = pInterface->qsPre;
+  if ( ! pInterface->qsPost.isEmpty ( ) && pPgc->post.value.isEmpty ( ) )
+    pPgc->post.value = pInterface->qsPost;
+
   return addToMenu  ( pPgc, pMenu );
 }
 
@@ -1137,9 +1153,9 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
     pVob->file  = pInterface->listIntroVobs[t]->file;
     pVob->pause = QString ( "0" );
   }
-  
-  pVob = pPgc->addVob ();
-  pVob->file=QString ("%1_menu.mpg").arg(theUtils.getTempFile(pMenu->name()));
+
+  pVob = pPgc->addVob ( );
+  pVob->file=QString  ( "%1_menu.mpg" ).arg ( theUtils.getTempFile ( pMenu->name ( ) ) );
   // since version 0.0.9 we also support movieMenus, so we need to loop here
   // We are now also keeping the last button selected so that after restarting the
   // menu movie the same button is highlighted (using g4 register).
@@ -1283,9 +1299,9 @@ ExportTitleset *DVDAuthor::findTitleset ( DVDMenu *pMenu )
 	      return m_listTitlesets[t];
 	  }
 	}
-	
 	// We have to ensure that we return a titleset for this menu ...
-	qsMenuFormat=QString ("%1x%2x%3").arg(pMenuInfo->iWidth).arg(pMenuInfo->iHeight).arg(pMenu->fps());
+	qsMenuFormat = createFormatString ( pMenu );
+	//QString ("%1x%2x%3").arg(pMenuInfo->iWidth).arg(pMenuInfo->iHeight).arg(pMenu->fps());
 	pTitleset = new ExportTitleset ( this );
 	if ( pMenuInfo->iTitleset > -1 )
 	  pTitleset->iTitlesetNumber = pMenuInfo->iTitleset;
@@ -1295,7 +1311,7 @@ ExportTitleset *DVDAuthor::findTitleset ( DVDMenu *pMenu )
 	pTitleset->bSetByUser        = false;
 	pTitleset->listMenus.append ( pMenu );
 	m_listTitlesets.append  ( pTitleset );
-	
+
 	return pTitleset;
 }
 
@@ -1801,7 +1817,7 @@ bool Spumux::createTextXml ( SourceFileInfo *pInfo, Subtitles *pSubtitles )
   QFileInfo fileInfo ( pInfo->qsFileName );
   QString   fileSpumux, fileSrt, qsSubIdx;
   CXmlSpumux::textsub_struct *pTextsub = xmlSpumux.m_subpictures.stream.addTextsub ();
-  
+
   // next is to save the srt - file ...
   fileSrt = theUtil.getTempFile( fileInfo.baseName () ) + QString ("/subtitles_%1.srt").arg ( pSubtitles->m_iSubtitleNumber, 2 );
   srtFile.writeFile ( pSubtitles, fileSrt );
@@ -1872,14 +1888,25 @@ bool Spumux::createImageXml ( SourceFileInfo *pInfo, Subtitles *pSubtitles )
     qsStart.remove ( ":"      );
     qsStart.replace( ".", "_" );
 
-    pSpu->start       = pEntry->qsTimeStart;
-    pSpu->end         = pEntry->qsTimeStop;
+    pSpu->start   = pEntry->qsTimeStart;
+    pSpu->end     = pEntry->qsTimeStop;
     // disturbs when having transparency completely opaque.
-    //      pSpu->transparent = pSubtitles->subColors[0].name ();
-    //      pSpu->transparent.remove ( "#" );
+    //  pSpu->transparent = pSubtitles->subColors[0].name ( );
+    //  pSpu->transparent.remove ( "#" );
 
-    pSpu->image       = QString ("%1%2.png").arg ( thePath ).arg( qsStart );
-    pSpu->force       = "no";
+    pSpu->image   = QString ("%1%2.png").arg ( thePath ).arg( qsStart );
+    pSpu->force   = "no";
+    // Here we do some trickery .If the rect is NULL OR it is the same size as the Movie, then we do our own thingy here.
+    pSpu->xoffset = pEntry->rect.x ( );
+    pSpu->yoffset = pEntry->rect.y ( );
+    if ( ( pEntry->rect.x     ( ) == 0 ) && ( pEntry->rect.y      ( ) == 0 ) &&
+         ( pEntry->rect.width ( ) == 0 ) && ( pEntry->rect.height ( ) == 0 ) )  {
+         pSpu->yoffset = iHeight - 45;
+         pSpu->xoffset = (int)( (float)iWidth / 2.0 );
+    }
+  }
+
+/*  old version ...
     // Here we do some trickery .If the rect is NULL OR it is the same size as the Movie, then we do our own thingy here.
     if ( ( pEntry->rect.x() == 0 ) && ( pEntry->rect.y() == 0 ) ) {
       if ( ( ( pEntry->rect.width () == iWidth ) && ( pEntry->rect.height () == iHeight ) ) ||
@@ -1897,6 +1924,7 @@ bool Spumux::createImageXml ( SourceFileInfo *pInfo, Subtitles *pSubtitles )
       pSpu->yoffset   = pEntry->rect.y ();
     }
   }
+*/
   // and lastly we save the xml file.
   qsSubIdx.sprintf ( "/subtitle_%d.xml", pSubtitles->m_iSubtitleNumber );
   fileSpumux = theUtil.getTempFile( fileInfo.baseName ( TRUE ) ) + qsSubIdx;
