@@ -39,12 +39,13 @@ namespace Cache {
 		{"arecord",       "ARecord",        "Optional.\n\nALSA sound utility. There are other utilities you can use instead."}, \
 		{"movie-to-dvd",  "VideoTrans",     "Optional. Important.\n\nYou can also use MEncoder, or transcode.\nThis utility uses MPlayer to convert movies into the correct format (See also man pages).\nhttp://videotrans.sf.net"}, \
 		{"transcode",     "Transcode",      "Optional. Important.\n\nYou can also use MEncoder.\nThis utility converts movies into the correct format (See also man pages).\nhttp://www.transcoding.org"}, \
+		{"mencoder",      "MEncoder",       "Optional.\n\nThis utility is part of the mplayer utilities. It can be used to convert  video into DVD confoming mpeg2.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nhttp://www.mplayerhq.hu"}, \
+		{"ffmpeg",        "FFMpeg",         "Optional.\n\nThis utility is part of the mplayer utilities. It can be used to convert  video into DVD confoming mpeg2.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nhttp://ffmpeg.mplayerhq.hu"}, \
 		{"png2yuv",       "PNG To YUV",     "Optional. Important.\n\nThis utility is used to create the mpeg2 video stream for Movie Menus.\nNote: without this tool you can not create MovieMenus.\nhttp://netpbm.sf.net"}, \
 		{"oggdec",        "Ogg Dec",        "Optional.\n\nThis utility will help to convert OGG audio files into a DVD conform format.\nThis will be implemented in the next release of 'Q' DVD-Author.\nogg to mp2 > oggdec test.ogg -o - | mp2enc -o test2.mp2"}, \
 		{"mp2enc",        "mp2 Enc",        "Optional !\n\nYou can also use toolame instead.\nThis utility converts a audio file into DVD conforming mp2 format."}, \
 		{"lame",          "Lame",           "Optional.\n\nNot used in the standard settings ... So why is this tool here ?\nmp3 to mp2 > lame --decode blues.mp3 - | mp2enc -o blues.mp2"}, \
-		{"mplayer",       "MPlayer",        "Optional.\n\nThis program / utility can be used to replace the xine engine.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nmp3 to mp2 > mplayer mymusicfile.mp3 -vo null -ao pcm -aofile menu_audio.pcm ; mp2enc -r 48000 -o menu_audio.mpa < menu_audio.pcm\nhttp://www.mplayerhq.de"}, \
-		{"mencoder",      "MEncoder",       "Optional.\n\nThis utility is part of the mplayer utilities. It can be used to convert  video into DVD confoming mpeg2.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nhttp://www.mplayerhq.de"}, \
+		{"mplayer",       "MPlayer",        "Optional.\n\nThis program / utility can be used to replace the xine engine.\nThis will be implemented in one of the next versions of 'Q' DVD-Author.\nmp3 to mp2 > mplayer mymusicfile.mp3 -vo null -ao pcm -aofile menu_audio.pcm ; mp2enc -r 48000 -o menu_audio.mpa < menu_audio.pcm\nhttp://www.mplayerhq.hu"}, \
 		{"jpegtopnm",     "JPG To PNM",     "Optional.\n\nYou can also use jpeg2yuv instead.\nThis utility is used to convert a background image into a mpeg2 movie."}, \
 		{"ppmtoy4m",      "PPM To Y4M",     "Optional.\n\nYou can also use mpeg2enc instead.\nThis utility i sused to convert a background image into a mpeg2 movie."}, \
 		{"mpeg2enc",      "MPEG2 Enc",      "Mandatory.\n\nThis utility is used to convert a background image into a mpeg2 movie.\nhttp://mjpeg.sf.net"}, \
@@ -61,7 +62,8 @@ namespace Cache {
 		{"dvd+rw-format", "DVD+RW Format",  "Optional.\n\nThis utility is used to burn the video DVD onto a RW+DVD."}, \
 		{"mkisofs",       "Make ISO FS",    "Optional.\n\nThis utility is used to create a iso image of the final DVD (on the harddrive) to be burned with your favourite burning program."}, \
 		{"dvdisaster",    "DVDisaster",     "Optional.\n\nThis utility can add ECC information to a DVD-iso.\nYou can find it at : http://www.dvdisaster.net"}, \
-		{"dvdrecord",     "DVD Record",     "Optional.\n\nRecords the final DVD structure onto the DVD media."}
+		{"dvdrecord",     "DVD Record",     "Optional.\n\nRecords the final DVD structure onto the DVD media.\nYou can find it at : http://www.arklinux.org/projects/dvdrtools"}, \
+		{"wodim",         "Wodim",          "Optional.\n\nRecords the final DVD structure onto the DVD media.\nYou can find it at : http://www.cdrkit.org"}
 
 #define STRING_SEPARATOR "+-+"
 
@@ -107,7 +109,7 @@ namespace Cache {
 // Note: the third color ill be interpolated between BG and FG color.
 //       the fourth color if transparent
 //#define START_SUBTITLEFG_COLOR   233, 240, 24
-#define START_SUBTITLEFG_COLOR   200, 200,  0
+#define START_SUBTITLEFG_COLOR   255, 200,  0
 #define START_SUBTITLEBG_COLOR     0,   0,  0
 
 // This color is applied to the background, thus it can be different unless the user 
@@ -144,6 +146,7 @@ public:
 	static QString qsProjectFileName;
 	static QString qsProjectName;
 	static QString qsTempPath;
+	static QString qsSystemPath;
 	static QString qsProjectPath;
 	static QString qsCurrentPath;
 	static QString qsExternalPlayer;
