@@ -22,16 +22,16 @@ Keyword::Keyword ()
     "+FORMAT+", "+MENU_NAME+", "+ASPECT+", "+START_POS+", "+DURATION+", "+NR_OF_FRAMES+", "+BACKGROUND_FILE_NAME+", 
     "+BACKGROUND_FULL_NAME+", "+SOUND_LIST+" };
 
-  char arrayTranscodeKeys[22][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_NAME+", "+BASE_NAME+",
-    "+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+", 
-    "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+", "+AUDIO_LIST+",
-    "+FOREACH_COUNTER+", "+TRACK_NAME+" };
+  char arrayTranscodeKeys[23][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_NAME+", "+BASE_NAME+",
+    "+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+",
+    "+DURATION+", "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+",
+    "+AUDIO_LIST+", "+FOREACH_COUNTER+", "+TRACK_NAME+" };
 
   char arraySubtitlesKeys[8][35] = {"+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_FILE_NAME+", "+XML_FILE_NAME+", "+BASE_NAME+", "+BASE_EXTENSION+", "+SUBTITLE_NUMBER+", "+MULTIPLE_SUBTITLE_PIPE+" };
-  
+
   // init the key lists
   Entry *pEntry = NULL;
-  
+
   for (t=0;t<KeyLast;t++) {
     pEntry = new Entry ();
     pEntry->qsKey = arrayKeys [ t ];
@@ -122,7 +122,7 @@ QStringList Keyword::getValues ( int iWhichKeyset )
   int t;
   if ( ( iWhichKeyset < 0 ) || ( iWhichKeyset >= BaseLast ) )
     return listOfValues;
-  
+
   for (t=0;t<count ( iWhichKeyset ); t++)
     listOfValues.append ( value ( iWhichKeyset, t ) );
 
@@ -155,11 +155,11 @@ void Keyword::setKeywords ( int iWhichKeys, QValueList<QString> listKeywords )
 
 QString Keyword::resolvString ( int iWhichKeyset, QString qsInput)
 {
-  // This function resolves the variables in the stored commands / commenst / names like
+  // This function resolves the variables in the stored commands / comments / names like
   // +MENU_NAME+, +WIDTH+, +BACKGROUND_FILE_NAME+ etc.
   QString qsOutput = qsInput;
   uint t;
-  
+
   for (t=0;t<m_listOfPair[iWhichKeyset].count();t++)	{
     // Here we replace the actual keyword with the real string.
     if ( (m_listOfPair[iWhichKeyset][t]->qsValue.isNull()) || (m_listOfPair[iWhichKeyset][t]->qsValue.isEmpty()) )
@@ -183,14 +183,14 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
 {
 //	char arrayTranscodeKeys[19][35] = {"+DVDAUTHOR_XML+", "+PROJECT_PATH+", "+TEMP_PATH+", "+INPUT_NAME+", "+BASE_NAME+",
 //		"+FILE_EXT+", "+AUDIO_FORMAT+", "+AUDIO_TYPE+", "+AUDIO_BITRATE+", "+SAMPLE_RATE+", "+STARTING_AT+", "+ENDING_AT+",
-//		"+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+", 
+//		"+DURATION+", "+WIDTH+", "+HEIGHT+", "+VIDEO_FORMAT+", "+VIDEO_TYPE+", "+VIDEO_BITRATE+", "+FRAME_RATE+", "+RATIO+",
 //		};
   QString qsRatio, qsValue, qsKey, qsOutput = qsInput;
   QString qsAudioBitrate, qsVideoBitrate;
   uint t;
-  long iAudioBitrate, iVideoBitrate, iStartingAt, iEndingAt;
+  long iAudioBitrate, iVideoBitrate, iStartingAt, iEndingAt, iDuration;
   // Next we adjust it for the conversion tool.
-  
+
   // These here are used for all conversion tools.
   qsAudioBitrate = value ( TransKeys, TransAudioBitrate );
   iAudioBitrate = qsAudioBitrate.toLong ( );
@@ -206,27 +206,33 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
   iStartingAt = qsValue.toLong ( );
   qsValue     = value ( TransKeys, TransEndingAt );
   iEndingAt   = qsValue.toLong ( );
+  qsValue     = value ( TransKeys, TransDuration );
+  iDuration   = qsValue.toLong ( );
   if ( iEndingAt < 20 )
-       iEndingAt = 1000000000; // approx. 9.3 hours
+       iEndingAt = 1000000000; // 1 Million Seconds approx. 9.3 hours
+  if ( iDuration < 20 )
+       iDuration = 1000000000; // 1 Million Seconds approx. 9.3 hours
   if ( iStartingAt > iEndingAt )
        iStartingAt = 0;
-  iEndingAt   = (long)( iEndingAt   / 1000.0 ); // convert from msec to seconds
   iStartingAt = (long)( iStartingAt / 1000.0 ); // convert form msec to seconds
+  iEndingAt   = (long)( iEndingAt   / 1000.0 ); // convert from msec to seconds
+  iDuration   = (long)( iDuration   / 1000.0 ); // convert form msec to seconds
   setValue ( TransKeys, TransStartingAt, QString ( "%1" ).arg ( iStartingAt ) );
   setValue ( TransKeys, TransEndingAt,   QString ( "%1" ).arg ( iEndingAt   ) );
+  setValue ( TransKeys, TransDuration,   QString ( "%1" ).arg ( iDuration   ) );
 
   qsValue = value ( TransKeys, TransAudioType );
   // default it to mp2 and only allow ac3, and pcm
   qsValue = qsValue.lower ( );
-  if ( ( qsValue != "ac3" ) && ( qsValue != "pcm" ) )
-         qsValue  = "mp2";
+  if ( ( qsValue != "mp2" ) && ( qsValue != "pcm" ) )
+         qsValue  = "ac3";
   setValue ( TransKeys, TransAudioType, qsValue );
 
   qsVideoBitrate = value ( TransKeys, TransVideoBitrate );
   iVideoBitrate = qsVideoBitrate.toInt ( );
   if ( iVideoBitrate > 10000 )
        iVideoBitrate = (int)((float)iVideoBitrate / 1000.0 );
-  if ( iVideoBitrate < 1856)	// according to DVD spec this is the minimum.
+  if ( iVideoBitrate < 1856 )	// according to DVD spec this is the minimum.
        iVideoBitrate = 1856;	// Note: How to handle no audio (0) ?
   setValue ( TransKeys, TransVideoBitrate, QString ("%1").arg( iVideoBitrate ) );
 
@@ -250,9 +256,9 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
     int iSampleRate      = qsSampleRate.toInt ( &bOkay );
 
     if ( bOkay && ( iSampleRate < 10000 ) )
-      iSampleRate *= 1000;
+      iSampleRate *=    1000;
     if ( iSampleRate < 10000 )
-      qsSampleRate = "48000"; // default sample rate.
+      qsSampleRate =  "48000"; // default sample rate.
     else 
       qsSampleRate = QString ( "%1" ).arg ( iSampleRate );
     setValue ( TransKeys, TransSampleRate, qsSampleRate );
@@ -283,12 +289,40 @@ QString Keyword::resolvConvert (QString qsInput, QString qsConversionTool)
       qsFrameRate = "25";
     setValue ( TransKeys, TransFrameRate, qsFrameRate );
   }
+  else if (qsConversionTool.find ( SUB_BLOCK_FFMPEG ) > -1 )	{
+    bool bOkay;
+    QString qsSampleRate = value ( TransKeys, TransSampleRate );
+    int iSampleRate      = qsSampleRate.toInt ( &bOkay );
+
+    if ( bOkay && ( iSampleRate < 10000 ) )
+      iSampleRate *=    1000;
+    if ( iSampleRate < 10000 )
+      qsSampleRate =  "48000"; // default sample rate.
+    else
+      qsSampleRate = QString ( "%1" ).arg ( iSampleRate );
+    setValue ( TransKeys, TransSampleRate, qsSampleRate );
+
+    qsAudioBitrate = value ( TransKeys, TransAudioBitrate );
+    iAudioBitrate = qsAudioBitrate.toInt ( &bOkay );
+    if ( iAudioBitrate < 224000 )
+         iAudioBitrate *=  1000;
+    if ( iAudioBitrate < 224000 )
+         iAudioBitrate = 224000;  // for ac3 minimum = 224kbps to 448kbps
+    setValue ( TransKeys, TransAudioBitrate, QString ("%1").arg( iAudioBitrate ) );
+    qsVideoBitrate = value ( TransKeys, TransVideoBitrate );
+    iVideoBitrate  = qsVideoBitrate.toInt ( &bOkay );
+    if ( iVideoBitrate < 1856000 ) // according to DVD spec this is the minimum.
+         iVideoBitrate *=   1000;
+    if ( iVideoBitrate < 1856000 )
+         iVideoBitrate = 1856000;  // Minimum video Bitrate = 2800kbps
+    setValue ( TransKeys, TransVideoBitrate, QString ("%1").arg( iVideoBitrate ) );
+  }
   else if (qsConversionTool.find ( SUB_BLOCK_VIDEOTRANS ) > -1 )	{
     qsRatio = value ( TransKeys, TransRatio ); // only 4:3 and 16:9 are valid
     if ( ( qsRatio != QString ("4:3") ) && ( qsRatio != QString ("16:9") ) )
       setValue ( TransKeys, TransRatio, QString ( "4:3" ) );
   }
-  
+
   for (t=0;t<m_listOfPair[TransKeys].count();t++)	{
     qsValue = value ( TransKeys, t );
     qsKey   = key   ( TransKeys, t );
@@ -306,9 +340,9 @@ void Keyword::printf ( int iWhichKeyset )
   Entry *pEntry;
   if ( iWhichKeyset >= BaseLast )
     iWhichKeyset = Keys;
-  
+
   for (t=0;t<(int)m_listOfPair[iWhichKeyset].count();t++) {
     pEntry = m_listOfPair[iWhichKeyset][t];
     ::printf ("%d > index=<%d> : Key=<%s> value=<%s>\n", t, pEntry->iIndex, pEntry->qsKey.ascii(), pEntry->qsValue.ascii() );
-  }  
+  }
 }
