@@ -1,8 +1,10 @@
 /****************************************************************************
 ** MenuObject
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **  This is the base class for all that is to appear onto the MenuPreview.
 ** Exception are background image, and the button masks (if the user
@@ -15,7 +17,7 @@
 ** FrameObject, and ButtonObject.
 **
 ** The ButtonObject in turn is a container class which can hold a
-** *TextObject, ImageObject, MovieObject, AND a FrameObject.
+** TextObject, ImageObject, MovieObject, AND a FrameObject.
 ** Please refer to the buttonobject.h - file for more detail on the
 ** ButtonObject.
 **
@@ -26,13 +28,14 @@
 
 #include <qwidget.h>
 
+#include "rgba.h"
 #include "modifiers.h"
 #include "animationattribute.h"
 
 class QDomNode;
 class QPopupMenu;
 class QDomElement;
-class QListViewItem;
+class StructureItem;
 
 #define HANDLE_WIDTH  9
 #define HANDLE_HEIGHT 9
@@ -69,39 +72,40 @@ public:
 
 	virtual bool readProjectFile      ( QDomNode     & );
 	virtual bool writeProjectFile     ( QDomElement  & );
-	virtual void createStructure      ( QListViewItem *) = 0;
-	virtual bool createContextMenu    ( QPoint   ) = 0;
-	virtual bool contains             ( QPoint & );
-	virtual MenuObject *clone         ( );
-	virtual MenuObject *clone         ( MenuObject * ); // those who need a parent (E.g. ShadowObhect)
+	virtual bool contains             ( QPoint  & );
+	virtual bool createContextMenu    ( QPoint    ) = 0;
+	virtual StructureItem *createStructure ( StructureItem * ) = 0;
+	virtual MenuObject *clone         ( QWidget *p1=NULL, MenuObject *p2=NULL );
 	virtual bool isActive             ( );
 	virtual void setActive            ( bool );
-	virtual void replaceColor         ( QColor, QColor ) { };
+	virtual void replaceColor         ( Rgba, Rgba ) { };
 	virtual void updateShadow         ( );
+	virtual void setShadow            ( MenuObject * );
 
 	virtual void setModifiers   ( Modifiers &     );
+	virtual void setRect        ( QRect &         );
+	virtual QRect &rect         ( );
+	virtual QRect &boundingRect ( );
 	void      update            (                 );
 	void      setName           ( QString &       );
 	void      setExtractionPath ( QString &       );
 	void      setAnimation      ( QString &       );
 	void      setParent         ( QWidget *       );
-	void      setRect           ( QRect &         );
-	void      setPosition       ( QPoint &        );
-	void      setShadow         ( MenuObject *    );
+	void      setPosition       ( QPoint  &       );
 	bool      drawRect          (                 );
 	void      setCurrentMousePos( QPoint  &       );
+	void      animationDialog   ( QString &, int  );
 	void      loadAnimationData ( QString &, long );
-	enState   setObjectState    ( QPoint &        );
+	enState   setObjectState    ( QPoint  &, Qt::ButtonState );
 	void      setObjectState    ( enState         );
-
+	
 	virtual Modifiers *modifiers( );
-	MenuObject *shadow          ( );
+	virtual MenuObject *shadow  ( );
+	virtual void resetStructureItem ( );
+	virtual QString &extractionPath ( );  // Used to store a unique path name for this object to be extracted into (movieObject)
 	QString   &objectType       ( );
 	QString   &name             ( );
-	QString   &extractionPath   ( );	// Used to store a unique path name for this object to be extracted into (movieObject)
 	QString   &animation        ( );
-	QRect     &boundingRect     ( );
-	QRect     &rect             ( );
 	QPoint     position         ( );
 	QWidget   *parent           ( );
 	QPoint    &currentMousePos  ( );
@@ -111,35 +115,41 @@ protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString) = 0;
 
 public slots:
-	virtual void slotDelete     ( );
-	virtual void slotToFront    ( );
-	virtual void slotToBack     ( );
-	virtual void slotAddShadow  ( );
+	virtual void slotDelete       ( );
+	virtual void slotEmitDelete   ( );
+	virtual void slotToFront      ( );
+	virtual void slotToBack       ( );
+	virtual void slotCut          ( );
+	virtual void slotCopy         ( );
+	virtual void slotAddShadow    ( );
+	virtual void slotDeleteShadow ( );
 
 signals:
-	void signalDefineAsButton   ( MenuObject * );
 	void signalMoveOnStack      ( MenuObject *, int );
+	void signalDefineAsButton   ( MenuObject * );
 	void signalDeleteMe         ( MenuObject * );
 	void signalShadowMe         ( MenuObject * );
+	void signalAnimateMe        ( QString &, int, QString );
 	void signalUpdateStructure  ( );
 	void signalUpdatePixmap     ( );
 	// Only used by Text, Frame, Button and only received if in ButtonDialog.
-	void signalMaskColorChanged ( QColor, QColor);
+	void signalMaskColorChanged ( Rgba, Rgba );
 
 protected:
-	QPopupMenu   *m_pContextMenu;
-	QString       m_qsObjectType;
-	QString       m_qsName;
-	QString       m_qsExtractionPath;
-	QRect	      m_rect;
-	QRect         m_boundingRect;
-	QWidget      *m_pParent;
-	bool          m_bDrawRect; // isActive, draw ActiveFrame (resize, rotate etc)
-	MenuObject   *m_pShadow;
-	Modifiers     m_modifiers;
-	QString       m_qsAnimation;	// script or dataset holds also the datafilename
-	QPoint        m_currentMousePos;
-	enState       m_objectState;
+	QPopupMenu    *m_pContextMenu;
+	QString        m_qsObjectType;
+	QString        m_qsName;
+	QString        m_qsExtractionPath;
+	QRect	       m_rect;
+	QRect          m_boundingRect;
+	QWidget       *m_pParent;
+	bool           m_bDrawRect; // isActive, draw ActiveFrame (resize, rotate etc)
+	MenuObject    *m_pShadow;
+	StructureItem *m_pStructureItem;
+	Modifiers      m_modifiers;
+	QString        m_qsAnimation;	// script or dataset holds also the datafilename
+	QPoint         m_currentMousePos;
+	enState        m_objectState;
 	QValueList<AnimationAttribute *> m_listAnimationAttributes;
 };
 
