@@ -192,7 +192,7 @@ int MessageBox::help ( QWidget *pParent, const QString &qsCaption, const QString
   bool bFound = false;
   QString qsText, qsFileName;
 
-  qsFileName = QString (  PREFIX_DIRECTORY"/share/qdvdauthor/html/%1/%2" ).arg( Global::qsLanguage ).arg( qsFile );
+  qsFileName = QString (  Global::qsSystemPath + "/share/qdvdauthor/html/%1/%2" ).arg( Global::qsLanguage ).arg( qsFile );
   QFile theFile( qsFileName );
 
   for ( t=0;t<2;t++) {
@@ -207,10 +207,10 @@ int MessageBox::help ( QWidget *pParent, const QString &qsCaption, const QString
       bFound = true;
     }
     else
-      qsFileName = QString (  PREFIX_DIRECTORY"/share/qdvdauthor/html/en/%1" ).arg( qsFile );
+      qsFileName = QString (  Global::qsSystemPath + "/share/qdvdauthor/html/en/%1" ).arg( qsFile );
   }
   if ( ! bFound ) 
-    qsText = QObject::tr ( "Error, could not find file\n%1/share/qdvdauthor/html/%2/%3\nPlease make sure you have " ).arg( PREFIX_DIRECTORY ).arg( Global::qsLanguage ).arg ( qsFileName );
+    qsText = QObject::tr ( "Error, could not find file\n%1/share/qdvdauthor/html/%2/%3\nPlease make sure you have " ).arg( Global::qsSystemPath ).arg( Global::qsLanguage ).arg ( qsFileName );
 
   return MessageBox::html ( pParent, qsCaption, qsText, initialSize, iButton1, iButton2 );
 }
