@@ -42,6 +42,7 @@ MovieObject::MovieObject ( QWidget *pParent )
   m_pDVDMenu      = NULL;
   m_bExtracted    = false;
   m_bMenuLength   = true; // default to the same length as the menu
+  m_enLoop        = Loop;
   m_iMSecPreview  = 0;
 }
 
@@ -73,12 +74,17 @@ void MovieObject::setDuration ( QTime &timeDuration )
 
 void MovieObject::setMenuLength ( bool bMenuLength )
 {
-  if ( dvdMenu  ( ) )
-    setDuration ( dvdMenu ( )->getInterface ( )->timeDuration );
+  if ( bMenuLength && dvdMenu ( ) )
+       setDuration  ( dvdMenu ( )->getInterface ( )->timeDuration );
 
   m_bMenuLength = bMenuLength;
 }
 
+void MovieObject::setLoop ( MovieObject::enType enLoop )
+{
+  m_enLoop = enLoop;
+}
+
 void MovieObject::createExtractionPath ( )
 {
   QString   qsExtractionPath, qsOffset;
@@ -91,7 +97,7 @@ void MovieObject::createExtractionPath ( )
   int iDuration    = zeroTime.msecsTo      ( duration ( ) );
   sprintf ( cBuffer, "-%07d", iDuration );
   qsExtractionPath += "-"+qsOffset + cBuffer;
-  setExtractionPath ( qsExtractionPath );  
+  setExtractionPath  ( qsExtractionPath );
 }
 
 QString &MovieObject::extractionPath ( )
@@ -123,7 +129,7 @@ QTime &MovieObject::offset    ()
 	return m_timeOffset;
 }
 
-QTime &MovieObject::duration  ()
+QTime &MovieObject::duration  ( )
 {
   if ( m_bMenuLength && dvdMenu ( ) )
     return dvdMenu ( )->getInterface ( )->timeDuration;
@@ -135,6 +141,11 @@ bool MovieObject::isMenuLength ( )
   return m_bMenuLength;
 }
 
+MovieObject::enType MovieObject::loop ( )
+{
+  return m_enLoop;
+}
+
 long MovieObject::msecPreview  ()
 {
 	return m_iMSecPreview;
@@ -316,34 +327,39 @@ void MovieObject::slotEdit ()
 void MovieObject::slotProperties ()
 {
 	// Okay the user does want to make some changes ... so let us stop the timer ...
-	if (m_pConvertTimer)
-		m_pConvertTimer->stop();
+	if ( m_pConvertTimer )
+		m_pConvertTimer->stop ( );
 
 	DialogMovie movieDialog (NULL);
 	connect ( &movieDialog, SIGNAL ( signalSetThumbnail ( long ) ), this, SLOT ( slotSetThumbnail ( long ) ) );
 	movieDialog.initMe ( this ); 
-	if (movieDialog.exec() == QDialog::Accepted)	{
+	if ( movieDialog.exec ( ) == QDialog::Accepted )  {
 		int iX, iY, iWidth, iHeight;
-		iX      = movieDialog.m_pEditX->text().toInt();
-		iY      = movieDialog.m_pEditY->text().toInt();
-		iWidth  = movieDialog.m_pEditWidth ->text().toInt();
-		iHeight = movieDialog.m_pEditHeight->text().toInt();
-		QRect rect (iX, iY, iWidth, iHeight);
-		setRect (rect);
+		iX      = movieDialog.m_pEditX->text ( ).toInt ( );
+		iY      = movieDialog.m_pEditY->text ( ).toInt ( );
+		iWidth  = movieDialog.m_pEditWidth ->text ( ).toInt ( );
+		iHeight = movieDialog.m_pEditHeight->text ( ).toInt ( );
+		QRect rect ( iX, iY, iWidth, iHeight );
+		setRect    ( rect );
 		// Next we hande the start/stop time.
 		QString qsFormat ("hh:mm:ss.zzz");
 		QTime startingTime, endingTime, duration;
 		startingTime = QTime::fromString ( movieDialog.m_pEditStarting2->text ( ) );
 		endingTime   = QTime::fromString ( movieDialog.m_pEditEnding2  ->text ( ) );
-		setMenuLength ( movieDialog.m_pCheckSameAsMenuLength->isChecked ( ) );
-		if ( startingTime.isValid ( ) )	{
-			setOffset (startingTime);
-			if (endingTime.isValid ())	{
-				int iMSecs = startingTime.msecsTo  (endingTime);
-				duration   = duration.addMSecs (iMSecs);
-				setDuration (duration);
+		if ( startingTime.isValid ( ) )  {
+			setOffset ( startingTime );
+			if (endingTime.isValid ( ) )  {
+				int iMSecs = startingTime.msecsTo ( endingTime );
+				duration   = duration.addMSecs    (     iMSecs );
+				setDuration ( duration );
 			}
 		}
+		setMenuLength ( movieDialog.m_pCheckSameAsMenuLength->isChecked  ( ) );
+		setLoop ( Loop );
+		if ( movieDialog.m_pButtonLoop->text ( ) == "Stretch" )
+			setLoop ( Stretch );
+		if ( movieDialog.m_pButtonLoop->text ( ) == "Stop" )
+			setLoop ( Stop );
 
 		emit (signalUpdatePixmap());
 		updatePixmap ();
@@ -353,7 +369,7 @@ void MovieObject::slotProperties ()
 	// And finally we re-start the timer (or start a new time to extract the propper images.
 	// Note: this can be done bacause I will check a status file first before extracting the frames, 
 	//       thus avoiding unneccesary extracting of the images in the movie.
-	registerToRender ();
+	registerToRender ( );
 }
 
 void MovieObject::registerToRender ()
@@ -396,10 +412,13 @@ void MovieObject::startConverting ( bool bAllowDialogs )
 	// Note that for the movies we follow the scheme :ith 
 	// /temp-Path/ProjectName/MenuName/MovieName/0000001.jpg
 	///////////////////////////////////////////////////////
-	qsMenuName = QString ("NoMenuError");
-	if (m_pDVDMenu)
+	qsMenuName = QString ( "NoMenuError" );
+	if ( m_pDVDMenu )
 		qsMenuName = m_pDVDMenu->getInterface()->qsMenuName;
 
+	// Make sure we have the latest and greates path.
+	createExtractionPath ( );
+
 	qsFullPath = QFile::encodeName ( QString ("%1/%2/%3/%4").arg ( Global::qsTempPath ).arg ( Global::qsProjectName ).arg ( qsMenuName ).arg ( extractionPath ( ) ) );
 	qsCommand  = QString ( "mkdir -p '%1'" ).arg ( qsFullPath );
 	if ( system ((const char *)qsCommand) == -1 )
@@ -477,6 +496,14 @@ bool MovieObject::readProjectFile  (QDomNode &theNode)
 	  setMenuLength ( ( attribute.value ( ) == "true" ) );
 	else
 	  setMenuLength ( true );
+	attribute =  theElement.attributeNode ( MOVIE_OBJECT_LOOP );
+	setLoop ( Loop );
+	if ( ! attribute.isNull ( ) )  {
+	  if ( attribute.value  ( ) == "Stretch" )
+	    setLoop ( Stretch );
+	  else  if  ( attribute.value ( ) == "Stop" )
+	    setLoop ( Stop );
+	}
 
 	QDomNode manNode = theNode.firstChild();
 	while (!manNode.isNull())	{
@@ -502,11 +529,17 @@ bool MovieObject::writeProjectFile (QDomElement &theElement)
 	QDomDocument xmlDoc = theElement.ownerDocument();
 	QDomElement movieNode = xmlDoc.createElement( MOVIE_OBJECT );	// <MovieObject>
 	// Here we set the attributes of the <dvdauthor> tag
+	QString qsType = "Loop";
+	if ( m_enLoop == Stretch )
+	  qsType = "Stretch";
+	if ( m_enLoop == Stop )
+	  qsType = "Stop";
 	if (!m_qsFileName.isNull())
 		movieNode.setAttribute( MOVIE_OBJECT_FILE_NAME, m_qsFileName );
 	movieNode.setAttribute( MOVIE_OBJECT_OFFSET,   m_timeOffset.toString   (qsFormat) );
 	movieNode.setAttribute( MOVIE_OBJECT_DURATION, m_timeDuration.toString (qsFormat) );
-	movieNode.setAttribute( MOVIE_OBJECT_MENU_LENGTH, m_bMenuLength ? "true" : "false" );
+	movieNode.setAttribute( MOVIE_OBJECT_MENU_LENGTH,  m_bMenuLength ? "true" : "false" );
+	movieNode.setAttribute( MOVIE_OBJECT_LOOP,         qsType );
 	movieNode.setAttribute( MOVIE_OBJECT_MSEC_PREVIEW, QString ( "%1" ).arg ( m_iMSecPreview ) );
 	movieNode.setAttribute( MOVIE_OBJECT_SIZE, QString("%1x%2").arg(movieSize().width()).arg(movieSize().height()) );
 
@@ -577,12 +610,12 @@ MenuObject *MovieObject::clone ( QWidget *pParent, MenuObject * )
   pNewObject->setStartAfterDropEvent ( m_bStartAfterDropEvent );
   //	QImage  m_imagePreview;	// used to create a preview in a background task.
   //	QTimer *m_pConvertTimer;
-  
+
   MenuObject *pShadow = shadow ( );
   if ( pShadow )
     pShadow = pShadow->clone ( pParent, pNewObject );
   pNewObject->setShadow      ( pShadow );
-  
+
   return pNewObject;
 }
 
@@ -661,20 +694,26 @@ void MovieObject::loadPixmap(QString qsFileName)
 void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int iTotalFramesToRender)
 {
   QString qsFullPath, qsFileName, qsMenuName;
-  int  iCurrentClipFile;
+  int iCurrentClipFile = 0;
 
   // Okay first step is get the fileName of the frame
-  qsMenuName = dvdMenu()->getInterface()->qsMenuName;
-  qsFullPath = QString ("%1/%2/%3/%4").arg(Global::qsTempPath).arg(Global::qsProjectName) .arg(qsMenuName).arg(extractionPath());
-  QDir theDir (qsFullPath);
-  theDir.setNameFilter ("0*.jpg");
+  qsMenuName = dvdMenu ( )->getInterface ( )->qsMenuName;
+  qsFullPath = QString ( "%1/%2/%3/%4" ).arg ( Global::qsTempPath ).arg ( Global::qsProjectName ) .arg ( qsMenuName ).arg ( extractionPath ( ) );
+  QDir theDir ( qsFullPath );
+  theDir.setNameFilter ( "0*.jpg" );
+  int iDirCount = theDir.count  ( );
 
 //	// Next is to set the AnimationAttributes
 //	for (t=0;t<m_listAnimationAttributes.count();t++)
 //		m_listAnimationAttributes[t]->setValue (iRenderFrameNumber);
 
-  // So we have the full list of the frames, now we pick the appropriate frame ...
-  iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
+  // This one we use as a loop the video
+  if ( m_enLoop == Loop )
+    iCurrentClipFile = ( iDirCount > 0 ) ? iRenderFrameNumber%iDirCount : 0;
+  else if ( m_enLoop == Stretch ) // Stretch : We have the full list of the frames, now we pick the appropriate frame ...
+    iCurrentClipFile = (int)((float)theDir.count() * (float)iRenderFrameNumber/(float)iTotalFramesToRender);
+  else if ( m_enLoop == Stop )
+    iCurrentClipFile = ( iRenderFrameNumber > iDirCount ) ? iDirCount-1 : iRenderFrameNumber;
   qsFileName = QString ("%1/%2").arg(qsFullPath).arg(theDir[iCurrentClipFile]);
   //printf ("MovieObject::drawContents <%s> <%s> <%d> <%d>\n", (const char *)qsFileName, (const char *)qsFileName, theDir.count(), iCurrentClipFile);
   loadPixmap (qsFileName);
@@ -682,7 +721,7 @@ void MovieObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int
   if ( m_listAnimationAttributes.count ( ) < 1 )
     updateShadow ( );
 
-  // then we call 
+  // then we call
   ImageObject::drawContents(pPainter, iRenderFrameNumber, iTotalFramesToRender);
 }
 
@@ -696,7 +735,7 @@ AnimationAttribute *MovieObject::getSpecificAttributes (long iMaxNumberOfFrames,
     if (qsProperty == "frameNo")
       pAnimAttr = new AnimationAttribute (iMaxNumberOfFrames, qsProperty, m_iTestInt, &m_iTestInt);
   }
-  
+
   return pAnimAttr;
 }
 
