@@ -18,6 +18,7 @@
 #include <qregexp.h>
 #include <qlayout.h>
 #include <qtoolbox.h>
+#include <qspinbox.h>
 #include <qgroupbox.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
@@ -74,7 +75,8 @@ OneClickWizard::OneClickWizard ( QWidget *pParent, const char *pName, bool bModa
   GroupView *pGroupView = new GroupView ( m_pToolBoxGroups, (SourceFileEntry *)NULL ); // or this 
   m_pToolBoxGroups->addItem ( pGroupView, QString ( "Groups" ) );
 
-  m_pFrameSlideshow->hide ( );
+  m_pSpinThreads->setValue ( Global::iMaxRunningThreads );
+  m_pFrameSlideshow->hide  ( );
 
   connect ( this, SIGNAL ( helpClicked ( ) ), this, SLOT ( slotHelp ( ) ) );
   connect ( m_pButtonBrowseTemp,  SIGNAL ( clicked ( ) ), this, SLOT ( slotBrowseTemp    ( ) ) );
@@ -119,8 +121,9 @@ void OneClickWizard::deleteGroups ( )
 
 bool OneClickWizard::initMe ( )
 {
-  QString strDirectory   ( PREFIX_DIRECTORY"/share/qdvdauthor/plugins" );
+  QString strDirectory   ( Global::qsSystemPath + "/share/qdvdauthor/plugins" );
   int iRet = loadPlugins ( strDirectory );
+
   if ( iRet > 0 )  {
     uiOneClickWizard::show ( );
     loadPlugin ( 0 );
@@ -562,42 +565,68 @@ GroupView *OneClickWizard::addGroup ( CXmlSlideshow *pSlideshow )
     return NULL;
 
   int       t;
-  bool      bAlternate = true;
+  bool      bBitmapSet = false;
+  bool      bAlternate =  true;
   QFileInfo fileInfo;
   QPixmap   thePixmap, errorPixmap;
-  Cache::Thumbs::Entry      *pCache  = NULL;
-  CXmlSlideshow::img_struct *pXmlImg = NULL;
-  GroupView::Item *pItem      = NULL;
-  GroupView       *pGroupView = new GroupView ( m_pToolBoxGroups, NULL, NULL, pSlideshow );
+  Cache::Thumbs::Entry       *pCache  = NULL;
+  CXmlSlideshow::time_object *pXmlObj = NULL;
+  CXmlSlideshow::img_struct  *pXmlImg = NULL;
+  CXmlSlideshow::vid_struct  *pXmlVid = NULL;
+  CXmlSlideshow::img_struct   tempImg;
+  CXmlSlideshow::vid_struct   tempVid;
+  GroupView::Item *pItem       = NULL;
+  GroupView       *pGroupView  = new GroupView ( m_pToolBoxGroups, NULL, NULL, pSlideshow );
   QImage theImage ( QImage ( ).fromMimeSource ( "error.jpg" ) );
 
   theImage = theImage.smoothScale ( GroupView::m_iSize, GroupView::m_iSize );
   errorPixmap.convertFromImage    ( theImage );
 
-  uint iCount = pSlideshow->countImg ( );
+  uint iCount = pSlideshow->count ( );
   for ( t=(int)iCount-1; t>=0; t-- ) {
-    pXmlImg = pSlideshow->getImg ( t );
-    if ( ! pXmlImg ) // || t > 100 ) // Only the first 100 images for performance issues
+    pItem      = NULL;
+    bBitmapSet = false;
+    pXmlObj = pSlideshow->getTimeObject ( t );
+    if ( ! pXmlObj ) // || t > 100 ) // Only the first 100 images for performance issues
       continue;
-    pCache = Global::pThumbsCache->find ( pXmlImg->src, true );
-    fileInfo.setFile ( pXmlImg->src );
+
     bAlternate = ! bAlternate;
-    pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), bAlternate );
+
+    if ( pXmlObj->node_name == tempImg.node_name )  {
+      pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
+      pCache  = Global::pThumbsCache->find ( pXmlImg->src, true );
+      fileInfo.setFile ( pXmlImg->src );
+      pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), bAlternate );
+    }
+    else if ( pXmlObj->node_name == tempVid.node_name )  {
+      pXmlVid = (CXmlSlideshow::vid_struct *)pXmlObj;
+      pCache  = Global::pThumbsCache->find ( pXmlVid->src, false );
+      fileInfo.setFile ( pXmlVid->src );
+      pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), bAlternate );
+    }
+    if ( ! pItem )
+      continue;
+
     if ( pCache )  {
       pItem->pCache = pCache;
       if ( ! pCache->arrayOfThumbs )
              pCache->loadImages  ( );
       if ( pCache->arrayOfThumbs && pCache->arrayOfThumbs[0] ) {
-        theImage = pCache->arrayOfThumbs[0]->smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
+        if ( pCache->getMatrix ( ) )  {
+             theImage = pCache->arrayOfThumbs[0]->xForm ( *pCache->getMatrix ( ) );
+             theImage = theImage.smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
+        }
+        else
+          theImage = pCache->arrayOfThumbs[0]->smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
         thePixmap.convertFromImage ( theImage );
         pItem->setPixmap ( 0, thePixmap );
+        bBitmapSet = true;
       }
-      else
-        pItem->setPixmap ( 0, errorPixmap );
     }
-    else
+    if ( ! bBitmapSet )
       pItem->setPixmap ( 0, errorPixmap );
   }
+
   connect  ( pGroupView, SIGNAL ( contextMenuRequested ( QListViewItem *, const QPoint &, int ) ), this, SLOT ( slotGroupContextMenu ( QListViewItem *, const QPoint &, int ) ) );
 
   // And finally we can add the listBox to the ToolBox
@@ -608,12 +637,12 @@ GroupView *OneClickWizard::addGroup ( CXmlSlideshow *pSlideshow )
 void OneClickWizard::slotGroupContextMenu ( QListViewItem *pSelItem, const QPoint &pos, int )
 {
   QPopupMenu *pMenu   = new QPopupMenu  ( this );
-  int iIDs[3];
-  iIDs[0] = pMenu->insertItem ( tr ( "to &Group ..." ),          1 ); // play in player
-  iIDs[1] = pMenu->insertItem ( tr ( "&Play" ),                  2 ); // play in player2
+  int iIDs[4];
+  iIDs[0] = pMenu->insertItem ( tr ( "to &Group ..." ), 1 ); // play in player
+  iIDs[1] = pMenu->insertItem ( tr ( "&Play" ),         2 ); // play in player2
   pMenu->insertSeparator ( );
-  iIDs[2] = pMenu->insertItem ( tr ( "&Add" ),                   3 ); // add a new entry
-  iIDs[3] = pMenu->insertItem ( tr ( "&Remove" ),                4 ); // remove this one entry
+  iIDs[2] = pMenu->insertItem ( tr ( "&Add" ),          3 ); // add a new entry
+  iIDs[3] = pMenu->insertItem ( tr ( "&Remove" ),       4 ); // remove this one entry
 
   if ( ! pSelItem )  {
     pMenu->setItemEnabled ( iIDs[0], false );
@@ -847,11 +876,14 @@ void OneClickWizard::accept ( )
   Global::qsProjectPath = m_pLabelDVDPath->text ( );
 
   Utils theUtils;
-//  theUtils.recMkdir ( m_pLabelTempPath->text ( ) );
-//  theUtils.recMkdir ( m_pLabelDVDPath ->text ( ) );
   theUtils.recMkdir ( Global::qsTempPath    );
   theUtils.recMkdir ( Global::qsProjectPath );
 
+  if ( m_pFrameSlideshow->isVisible ( ) )
+       Global::iMaxRunningThreads = m_pSpinThreads->value ( );
+  if ( Global::iMaxRunningThreads < 1 )
+       Global::iMaxRunningThreads = 1;
+
   groupsToPlugin ( );
 
   // Once we are at this point we can delete the stored objects ...
@@ -946,7 +978,10 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   QTime time (   12, 22, 44 );
 
   unsigned int     t, iCount;
-  CXmlSlideshow::img_struct *pXmlImg = NULL;
+  CXmlSlideshow::time_object *pXmlObj = NULL;
+  CXmlSlideshow::img_struct  *pXmlImg = NULL;
+  CXmlSlideshow::img_struct   tempImg;
+  CXmlSlideshow::vid_struct   tempVid;
 
   pGroup->qsGroupName         = pSlideshow->slideshow_name;
   pGroup->bSlideshow          = true;
@@ -960,15 +995,32 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   date = date.addDays ( 10 );
   pGroup->dateEnd             = QDateTime ( date, time );
   ////////////////////////////////////////////////////////
-  iCount = pSlideshow->countImg ( );
+  iCount = pSlideshow->count ( );
   for ( t=0; t<iCount; t++ )  {
-    pXmlImg = pSlideshow->getImg ( t );
-    // Make sure the Group has a sceenshot associated with
-    if ( pGroup->qsScreenshot.isEmpty ( ) )
-         pGroup->qsScreenshot = pXmlImg->src;
+    pXmlObj = pSlideshow->getTimeObject ( t );
+    pXmlImg = NULL;
+    if ( pXmlObj->node_name == tempImg.node_name )  {
+      pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
+      // Make sure the Group has a sceenshot associated with
+      if ( pGroup->qsScreenshot.isEmpty ( ) )  {
+           pGroup->qsScreenshot = pXmlImg->src;
+        if ( pXmlImg->pMatrix )  {
+           QString qsFileName = Global::qsTempPath + QString ( "/temp_%1.png" ).arg ( t );
+           QImage img ( pXmlImg->src );
+           img  = img.xForm ( *pXmlImg->pMatrix );
+           img.save   ( qsFileName, "PNG", 100 );
+           pGroup->qsScreenshot = qsFileName;
+        }
+      }
+    }
+    else if ( pXmlObj->node_name == tempVid.node_name )
+      pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
+    if ( ! pXmlImg )
+      continue;
 
     Plugin::SourceGroup::SourceEntry *pSourceEntry = new Plugin::SourceGroup::SourceEntry;
     pSourceEntry->qsFileName = pXmlImg->src;
+    pSourceEntry->bVidSource = ( pXmlObj->node_name == tempVid.node_name );
     if ( pXmlImg->fDuration > 0.0f )
       pSourceEntry->iLength  = (unsigned long)( pXmlImg->fDuration * 1000.0 ); // in MSec
     else
