@@ -28,8 +28,8 @@ extern "C" void destroyPlugin ( Plugin::Interface *pDeleteMe ) {
 
 #include "../../CONFIG.h"
 
-#ifndef PREFIX_DIRECTORY
-#define PREFIX_DIRECTORY "/usr"
+#ifndef SYSTEM_DIRECTORY
+#define SYSTEM_DIRECTORY "/usr"
 #endif
 
 namespace Plugin
@@ -327,7 +327,7 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
     return qsMenuXML;
 
   qsTempPath = m_qsTempPath + "/" + m_qsProjectName;
-  qsBackgroundFile = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/background.jpg";
+  qsBackgroundFile = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/background.jpg";
   if ( m_pConfigWidget && m_pConfigWidget->m_pCheckRandomImages && 
        m_pConfigWidget->m_pCheckRandomImages->isChecked ( ) )
     qsBackgroundFile = QString ( "%1/menu_%2.jpg" ).arg ( qsTempPath ).arg ( iMenuNumber );
@@ -422,8 +422,12 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
     qsMenuXML += "   </ButtonObject>\n";
   }
   // Create prev/next buttons
+  int  iNrOfMenus = m_iNrOfMenus;
+  if ( m_pConfigWidget->m_pCheckMainMenu->isChecked ( ) )
+       iNrOfMenus ++;
+
   bool bPrev = ( iMenuNumber > 1 );
-  bool bNext = ( iMenuNumber < m_iNrOfMenus );
+  bool bNext = ( iMenuNumber < iNrOfMenus );
   qsMenuXML += getMenuButtons ( bPrev, bNext, iMenuNumber );
 
   qsMenuXML += "  </PreviewVariables>\n";
@@ -436,9 +440,9 @@ QString ComplexDVD::getMenuButtons ( bool bPrev, bool bNext, int iMenuNumber )
 {
   QString qsMenuXML, qsMenuName;
   // The three buttons to the previous, next and Main menu ...
-  QString qsButtonPrev = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/prev.png";
-  QString qsButtonMain = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/main.png";
-  QString qsButtonNext = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/next.png";
+  QString qsButtonPrev = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/prev.png";
+  QString qsButtonMain = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/main.png";
+  QString qsButtonNext = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/next.png";
   if ( bPrev )  {
     qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber - 1 );
     qsMenuXML += "   <ButtonObject Action=\"jump+-+"+qsMenuName+"+-+\" ButtonName=\"Button 7\" >\n";
