@@ -19,8 +19,8 @@ extern "C" void destroyPlugin ( Plugin::Interface *pDeleteMe ) {
 
 #include "../../CONFIG.h"
 
-#ifndef PREFIX_DIRECTORY
-#define PREFIX_DIRECTORY "/usr"
+#ifndef SYSTEM_DIRECTORY
+#define SYSTEM_DIRECTORY "/usr"
 #endif
 
 namespace Plugin
@@ -54,7 +54,8 @@ bool SimpleDVD::execute ( )
   while ( it != m_listOfGroups.end ( ) )  {
     pGroup = *it++;
 //    printf ( "Group #<%d>: <%s> from<%s> to<%s>\n", (int)pGroup->listFiles.count ( ), pGroup->qsGroupName.ascii ( ), pGroup->dateStart.toString ( ).ascii ( ), pGroup->dateEnd.toString ( ).ascii ( ) );
-    emit ( signalNewSource ( pGroup ) );
+
+    emit ( signalNewSource ( pGroup ) ); // calls QDVDAuthor::slotNewSource ( Plugin::SourceGroup *pGroup )
   }
 
   // The next iteration we generate the DVDMenus.
@@ -116,7 +117,7 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
   if ( list.count ( ) < 1 )
     return qsMenuXML;
 
-  qsBackgroundFile = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/background.jpg";
+  qsBackgroundFile = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/background.jpg";
   qsMenuName.sprintf ( "Menu %d", iMenuNumber );
   pGroup = list[0];
   if ( pGroup->enType == SourceGroup::PAL )
@@ -222,9 +223,9 @@ QString SimpleDVD::getMenuButtons ( bool bPrev, bool bNext, int iMenuNumber )
 {
   QString qsMenuXML, qsMenuName;
   // The three buttons to the previous, next and Main menu ...
-  QString qsButtonPrev = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/prev.png";
-  QString qsButtonMain = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/main.png";
-  QString qsButtonNext = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/next.png";
+  QString qsButtonPrev = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/prev.png";
+  QString qsButtonMain = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/main.png";
+  QString qsButtonNext = SYSTEM_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/next.png";
   if ( bPrev )  {
     qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber - 1 );
     qsMenuXML += "   <ButtonObject Action=\"jump+-+"+qsMenuName+"+-+\" ButtonName=\"Button 7\" >\n";
