@@ -13,8 +13,9 @@ class SourceGroup
 
     class SourceEntry  {
     public:
-      SourceEntry ( ) { iLength=0; };
+      SourceEntry ( ) { iLength=0; bVidSource=false; };
       QString    qsFileName;
+      bool       bVidSource;
       unsigned long iLength; // in MSec
     };
              SourceGroup ( ) { enType=NTSC; bSlideshow=false; bCreateChapterMenu=false; };
