@@ -5,12 +5,16 @@
 **      by: Varol Okan using Kate
 **
 ****************************************************************************/
+#ifdef QDVD_LINUX 
+#include <unistd.h>
+#endif 
 
 #include <qregexp.h>
 #include <qprocess.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
 
+#include "../../win32.h"
 #include "qmplayerwidget.h"
 #include "dialogmplayersetup.h"
 
@@ -86,7 +90,8 @@ void DialogMPlayerSetup::slotProcessVideoPlugins ()
 	if (qsStdout.length() < 100)
 		return;
 //printf ("%s\n\n", (const char *)qsStdout);
-
+	// Note withot this sleep the driver do not always show up ...
+    usleep ( 10000 ); // 10 ms
 	qsCurrent = (*m_pListPluginOptions)[QMPlayerWidget::VideoPlugin];
 	// First we generate a list with one entry per line.
 	listInfos = QStringList::split ("\n", qsStdout);
@@ -95,7 +100,7 @@ void DialogMPlayerSetup::slotProcessVideoPlugins ()
 	for (t=0;t<listInfos.count();t++)	{
 		if (regExp.search(listInfos[t]) > -1)	{
 			m_pComboVideo->insertItem (regExp.cap(1));
-//	printf ("<%d><%s> -=> <%s>\n", t, (const char *)listInfo[t], (const char *)regExp.cap(1));
+//printf ("<%d><%s> -=> <%s>\n", t, (const char *)listInfos[t], (const char *)regExp.cap(1));
 			if ( (!qsCurrent.isNull()) && (qsCurrent == regExp.cap(1)) )
 				m_pComboVideo->setCurrentText (qsCurrent);
 		}
@@ -111,14 +116,19 @@ void DialogMPlayerSetup::slotProcessAudioPlugins ()
 	// The length will tell us if we have the requested information or not.
 	if (qsStdout.length() < 100)
 		return;
-
+	// Note without this sleep the driver do not always show up ...
+    usleep ( 10000 ); // 10ms
 	qsCurrent = (*m_pListPluginOptions)[QMPlayerWidget::AudioPlugin];
 	// First we generate a list with one entry per line.
 	listInfos = QStringList::split ("\n", qsStdout);
 
+//printf ( "Audio found %d plugins\n", (int)listInfos.count ( ) );
+
 	QRegExp	regExp ("^\\s+(\\w+)\\s+.*");
 	for (t=0;t<listInfos.count();t++)	{
+//		printf ( "Audio [%d] = <%s>\n", t, listInfos[t].ascii() );
 		if (regExp.search(listInfos[t]) > -1)	{
+//printf ( "  Insert [%d]<%s>\n", t, regExp.cap ( 1 ).ascii ( ) );
 			m_pComboAudio->insertItem (regExp.cap(1));
 			if ( (!qsCurrent.isNull()) && (qsCurrent == regExp.cap(1)) )
 				m_pComboAudio->setCurrentText (qsCurrent);
