@@ -236,7 +236,8 @@ void QPlayer::loadHistory ()
 	if (!xmlDoc.setContent (&iniFile))	{
 		// Error handling ...
 		iniFile.close();
-		printf ( (const char *) tr ("QPlayer xml init file <%1> seems to be defective. Re-setting values.\n").arg(qsPlayerIniFile));
+		QString qsOut = tr ( "QPlayer xml init file <%1> seems to be defective. Re-setting values.\n" ).arg ( qsPlayerIniFile );
+		printf ( "%s", qsOut.ascii ( ) );
 		return;
 	}
 
