@@ -54,8 +54,8 @@
 #undef debug_out
 #endif
 static void dummy(const char*,...){};
-//#define debug_out printf
 #define debug_out dummy
+//#define debug_out printf
 
 namespace Render
 {
@@ -117,8 +117,8 @@ bool Manager::ServerInfo::hasClient ( Client *pClient )
 
 Client *Manager::ServerInfo::addClient ( SourceFileEntry *pEntry )
 {
-  Client *pClient = new Client ( pEntry );
-  m_listOfClients.append ( pClient );
+  Client *pClient = new Client ( pEntry  );
+  m_listOfClients.append       ( pClient );
   return pClient;
 }
 
@@ -162,6 +162,9 @@ bool Manager::ServerInfo::startNextClient ( )
     if  ( iCount >= m_iConcurrentThreads )
       break;
     pClient = *it++;
+
+    debug_out ( "%s : %d > Starting Client for <%s>\n", __FUNCTION__, __LINE__, pClient->sourceFileEntry()->qsDisplayName.ascii() );
+
     if ( pClient->waitingInQueue ( ) )  {
       pClient->setWaiting  ( false );
       pClient->start ( );
@@ -211,6 +214,51 @@ Manager::ServerInfo *Manager::getServerInfo ( Client *pClient )
   return NULL;
 }
 
+QStringList &Manager::getFilterNames ( )
+{
+  if ( m_listFilterNames.count ( ) > 0 )
+    return m_listFilterNames;
+
+  Utils theUtils;
+  QStringList filterList;
+  QString qsTempFile, qsFilterName, qsCommand;
+
+  qsCommand = theUtils.getToolPath ( "qrender" );
+  if ( qsCommand.isEmpty ( ) )  {
+    qsCommand = theUtils.checkForExe ( "qrender" );
+    if ( qsCommand.isEmpty ( ) )
+         qsCommand = "qrender";
+  }
+  m_listFilterNames.clear ( );
+
+  qsTempFile = Global::qsTempPath  +  "/filterList.txt";
+  qsCommand += QString ( " -f >%1" ).arg   ( qsTempFile );
+  int iRet   = system  ( qsCommand.ascii ( ) );
+  iRet = iRet; // quiet down the compiler.
+
+  // Next we read in the temp file
+  QFileInfo fileInfo ( qsTempFile );
+  if ( fileInfo.size ( ) > 10 )  {
+    QFile file ( qsTempFile );
+    if ( file.open ( IO_ReadOnly ) )  {
+      while ( ! file.atEnd   ( ) ) {
+        file.readLine ( qsFilterName, 4096 );
+        qsFilterName  = qsFilterName.remove ( "\n" );
+        if (  qsFilterName.length  ( ) > 0 )
+          m_listFilterNames.append ( qsFilterName );
+      }
+    }
+    file.close ( );
+  }
+
+  if ( m_listFilterNames.size ( ) < 1 )  {
+    // Hardcode at least the Cross Fade and KenBurns filter.
+    m_listFilterNames.append ( "Cross Fade" );
+    m_listFilterNames.append ( "Ken Burns"  );
+  }
+  return m_listFilterNames;
+}
+
 bool Manager::registerEntry ( SourceFileEntry *pEntry )
 {
   if ( ! pEntry || ! pEntry->bIsSlideshow || pEntry->listFileInfos.count ( ) < 1 )
@@ -235,7 +283,7 @@ bool Manager::registerEntry ( SourceFileEntry *pEntry )
   unsigned long iServerIP = 0x0F000001;  // 127.0.0.1
   ServerInfo *pServerInfo = m_pSelf->getServerInfo ( iServerIP );
   if ( ! pServerInfo )  {
-         pServerInfo =   new ServerInfo ( iServerIP, SERVER_PORT, CONCURRENT_THREADS );
+         pServerInfo =   new ServerInfo ( iServerIP, SERVER_PORT, Global::iMaxRunningThreads );
          m_pSelf->m_listOfServer.append ( pServerInfo );
   }
 
@@ -310,8 +358,6 @@ Client::Client ( SourceFileEntry *pEntry )
   connect ( m_pSocket, SIGNAL ( readyRead        ( ) ), SLOT ( socketReadyRead ( ) ) );
   connect ( m_pSocket, SIGNAL ( error        ( int ) ), SLOT ( socketError ( int ) ) );
   connect ( m_pSocket, SIGNAL ( connectionClosed ( ) ), SLOT ( socketConnectionClosed ( ) ) );
-  slotReconnect ( );  // Connect now.
-  enableTimer   ( true );
 }
 
 Client::~Client ( )
@@ -415,6 +461,7 @@ void Client::receivedProgress ( )
   m_fProgress = fProgress;
   unlock ( );
 
+  m_lastPing = QDateTime::currentDateTime ( );
   displayProgress ( );
 }
 
@@ -432,6 +479,17 @@ void Client::receivedPing ( )
 
 void Client::timerEvent ( QTimerEvent *pEvent )
 {
+/* Somehow I get remote server even though it should always be local ( for now ).
+Manager::ServerInfo *p = Manager::m_pSelf->getServerInfo ( this );
+printf ( "in <%p>\n", p );
+if ( ! p )
+  return;
+in_addr in;
+in.s_addr = p->getIP   (  );
+const char *pServer = inet_ntoa ( in );
+printf ( "bRemoteServer<%d> IP=<0x%016X> = <%s>\n", m_bRemoteServer, p->getIP ( ), pServer );
+*/
+
   if ( pEvent->timerId ( ) == m_iKeepaliveTimer )  {
     debug_out ( "Render::Client::timerEvent last<%s> Curr<%s>\n", m_lastPing.toString ( ).ascii ( ), QDateTime::currentDateTime ( ).toString ( ).ascii ( ) );
     if ( m_lastPing.secsTo ( QDateTime::currentDateTime ( ) ) > WENT_MISSING_AFTER * 2 ) { //I_AM_ALIVE_INTERVAL )  {
@@ -446,7 +504,7 @@ void Client::timerEvent ( QTimerEvent *pEvent )
         if ( ! pServerInfo->inRecovery ( ) )  {
           QString qsHtml, qsTime, qsServer;
           in_addr in;
-          in.s_addr = pServerInfo->getIP   ( );
+          in.s_addr = pServerInfo->getIP   (  );
           const char *pServer = inet_ntoa ( in );
 
           qsTime  = QString ( "%1" ).arg ( (int)(WENT_MISSING_AFTER * I_AM_ALIVE_INTERVAL / 1000.0 ) );
@@ -554,6 +612,7 @@ void Client::killServerThread ( )
 {
   QDataStream stream ( m_pSocket );
   stream << (Q_UINT16)CLIENT_KILL_YOURSELF << (Q_UINT64)0LL;
+  m_pSocket->flush ( );
 }
 
 bool Client::sendFile ( QString qsFileName )
@@ -587,7 +646,7 @@ void Client::sendNextPacket ( )
   char data[BLOCK_LEN];
   if ( ! m_pFile )
     return;
-
+printf ( "%s : %d > \n", __FUNCTION__, __LINE__ );
   int  iLen  = m_pFile->readBlock ( data, BLOCK_LEN );
   if ( iLen != -1 )  {
     m_pSocket->writeBlock ( data, iLen );
@@ -609,7 +668,7 @@ void Client::sendNextPacket ( )
   }
 }
 
-void Client::sendVersionAndHostRequest ( )
+bool Client::sendVersionAndHostRequest ( )
 {
   char cHostName[1024];
   gethostname ( (char *)&cHostName, 1024 );
@@ -620,7 +679,7 @@ void Client::sendVersionAndHostRequest ( )
   stream << qsHostName;
   m_pSocket->flush ( );
   debug_out ( "Client::sendVersionAndHostRequest <0x%04X>\n", CLIENT_WHO_AND_WHERE_ARE_YOU );
-  m_waiter.wait    ( );
+  return m_waiter.wait ( 30000 ); // wait for 30 seconds max
 }
 
 void Client::socketConnected ( )
@@ -662,7 +721,8 @@ void Client::startServer ( )
          qsCommand = "qrender";
   }
   qsCommand += " -v 5";
-  system ( qsCommand.ascii ( ) );
+  int iRet = system ( qsCommand.ascii ( ) );
+  iRet = iRet; // quiet down the compiler.
   // Wait a second and then try to re-connect
   QTimer::singleShot ( 1000, this, SLOT ( slotReconnect ( ) ) );
 }
@@ -672,7 +732,8 @@ void Client::restartServer ( )
   for ( int t=0; t<3; t++ )  {
     // if no connection after three attempts, then restart the server ...
     slotReconnect ( );
-    if ( m_pSocket->state ( ) == QSocket::Connected )  {
+    if ( ( m_pSocket->state ( ) == QSocket::Connected  ) ||
+         ( m_pSocket->state ( ) == QSocket::Connecting ) ) {
        return;
     }
     usleep ( 1000000 );  // Now wait a second ...
@@ -706,6 +767,15 @@ void Client::run ( )
   CXmlSlideshow *pSlideshow = m_pSourceFileEntry->listFileInfos[0]->pSlideshow;
   if ( ! pSlideshow )
     return;
+
+ slotReconnect ( );
+ if ( m_pSocket->state ( ) == QSocket::Idle )  {
+      startServer  ( );
+      usleep ( 10000 );  // give it 10 milli seconds
+  }
+  // Now that the connection is/should be established, we can start the Keepalive - timer.
+  enableTimer   ( true );
+
   debug_out ( "Client::run \n" );
 
   int iCounter = 0;
@@ -718,9 +788,16 @@ void Client::run ( )
     }
   }
 
-  sendVersionAndHostRequest ( );
+  if ( ! sendVersionAndHostRequest ( ) )  {
+    // Timed out, Assume local host.
+    debug_out ( "Client::run After 30 seconds : did not receive ServerVersionAndHost response\n" );
+    m_bRemoteServer = false;
+    m_waiter.wakeAll ( );
+  }
 
-  QString qsFileName = theUtils.getTempFile ( pSlideshow->slideshow_name + ".xml" );
+  QString qsFileName = pSlideshow->slideshow_name;
+  qsFileName.replace ( "/", "_" );
+  qsFileName = theUtils.getTempFile ( qsFileName + ".xml" );
   pSlideshow->writeXml ( qsFileName );
 
   QDataStream stream   (  m_pSocket );
@@ -734,7 +811,7 @@ void Client::run ( )
     // Another process is already creating the slideshow.
     iCounter = 0;
     while ( iCounter < 50 )  {
-      if  ( m_waiter.wait  ( 100 ) )
+      if  ( m_waiter.wait ( 100 ) )
             iCounter = 50;
     }
 
@@ -762,6 +839,7 @@ void Client::run ( )
 
   debug_out ( "Client::run Get the server to work ... msgID<0x%04X>\n",  CLIENT_GO_TO_WORK );
   m_pSocket->flush ( );
+  setWaiting ( false );
 }
 
 void Client::lock ( )
@@ -800,14 +878,10 @@ void Client::setWaiting ( bool bWaitInQueue )
 
 void Client::displayProgress ( )
 {
-  static float fProgress = -1.0f;
-  if ( fabs ( m_fProgress - fProgress ) >= 1.0f )  {
-    // QDVDAuthor::customEvent will call progress() to determinte the current progress.
-    QCustomEvent *pNewEvent = new QCustomEvent ( EVENT_RENDER_PROGRESS );
-    pNewEvent->setData      ( (void *) this );
-    QApplication::postEvent ( Global::pApp, pNewEvent );
-    fProgress = m_fProgress;
-  }
+  // QDVDAuthor::customEvent will call progress() to determinte the current progress.
+  QCustomEvent *pNewEvent = new QCustomEvent ( EVENT_RENDER_PROGRESS );
+  pNewEvent->setData      ( (void *) this );
+  QApplication::postEvent ( Global::pApp, pNewEvent );
 }
 
 Q_UINT64 Client::fileFromSocket ( )
