@@ -814,7 +814,7 @@ bool ShadowObject::filterColorKeys ( QImage &theShadow )
 
   // Next we create the min/max Color keys, to check if we ought to filter the pixel out or not
   ImageManipulator *pManipulator = &pImageObject->manipulator ( );
-  QImage theImage   = pImageObject->pixmap ( ).convertToImage ( );
+  QImage theImage   = pImageObject->image ( );
   QValueList<QColor *>listColorKeyMin;
   QValueList<QColor *>listColorKeyMax;
   QColor *pColorMin, *pColorMax, theColor, targetColor;
