@@ -130,7 +130,7 @@ TranscodeInterface::TranscodeInterface ()
 	iAudioBitrate = 0;
 	iSample       = 0;
 	iStartingAt   = 0;
-	iEndingAt     = 1000000;  // defaulting to a large number ...
+	iEndingAt     = 1000000000;  // defaulting to a large number (1.000.000 sec)...
 	bTranscoding  = false;
 	bRemuxOnly    = false; 
 	iSubtitleFromMetaInfo = -1;
@@ -515,7 +515,9 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
     SourceFileInfo *pInfo = listFileInfos[0];
     if ( pInfo->pSlideshow )  {
       Utils theUtils;
-      QString qsFileName = theUtils.getTempFile ( pInfo->pSlideshow->slideshow_name + ".vob" );
+      QString qsFileName = pInfo->pSlideshow->slideshow_name;
+      qsFileName.replace ( "/", "_" );
+      qsFileName = theUtils.getTempFile ( qsFileName + ".vob" );
       QFileInfo fileInfo ( qsFileName );
       if ( ! fileInfo.exists ( ) ) { // generated file does not exist.
         bIsSlideshow = true;
@@ -977,7 +979,7 @@ SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
   bMetaSubtitles = theOther.bMetaSubtitles;
   if (theOther.pTranscodeInterface)	{
     if (!pTranscodeInterface)
-      pTranscodeInterface = new TranscodeInterface ();
+      pTranscodeInterface  = new TranscodeInterface ();
     *(pTranscodeInterface) = *(theOther.pTranscodeInterface);
   }
   else if ( pTranscodeInterface )	{
@@ -1000,6 +1002,14 @@ SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
     }
   }
 
+  if ( pSlideshow )
+    delete pSlideshow;
+  pSlideshow = NULL;
+  if ( theOther.pSlideshow )  {
+     pSlideshow = new CXmlSlideshow;
+    *pSlideshow = *theOther.pSlideshow;
+  }
+
   return *this;
 }
 
