@@ -20,9 +20,10 @@
 
 #include "subtitles.h"
 
+class QImage;
 class QDomNode;
 class QDomElement;
-class QImage;
+class CXmlSlideshow;
 
 #define MAX_AUDIO 8
 
@@ -94,6 +95,9 @@ public:
 	~SourceFileInfo ( );
 
 	SourceFileInfo & operator = (SourceFileInfo &);
+	bool readProjectFile    ( QDomNode & );
+	bool writeProjectFile   ( QDomElement &, bool b=false );
+
 	QString getFileName     ( );
 	int     audioCount      ( );
 	void    deleteAudio     ( );
@@ -132,6 +136,7 @@ public:
 	TranscodeInterface *pTranscodeInterface;
 	Subtitles  *arraySubtitles[ MAX_SUBTITLES ];
 	Audio      *arrayAudio    [ MAX_AUDIO ];
+	CXmlSlideshow *pSlideshow;  // This is set through DialogImages. One SourceGroup = 1 SourceFileEntry with SourceFileInfo
 };
 
 // Note if the entry is a dvd-slideshow, then the qsDisplayName will end in .xml
