@@ -29,6 +29,7 @@
 
 #include <qapplication.h>
 #include <qinputdialog.h>
+#include <qradiobutton.h>
 #include <qmainwindow.h>
 #include <qfiledialog.h>
 #include <qpushbutton.h>
@@ -309,7 +310,7 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
   for (t=0;t<m_listSourceFileEntries.count();t++)	{
     if (pItem->text(SOURCE_FILE_ENTRY_NAME) == m_listSourceFileEntries[t]->qsDisplayName)	{
       if (m_listSourceFileEntries[t]->bIsSlideshow)
-	bShow = false;
+        bShow = false;
       pSourceFileEntry = m_listSourceFileEntries[t];
       break;
     }
@@ -319,29 +320,30 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
   SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
   if ( pEntry ) {
     if ( pEntry->bSoundSource ) {
-      pMenu->insertItem ( tr ("Proprties ..."),        this, SLOT ( slotEditAudio     ( ) ) );
+      pMenu->insertItem ( tr ("Proprties ..."),           this, SLOT ( slotEditAudio      ( ) ) );
     }
     else {
       SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
       // Not a sound source
       if (bShow)
-	pMenu->insertItem ( tr ("&Play"),               this, SLOT ( slotPlayMovie     ( ) ) );
+        pMenu->insertItem ( tr ("&Play"),                 this, SLOT ( slotPlayMovie      ( ) ) );
 
       if ( pInfo->pSlideshow ) // If the movie was created through a slideshow ...
-        pMenu->insertItem ( tr ( "&Slideshow" ),        this, SLOT ( slotEditSlideshow ( ) ) );
-      pMenu->insertItem   ( tr ("P&roperties ..."),     this, SLOT ( slotEditMovie     ( ) ) );
+        pMenu->insertItem ( tr ( "&Slideshow" ),          this, SLOT ( slotEditSlideshow  ( ) ) );
+      pMenu->insertItem   ( tr ( "P&roperties ..." ),     this, SLOT ( slotEditMovie      ( ) ) );
       if ( pSourceFileEntry && (pSourceFileEntry->listFileInfos.count() > 1) ) {
-	pMenu->insertItem ( tr ("&Transcode All ..."),  this, SLOT ( slotTranscodeAll  ( ) ) );
-	pMenu->insertItem ( tr ("&Disable Transcode" ), this, SLOT ( slotTranscodeNone ( ) ) );
-	pMenu->insertItem ( tr ("&All to titleset ..."),this, SLOT ( slotAllToTitleset ( ) ) );
+        pMenu->insertItem ( tr ( "&Transcode All ..." ),  this, SLOT ( slotTranscodeAll   ( ) ) );
+        pMenu->insertItem ( tr ( "&Disable Transcode" ),  this, SLOT ( slotTranscodeNone  ( ) ) );
+        pMenu->insertItem ( tr ( "&All to titleset ..." ),this, SLOT ( slotAllToTitleset  ( ) ) );
+        pMenu->insertItem ( tr ( "Thumbnails ..." ),      this, SLOT ( slotSFEThumbnailing( ) ) );
       }
       else if ( !pSourceFileEntry ) { // Here we handle if the user clicked on a SourceFileInfo
-	SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
-	if ( pInfo && pInfo->listChapters.count ( ) > 2 )
-	  pMenu->insertItem ( tr ( "Thumbnails ..." ), this, SLOT (slotThumbnailing ( ) ) );
+        SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
+        if ( pInfo && pInfo->listChapters.count ( ) > 2 )
+          pMenu->insertItem ( tr ( "Thumbnails ..." ),    this, SLOT ( slotThumbnailing   ( ) ) );
       }
       else {
-	pMenu->insertItem ( tr ("Assign to titleset ..." ),this, SLOT(slotAllToTitleset ( ) ) );
+        pMenu->insertItem ( tr ("Assign to titleset ..." ),this, SLOT( slotAllToTitleset  ( ) ) );
       }
 //      pMenu->insertItem ( tr ( "Add to new Submenu" ), this, SLOT(slotToNewSubmenu  ( ) ) );
 //      // the next item is only valid for SourceFileEntries and not for SourceFileInfos.
@@ -382,6 +384,21 @@ void SourceToolBar::slotSetThumbnail ( long iMSecOffset )
   }
 }
 
+void SourceToolBar::slotSFEThumbnailing ( )
+{
+  SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
+  if ( ! pEntry )
+    return;
+
+  if ( ! m_pThumbnailDialog )
+    m_pThumbnailDialog = new DialogThumbnail ( m_pDVDAuthor );
+
+  m_pThumbnailDialog->initSourceFileEntry ( pEntry );
+
+  if ( ! m_pThumbnailDialog->isVisible ( ) )
+         m_pThumbnailDialog->show ( );
+}
+
 void SourceToolBar::slotThumbnailing ( )
 {
   QFileInfo fileInfo;
@@ -771,7 +788,7 @@ void SourceToolBar::setAudioTranscode ( SourceFileInfo *pInfo )
 
 bool SourceToolBar::checkRightFileFormat ( SourceFileInfo *pInfo )
 {
-  Utils     theUtil;
+  Utils theUtil;
   // this function will check if we have a VOB stream.
   // if not, if we have a Mpeg2 stream
   // if not the set transcode parameters for this SourceFileInfo - object.
@@ -788,7 +805,7 @@ bool SourceToolBar::checkRightFileFormat ( SourceFileInfo *pInfo )
   // Also if there is already a TranscodeInterface defined, then keep our hands off !!!
   if ( pInfo->pTranscodeInterface ) 
     return true;
-  
+
   QFileInfo fileInfo ( pInfo->qsFileName );
   int       iWidth, iHeight;
   // Everything else needs to be transcoded !!!
@@ -1210,7 +1227,7 @@ void SourceToolBar::slotAddSlideshow ( )
   if ( fileDialog.exec ( ) == QDialog::Rejected )
     return;
 
-  CXmlSlideshow             *pXmlSlideshow;
+  CXmlSlideshow   *pXmlSlideshow;
   SourceFileEntry *pEntry;
   SourceFileInfo  *pInfo;
   QValueList<CXmlSlideshow *>newList = fileDialog.getSlideshows ( );
@@ -1220,9 +1237,9 @@ void SourceToolBar::slotAddSlideshow ( )
     pXmlSlideshow = *it++;
     pEntry = sourceFileEntry ( pXmlSlideshow );
     pInfo  = pEntry ? pEntry->listFileInfos[0] : NULL;
-    if ( pXmlSlideshow->countImg ( ) < 1 )  {
+    if ( pXmlSlideshow->count ( ) < 1 )  {
       // No more images in the slideshow
-//      delete pXmlSlideshow; done in desstructor of GroupView
+//      delete pXmlSlideshow; done in destructor of GroupView
       if ( pEntry && pInfo )  {
            if ( pInfo->pSlideshow )
                 delete pInfo->pSlideshow;
@@ -1241,12 +1258,18 @@ void SourceToolBar::slotAddSlideshow ( )
     if ( pEntry && pInfo )  {
       CXmlSlideshow *pSlideshow = pInfo->pSlideshow;
       if ( ! ( *pSlideshow == *pXmlSlideshow ) )  {
-         Render::Manager::unregisterEntry  (  pEntry );
+         Render::Manager::unregisterEntry ( pEntry );
+
+         // In case the Slideshow name has changed. We need to also change the file name.
+         QString qsFileName = pXmlSlideshow->slideshow_name;
+         qsFileName.replace ( "/", "_" );
+         pInfo->qsFileName    = theUtil.getTempFile ( qsFileName + ".vob" );
          pEntry->bIsSlideshow = true;
 
         *pSlideshow = *pXmlSlideshow;
-
-         Render::Manager::registerEntry    (  pEntry );
+         updateSlideshowItem ( pEntry );
+//pSlideshow->writeXml ( );
+         Render::Manager::registerEntry ( pEntry );
       }
       continue;
     }
@@ -1254,12 +1277,64 @@ void SourceToolBar::slotAddSlideshow ( )
   }
 }
 
+void SourceToolBar::updateSlideshowItem ( SourceFileEntry *pEntry )
+{
+  if ( ! pEntry )
+    return;
+
+  QString qsInfo;
+  Utils theUtils;
+  QFileInfo fileInfo;
+  unsigned int t, iLength;
+  bool bPal = false;
+  CXmlSlideshow::vid_struct *pXmlVid;
+  ListViewItemMedia *pItem = getItem ( pEntry );
+  SourceFileInfo    *pInfo = pEntry->listFileInfos[0];
+  CXmlSlideshow     *pXmlSlideshow = pInfo ? pInfo->pSlideshow : NULL;
+
+  if ( ( ! pXmlSlideshow ) || ( ! pItem ) )
+    return;
+
+  // First we parse the current Entry name and adjust it if required.
+  if ( pEntry->qsDisplayName.find ( " - " ) > 0 )  {
+    QString qsTemp = pEntry->qsDisplayName.left ( pEntry->qsDisplayName.find ( " - " ) + 3 );
+    pEntry->qsDisplayName = qsTemp + pXmlSlideshow->slideshow_name.ascii ( );
+  }
+  else
+    pEntry->qsDisplayName.sprintf ( "[%02d] - %s", getFreeSourceSlot ( ), pXmlSlideshow->slideshow_name.ascii ( ) );
+
+  // Next we determine if we have PAL or NTSC
+  if ( pInfo->qsVideoFormat.find ( "pal", 0, FALSE ) > -1 )
+       bPal = true;
+
+  iLength = (unsigned int) ( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
+  for ( t=0; t<pXmlSlideshow->countVid ( ); t++ )  {
+    pXmlVid  = pXmlSlideshow->getVid  ( t );
+    if ( pXmlVid )
+         iLength += (unsigned int)( pXmlVid->length + 1000 * pXmlSlideshow->filter_delay );
+  }
+  pInfo->qsLength = theUtils.getStringFromMs ( iLength );
+
+  fileInfo.setFile ( pInfo->qsFileName );
+  qsInfo = QString ( fileInfo.fileName ( ) + QString ( "\n" ) + pInfo->qsLength );
+
+  pItem->setText ( 0, bPal ? "pal" : "ntsc" );
+  pItem->setText ( 1, pEntry->qsDisplayName );
+
+  pItem = (ListViewItemMedia *)pItem->firstChild ( );
+  if ( pItem )
+       pItem->setText ( 1, qsInfo );
+}
+
 SourceFileEntry *SourceToolBar::entryFromSlideshow ( CXmlSlideshow *pXmlSlideshow )
 {
-  Utils theUtils;
+  QString qsFileName;
+  Utils   theUtils;
+  CXmlSlideshow::vid_struct *pXmlVid;
   CXmlSlideshow::img_struct *pXmlImage;
   SourceFileEntry *pEntry;
   SourceFileInfo  *pInfo;
+  unsigned int t, iLength = 0;
 
   pXmlImage = pXmlSlideshow->getImg ( 0 );
 
@@ -1274,14 +1349,23 @@ SourceFileEntry *SourceToolBar::entryFromSlideshow ( CXmlSlideshow *pXmlSlidesho
 
   bool bPAL = ( pXmlSlideshow->yres == 576 );
   pInfo = new SourceFileInfo;
-  pInfo->qsFileName    = theUtils.getTempFile ( pXmlSlideshow->slideshow_name + ".vob" );
+  qsFileName = pXmlSlideshow->slideshow_name;
+  qsFileName.replace ( "/", "_" );
+  pInfo->qsFileName    = theUtils.getTempFile ( qsFileName + ".vob" );
   pInfo->pSlideshow    = new CXmlSlideshow;
  *pInfo->pSlideshow    = *pXmlSlideshow;
 
   pInfo->qsVideoFormat = bPAL ? "PAL" : "NTSC";
   pInfo->qsFPS         = bPAL ?  "25" : "29.97";
   pInfo->qsResolution  = QString ( "%1x%2" ).arg ( pXmlSlideshow->xres ).arg ( pXmlSlideshow->yres );
-  pInfo->qsLength      = theUtils.getStringFromMs ( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
+  iLength              = (unsigned int)( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
+  for ( t=0; t<pXmlSlideshow->countVid ( ); t++ )  {
+    pXmlVid =  pXmlSlideshow->getVid  ( t );
+    if ( pXmlVid )
+         iLength      += (unsigned int)( pXmlVid->length + 1000 * pXmlSlideshow->filter_delay );
+  }
+
+  pInfo->qsLength      = theUtils.getStringFromMs ( iLength );
   pInfo->qsRatio       = "4:3";
 
   pInfo->pPreview   = new QImage ( theImage );
@@ -1365,19 +1449,46 @@ void SourceToolBar::editSourceFileInfo ( SourceFileInfo  *pSourceFileInfo )
 
 void SourceToolBar::slotEditSlideshow ( )
 {
-  SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
-  CXmlSlideshow *pSlideshow = pInfo->pSlideshow;
+  SourceFileInfo *pInfo      = getCurrentSourceFileInfo  ( );
+  CXmlSlideshow  *pSlideshow = pInfo->pSlideshow;
 
+  Utils  theUtils;
   Input::DialogSlideshow theDialog ( this );
   theDialog.initMe ( pSlideshow, false );
 
-  if ( theDialog.exec ( ) == QDialog::Accepted )  {
-    pSlideshow->slideshow_name = theDialog.m_pEditName->text  ( );
-    pSlideshow->background     = theDialog.background ( );
-    pSlideshow->audio_list     = theDialog.audioList  ( );
-    pSlideshow->delay          = theDialog.m_pSpinImageDelay->value    ( );
-    pSlideshow->filter_delay   = theDialog.m_pSpinFilterDelay->value   ( );
-    pSlideshow->intro_page     = theDialog.m_pCheckIntroPage->isChecked( );
+  if ( theDialog.exec ( ) ==  QDialog::Accepted ) {
+    bool bChecked   = pSlideshow->imgBkgImg   ( );
+    bool bPal       = ( theDialog.m_pComboFormat->currentItem ( ) == 1 );
+    bool bIsTheSame = ( ( pSlideshow->slideshow_name   == theDialog.m_pEditName->text  ( ) ) &&
+                        ( pSlideshow->background       == theDialog.background         ( ) ) &&
+                        ( pSlideshow->audio_list       == theDialog.audioList          ( ) ) &&
+                        ( pSlideshow->validFilterNames == theDialog.filterList         ( ) ) &&
+                        ( pSlideshow->delay            == theDialog.m_pSpinImageDelay->value     ( ) ) &&
+                        ( pSlideshow->filter_delay     == theDialog.m_pSpinFilterDelay->value    ( ) ) &&
+                        ( pSlideshow->intro_page       == theDialog.m_pCheckIntroPage->isChecked ( ) ) &&
+                        ( bChecked                     == theDialog.m_pRadioImgBkgImg->isChecked ( ) ) &&
+                        ( bPal  == ( theUtils.getFormat ( pSlideshow->xres, pSlideshow->yres ) > FORMAT_NTSC4 ) ) );
+    pSlideshow->slideshow_name   = theDialog.m_pEditName->text  ( );
+    pSlideshow->background       = theDialog.background ( );
+    pSlideshow->audio_list       = theDialog.audioList  ( );
+    pSlideshow->validFilterNames = theDialog.filterList ( );
+    pSlideshow->delay            = theDialog.m_pSpinImageDelay->value     ( );
+    pSlideshow->filter_delay     = theDialog.m_pSpinFilterDelay->value    ( );
+    pSlideshow->intro_page       = theDialog.m_pCheckIntroPage->isChecked ( );
+    pSlideshow->setImgBkgImg     ( theDialog.m_pRadioImgBkgImg->isChecked ( ) );
+    pSlideshow->xres             = 720;
+    pSlideshow->yres             = bPal ? 576 : 480;
+
+    if ( ! bIsTheSame )  {
+      SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
+      // Re-render the slideshow if different
+      if ( pEntry && pInfo )  {
+        Render::Manager::unregisterEntry  ( pEntry );
+        pEntry->bIsSlideshow = true;
+//pSlideshow->writeXml ( );
+        Render::Manager::registerEntry    ( pEntry );
+      }
+    }
   }
 }
 
