@@ -89,29 +89,30 @@ private:
 	void *getMediaEngine          ( );
 	void  importChapters          ( QString, SourceFileInfo * );
 	void  updateEntryHeader       ( SourceFileEntry * );
+	void  updateSlideshowItem     ( SourceFileEntry * );
 	void  setAudioTranscode       ( SourceFileInfo  * );
 
 public slots:
 	virtual void slotDoubleClickedOnVideoList( QListViewItem *, const QPoint &, int );
 	virtual void slotRightClickedOnVideoList ( QListViewItem *, const QPoint &, int );
 	virtual void slotClickedOnVideoList      ( QListViewItem *, const QPoint &, int );
-	virtual void slotPlayMovie    ( );
-	virtual void slotEditMovie    ( );
-	virtual void slotEditSlideshow( );
-	virtual void slotEditAudio    ( );
-	virtual void slotDeleteSource ( );
-	virtual void slotTranscodeAll ( );
-	virtual void slotTranscodeNone( );
-	virtual void slotAllToTitleset( );
-	virtual void slotToNewSubmenu ( );
-	virtual void slotAddMovieOld  ( );
-	virtual void slotAddMovie     ( );
-	virtual void slotAddSound     ( );
-	virtual void slotAddSlideshow ( );
-	virtual void slotThumbnailing ( );
-	virtual void slotSetThumbnail ( long );
-//	virtual void slotAddSlideshow ( QString );
-	virtual void slotRemoveEntry  ( SourceFileEntry * );
+	virtual void slotPlayMovie       ( );
+	virtual void slotEditMovie       ( );
+	virtual void slotEditSlideshow   ( );
+	virtual void slotEditAudio       ( );
+	virtual void slotDeleteSource    ( );
+	virtual void slotTranscodeAll    ( );
+	virtual void slotTranscodeNone   ( );
+	virtual void slotAllToTitleset   ( );
+	virtual void slotToNewSubmenu    ( );
+	virtual void slotAddMovieOld     ( );
+	virtual void slotAddMovie        ( );
+	virtual void slotAddSound        ( );
+	virtual void slotAddSlideshow    ( );
+	virtual void slotThumbnailing    ( );
+	virtual void slotSFEThumbnailing ( );
+	virtual void slotSetThumbnail    ( long );
+	virtual void slotRemoveEntry     ( SourceFileEntry * );
 
 private:
 	uiSourceWidget    *m_pSourceWidget;
