@@ -27,7 +27,7 @@
 #include "sourcefileentry.h"
 #include "subtitles.h"
 #include "qplayer/mediacreator.h"
-	 
+
 SubtitleEntry::SubtitleEntry ( )
 {
   m_iSubtitleNumber = -1;
@@ -66,12 +66,12 @@ Subtitles::Subtitles ()
   //m_subColors[3]    = Rgba ( START_FRAME_COLOR       );
 
   m_iSubtitleNumber = 0;
-  m_bFit            = false;
+  m_bFit            = true;
   m_iOutline        = 2; // Default to outline with a shadow of 2 pixels...
   m_bTextSubtitles  = false; // default to image based subtitles (render subtitles in this class)
   m_iTextFontSize   = 24;
   m_qsTextFont      = "Vera";
-  m_alignment       = QPoint ( 1, 1 ); // HAlign=Center / VAlign=bottom
+  m_alignment       = QPoint ( 1, 3 ); // HAlign=Center / VAlign=top
   m_subtitleState   = STATE_MANUAL;
   m_rect            = QRect ( 0, 0, 720, 480 ); // standard NTSC res.
 }
@@ -101,7 +101,7 @@ Subtitles &Subtitles::operator = ( Subtitles &theOther )
 
   for ( t=0;t<MAX_SUBTITLE_COLORS;t++)
     m_subColors[t] = theOther.m_subColors[t];
-  
+
   if ( m_listOfSubtitles.count () ) {
     for ( t=0;t<theOther.m_listOfSubtitles.count();t++) 
       delete m_listOfSubtitles[t];
@@ -194,7 +194,7 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
 	m_subColors[t].setAlpha ( list[t].toInt ( ) );
     }
   }
-  
+
   infoNode = theElement.firstChild ();  
   while (!infoNode.isNull())	{
     infoElement = infoNode.toElement();
@@ -328,7 +328,7 @@ QRect Subtitles::getSubtitlesRect ( QString &qsResolution )
   if ( iFontSize == -1 ) {
        iFontSize = m_font.pixelSize ();
        if ( iFontSize == -1 )
-	    iFontSize = 24;
+            iFontSize =  24;
   }
   iFontSize *= 3;
 
@@ -341,11 +341,11 @@ QRect Subtitles::getSubtitlesRect ( QString &qsResolution )
 
   theRect = m_rect;
   // Try to figure out if the user was too lazy to input values ...
-  if ( ( m_rect.x() == 0 ) && ( m_rect.y() == 0 ) ) {
-    if ( ( ( m_rect.width  () == iVideoWidth  ) && 
-	   ( m_rect.height () == iVideoHeight )  ) ||   // rect == video's rect
-	 ( ( m_rect.width  () == 0            ) && 
-	   ( m_rect.height () == 0            )  )  ) { // or rect is empty
+  if ( ( m_rect.x() == 0 ) && ( m_rect.y() == 0 )  ) {
+    if ( ( ( m_rect.width  ( ) == iVideoWidth   ) &&
+           ( m_rect.height ( ) == iVideoHeight  )  ) ||   // rect == video's rect
+         ( ( m_rect.width  ( ) == 0             ) &&
+           ( m_rect.height ( ) == 0             )  )  ) { // or rect is empty
       theRect = QRect ( 0, iVideoHeight - 45 - iFontSize, iVideoWidth, iFontSize );
     }
   }
@@ -407,9 +407,9 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   QFileInfo fileInfo ( qsFileInfoName );
   iTotalCount = (int)m_listOfSubtitles.count ( );
 
-  // The following widgets will create th progress dialog on the fly.
+  // The following widgets will create the progress dialog on the fly.
   if ( iTotalCount > 20 ) { // no progress for only a few subtitles.
-    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog ); //, 1, 1 ); //, 11, 6, "progressWidgetLayout" );
+    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );
     pProgressBar = new QProgressBar ( &progressDialog );
     pProgressLayout->addWidget( pProgressBar, 0, 0 );
     progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
@@ -430,14 +430,10 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   if ( iHeight < 240 )
        iHeight = 480;
 
-  // get the rect for the subtitles. Try to be clever about it.
-  theRect = getSubtitlesRect ( qsResolution );
-  // If we have user input we should abide by it
-  if ( ( m_rect.x ( ) == 0 ) && ( m_rect.y ( ) == 0 ) )
-    m_rect  = theRect;
-  else
     theRect = m_rect;
 
+//printf ( "%s::%d > theRect<%d,%d x x%d,%d> m_rect<%d,%d x %d,%d>\n", __FUNCTION__, __LINE__, theRect.x ( ), theRect.y ( ), theRect.width ( ), theRect.height ( ), m_rect.x ( ), m_rect.y ( ), m_rect.width ( ), m_rect.height ( ) );
+
   // Now we do some magic with colors ...
   // we will set the Background Color to be completely GREEN
   // and we set the foreground color to be completely RED
@@ -453,7 +449,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   int   iMaxColors = MAX_SUBTITLE_COLORS - 2;
   float fDelta   = (float)0xFF / (iMaxColors+1);
   int   iBGRed, iBGGreen, iBGBlue, iRed, iGreen, iBlue, iTransparency;
-  for ( t=0;t<iMaxColors;t++ ) {
+  for ( t=0; t<iMaxColors; t++ )  {
     iGreen  = (int)((t+1) * fDelta);
     iRed    = 255 - iGreen;
     colors[t+2] = ( iRed << 16 ) + ( iGreen << 8 );
@@ -461,7 +457,31 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
   QRect boundingRect;
   QPen  thePen ( colors[1], 2, Qt::DashDotLine );
-  int   iFlags = Qt::DontClip|Qt::WordBreak|Qt::AlignHCenter|Qt::AlignVCenter;
+  int   iFlags = Qt::DontClip | Qt::WordBreak;
+
+  switch   ( m_alignment.x ( ) ) {
+  case 2:
+    iFlags |= Qt::AlignLeft;
+    break;
+  case 3:
+    iFlags |= Qt::AlignRight;
+    break;
+  case 4:
+    iFlags |= Qt::AlignJustify;
+    break;
+  default:
+    iFlags |= Qt::AlignHCenter;
+  }
+  switch   ( m_alignment.y ( ) )  {
+  case 3:
+    iFlags |= Qt::AlignTop;
+  break;
+  case 4:
+    iFlags |= Qt::AlignBottom;
+  break;
+  default:
+    iFlags |= Qt::AlignVCenter;
+  }
 
   iTotalCount = (int)m_listOfSubtitles.count ();
   // Processing some Qt events / messages
@@ -485,7 +505,10 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     theUtils.reduceColors ( theBrush, 2, (QRgb *)&colors );
   }
 
-  for (t=0;t<iTotalCount; t++) {
+  iWidth  = m_rect.width  ( );
+  iHeight = m_rect.height ( );
+  for ( t=0; t<iTotalCount; t++ )  {
+    theRect = m_rect;
     pEntry  = m_listOfSubtitles[t];
     qsStart = pEntry->qsTimeStart;
     qsStart.remove ( ":"      );
@@ -501,40 +524,35 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
       thePainter.setFont  ( m_font );
 
       // Here we draw onto the drawing board
-      thePainter.drawText ( theRect, iFlags, pEntry->qsText, -1, &boundingRect );
+      QRect temp ( 0, 0, iWidth, iHeight );
+      thePainter.drawText ( temp, iFlags, pEntry->qsText, -1, &boundingRect );
 
-      int x, y, w, h, d;
-      d = boundingRect.height ( ) - theRect.height ( );
-      x = theRect.x ( ); // should be 0
-      y = theRect.y ( );
+      int x, y, w, h;
+      x = 0;
+      y = 0;
       w = theRect.width  ( ); // should be iWidth
       h = theRect.height ( ); // should be iHeight
       // We should always adjust the height
       if ( m_bFit ) {
-	w = boundingRect.width  ( );
-	h = boundingRect.height ( );
-	y = theRect.y ( ) - (int)( (float)d / 2.0 );
-
-	switch ( m_alignment.x ( ) ) {
-	case 2:
-	case 4:
-	  x = 0;
-	  break;
-	case 3:
-	  x = iWidth - w;
-	  break;
-	default:
-	  x = (int)( ( iWidth - w ) / 2.0 );
-	}
+        x = boundingRect.x      ( ) - m_iOutline;
+        y = boundingRect.y      ( ) - m_iOutline;
+        w = boundingRect.width  ( ) + m_iOutline * 2;
+        h = boundingRect.height ( ) + m_iOutline * 2;
+        if ( x <  0 )       x = 0;
+        if ( y <  0 )       y = 0;
+        if ( w >= iWidth  ) w = iWidth -1;
+        if ( h >= iHeight ) h = iHeight-1;
+        theRect = QRect ( x + theRect.x ( ), y + theRect.y ( ), w, h );
       }
-      pEntry->rect = QRect ( x, y, w, h );
+      pEntry->rect = theRect; //QRect ( x, y, w, h );
+//printf ( "%s::%d >   <%s> bFit<%d> w<%d> h<%d> pEntry->rect<%d,%d x %d,%d> boundingRect<%d,%d x %d,%d> XYWH<%d,%d x %d,%d>\n", __FUNCTION__, __LINE__, pEntry->qsText.ascii(), m_bFit, iWidth, iHeight, theRect.x(), theRect.y(), theRect.width(), theRect.height(), boundingRect.x ( ), boundingRect.y ( ), boundingRect.width ( ), boundingRect.height ( ), x, y, w, h );
 
       // create new dimensioned pixmap
       QPixmap thePixmap = QPixmap ( w, h );
 #if ( QT_VERSION > 0x0301FF )
-      copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, (int)( ( iWidth - w ) / 2.0 ), y, w, h );
+      copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h );
 #else
-      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, (int)( ( iWidth - w ) / 2.0 ), y, w, h, Qt::CopyROP);
+      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP);
 #endif
       theImage = thePixmap.convertToImage ();
     }  thePainter.end ();
@@ -588,26 +606,26 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
       int pIdx;
       for ( x=0; x<w; x++ ) {
-	for ( y=0; y<h; y++ ) { // Image x, and y ...
-	  // here we take m_iOutline number of pixels before and after an set them to the fourth color.
-	  pIdx = theImage.pixelIndex ( x, y );
-	  if ( ( pIdx == 1 ) || ( pIdx == 2 ) ) { // not background
-	    // So we should underlay the brush ...
-	    for ( yb=0; yb<iDiameter; yb++ ) { // copy brush over ...
-	      brushY = y - m_iOutline + yb;
-	      if ( ( brushY < 0 ) || ( brushY >= h ) )  // out of bounds
-		continue;
-	      for ( xb=0; xb<iDiameter; xb++ ) {
-		brushX = x - m_iOutline + xb; 
-		if ( ( brushX < 0 ) || ( brushX >= w ) ) // out of bounds
-		  continue;
-		idx = theImage.pixelIndex ( brushX, brushY );
- 		if ( ( idx == 0 ) && ( theBrush.pixelIndex ( xb, yb ) == 1 ) )
-		  theImage.setPixel   ( brushX, brushY, 3 );
-	      }
-	    }
-	  }
-	}
+        for ( y=0; y<h; y++ ) { // Image x, and y ...
+          // here we take m_iOutline number of pixels before and after an set them to the fourth color.
+          pIdx = theImage.pixelIndex ( x, y );
+          if ( ( pIdx == 1 ) || ( pIdx == 2 ) ) { // not background
+            // So we should underlay the brush ...
+            for ( yb=0; yb<iDiameter; yb++ ) { // copy brush over ...
+              brushY = y - m_iOutline + yb;
+              if ( ( brushY < 0 ) || ( brushY >= h ) )  // out of bounds
+                continue;
+              for ( xb=0; xb<iDiameter; xb++ ) {
+                brushX = x - m_iOutline + xb; 
+                if ( ( brushX < 0 ) || ( brushX >= w ) ) // out of bounds
+                  continue;
+                idx = theImage.pixelIndex ( brushX, brushY );
+                if ( ( idx == 0 ) && ( theBrush.pixelIndex ( xb, yb ) == 1 ) )
+                  theImage.setPixel   ( brushX, brushY, 3 );
+              }
+            }
+          }
+        }
       }
     }
     theImage.save ( qsFileName, "PNG", 100 );  // 100%== No compression. png image
@@ -615,7 +633,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     if ( ( iTotalCount > 20 ) && ( pProgressBar ) ) {
       pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );
       if ( t%10 == 0 ) 
-	qApp->processEvents ( 100 ); // do some event processing ...
+        qApp->processEvents ( 100 ); // do some event processing ...
     }
   }
   // that's it ...
