@@ -437,7 +437,10 @@ void TemplateDownload::parseIndexFile ( )
 
   if ( ! m_xml.parseXml ( m_qsIndexFile ) ) {
     resetDialog   ( );
-    qsStatus = tr ("Error Parsing index.xml - file from server.<BR>Try again ?" );
+    qsStatus = tr ( "Error Parsing index.xml - file from server.<BR>Try again ?\n" );
+    // Debug info ...
+    //m_pEditConnect->append  ( QString ( "CurrBytes<%1> vs totalBytes<%2>\n" ).arg ( m_iCurrentBytes ).arg ( m_iTotalBytes ) );
+    //m_pEditConnect->append  ( m_qsIndexFile );
     displayStatus ( qsStatus );
     return;
   }
@@ -609,7 +612,7 @@ void TemplateDownload::installTemplates ( )
   QFile file ( qsExecutable );
   qsTemplatePath = "~/.qdvdauthor/";
   if ( m_pRadioSystemWide->isChecked ( ) )
-    qsTemplatePath = PREFIX_DIRECTORY"/share/qdvdauthor/";
+    qsTemplatePath = Global::qsSystemPath + "/share/qdvdauthor/";
   
   if ( file.open( IO_WriteOnly ) ) {
     QTextStream stream( &file );
@@ -668,16 +671,16 @@ void TemplateDownload::installToSystem ( QString &qsCommand, bool bInstallLocall
   connect( m_pNewProcess, SIGNAL ( readyReadStdout ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
   connect( m_pNewProcess, SIGNAL ( readyReadStderr ( ) ), this, SLOT ( slotReadFromProcess ( ) ) );
   connect( m_pNewProcess, SIGNAL ( processExited   ( ) ), this, SLOT ( slotProcessExited   ( ) ) );
-  
+
   if ( ! bInstallLocally ) {
     // the next check is to see if we can find kdesu
     QString qsGuiSU = findGuiSU ( );
     if ( qsGuiSU.isEmpty ( ) ) {
       MessageBox::information (NULL, tr ( "Could not find kdesu, xsu, or gnomesu" ),
         tr ( "Without kdesu, xsu, or gnomesu I can not istall them templates in %1/share/qdvdauthor/.\n").
-	arg ( PREFIX_DIRECTORY ), QMessageBox::Ok ,  QMessageBox::NoButton);
+        arg ( Global::qsSystemPath ), QMessageBox::Ok ,  QMessageBox::NoButton);
       return;
-    }  
+    }
     if (qsGuiSU == QString ("kdesu"))	{
       m_pNewProcess->addArgument ("kdesu");
       m_pNewProcess->addArgument ("-n");
