@@ -259,9 +259,9 @@ void TemplateWizard::refreshComboMenu ()
 	}
 }
 
-void TemplateWizard::initPreview ()
+void TemplateWizard::initPreview ( )
 {
-	m_pLabelPreview->hide();
+	m_pLabelPreview->hide ( );
 
 	// Here we create the mediaEngine for this dialog.
 	MediaInfo *pMediaInfo   = Global::pApp->getMediaInfo ( );
@@ -322,7 +322,7 @@ void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
     if ( iTemplatePath == 1 ) {
       // for the second run we'll get the system wide installed Templates.
       // Note: lcally installed Templates overrule System wide installed Templates.
-      qsPrefixDir = QString ("%1/share/qdvdauthor/%2").arg(PREFIX_DIRECTORY).arg(qsWhichTab);
+      qsPrefixDir = QString ("%1/share/qdvdauthor/%2").arg ( Global::qsSystemPath ).arg(qsWhichTab);
     }
 
     if ( ! theTemplates.exists (qsPrefixDir) ) {
@@ -332,9 +332,9 @@ void TemplateWizard::initTab (QString qsWhichTab, QIconView *pIconView)
 	new QIconViewItem (pIconView, tr ("No %1 templates found.").arg (qsWhichTab));
       return;
     }
-    
+
     pIconView->arrangeItemsInGrid ( grid, TRUE );
-    
+
     theTemplates.cd ( qsPrefixDir, TRUE );
     listTemplates = theTemplates.entryList ( QDir::Dirs, QDir::Name );
     if (listTemplates.count ( ) < 3)	{ // 3 = this dir / parent dir / background file
@@ -400,11 +400,11 @@ void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
     qsType = "transition";
   m_qsPathName =  QString ("%1/.qdvdauthor/%2/%3/").arg( QDir::homeDirPath () ).arg( qsType ).arg(pIconViewItem->text());
   m_bLocalTemplate = true;
-  
+
   // check if this is a local template or a system wide installed template.
   if ( ! theDir.exists ( m_qsPathName ) ) {
     m_bLocalTemplate = false;
-    m_qsPathName = QString ("%1/share/qdvdauthor/%2/%3/").arg(PREFIX_DIRECTORY).arg( qsType ).arg(pIconViewItem->text());
+    m_qsPathName = QString ("%1/share/qdvdauthor/%2/%3/").arg ( Global::qsSystemPath ).arg( qsType ).arg(pIconViewItem->text());
   }
 
   QFileInfo fileInfo ( m_qsPathName + QString ( "thumbnail.mpg" ) );
@@ -630,7 +630,7 @@ QString TemplateWizard::readProjectFile (QString qsFileName, bool bHeaderOnly)
 	QDomAttr attribute;
 
 	QFile templateFile (qsFileName);
-	if ( ! templateFile.open(IO_ReadWrite))
+	if ( ! templateFile.open(IO_ReadOnly))
 		return qsTemplateName;
 	
 	if (!xmlDoc.setContent (&templateFile))	{
@@ -851,7 +851,7 @@ void TemplateWizard::accept ()
 	
 	qsPrefixDir = QString ("%1/.qdvdauthor/").arg( QDir::homeDirPath ( ) );
 	if ( ! m_bLocalTemplate ) 
-	  qsPrefixDir = QString ("%1/share/qdvdauthor/").arg( PREFIX_DIRECTORY );
+	  qsPrefixDir = QString ("%1/share/qdvdauthor/").arg( Global::qsSystemPath );
 
 	m_qsXMLDVDMenu.replace (QString ("+PREFIX_DIRECTORY+"), qsPrefixDir);
 	for ( t=0; t<m_listDropZones.count ( ); t++ )  {
@@ -982,17 +982,21 @@ void TemplateWizard::accept ()
 	// if the menu exist we take this one over
 	DVDMenu *pDVDMenu  = Global::pApp->getSubMenuByName ( m_pComboMenu->currentText ( ) );
 	if ( pDVDMenu )	{
-		qsMenuName = m_pComboMenu->currentText();
-		pDVDMenu->clear ();
-		pDVDMenu->readProjectFile(menuElement, fLoadVersion);
-		pDVDMenu->getInterface()->qsMenuName = qsMenuName;
-		pDVDMenu->setTabLabel (qsMenuName);
-		pDVDMenu->updateDVDMenu();
+		qsMenuName = m_pComboMenu->currentText ( );
+		pDVDMenu->clear ( );
+		pDVDMenu->readProjectFile ( menuElement, fLoadVersion );
+		pDVDMenu->getInterface ( )->iTitleset  = -1;
+		pDVDMenu->getInterface ( )->iMenu      = -1;
+		pDVDMenu->getInterface ( )->qsMenuName = qsMenuName;
+		pDVDMenu->setTabLabel  ( qsMenuName );
+		pDVDMenu->updateDVDMenu( );
 	}
 	else	{ // Otherwise we will create a new menu.
 		pDVDMenu   = new DVDMenu ( Global::pApp );
 		qsMenuName = Global::pApp->getUniqueMenuTitle ( m_pComboMenu->currentText ( ), 0 );
 		pDVDMenu->readProjectFile ( menuElement, fLoadVersion );
+		pDVDMenu->getInterface    ( )->iTitleset  = -1;
+		pDVDMenu->getInterface    ( )->iMenu      = -1;
 		pDVDMenu->getInterface    ( )->qsMenuName = qsMenuName;
 		pDVDMenu->setTabLabel     ( qsMenuName );
 		pDVDMenu->updateDVDMenu   ( );
