@@ -18,11 +18,12 @@
 #include "shared.h"
 #include "server.h"
 #include "parser.h"
+#include "logger.h"
 
-int main(int argc, char *argv[])
+int main ( int argc, char *argv[] )
 {
   QApplication app ( argc, argv );
-
+  Render::Logger logger;
   // The parser class handles user input.
   // We can exit here if QRender is
   // not executed as deamon ( Client-Server )
@@ -32,21 +33,26 @@ int main(int argc, char *argv[])
 
   pid_t iPid = getpid ( );
 
-  if ( ! parser.isTTY ( ) )  {
-    printf ( "\nStarting QRender[%d] in deamon mode, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
+  if ( ! parser.isTTY ( ) )
     daemon ( 1, 1 );
-  }
-  else 
-    printf ( "\nStarting QRender[%d] in the foreground, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
 
   // At this point we start the server thread and listen to the set port.
   Render::Server server;
   server.setLogInfo ( parser.getLogLevel ( ), parser.getLogfileName ( ) );
+  logger.setLogInfo ( parser.getLogLevel ( ), parser.getLogfileName ( ) );
 
-  if ( ! server.listen ( QHostAddress::Any, parser.getServerPort ( ) ) )
-    printf ( "ERROR: Can not bind to port 5066\n%s\n", (const char *)server.errorString ( ).toAscii ( ) );
-  else
+  if ( ! server.listen ( QHostAddress::Any, parser.getServerPort ( ) ) )  {
+    // QRender is most likely alreadyt running in the background. So this is not an error per-se
+    // but rather an expected exception.
+    logger.log ( Render::Logger::logError, "ERROR: Can not bind to port 5066\n%s\n", (const char *)server.errorString ( ).toAscii ( ) );
+  }
+  else  {
+    if ( ! parser.isTTY ( ) )
+      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] in deamon mode, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
+    else
+      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] in the foreground, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
     return app.exec ( );
+  }
 
   return -1;
 }
