@@ -39,11 +39,15 @@ public:
 protected:
   CXmlSlideshow::img_struct *createStartEnd ( bool );
   void createBackground ( );
-  void createTransition ( CXmlSlideshow::img_struct *, CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
-  void createFromImage  ( CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
+  void createIITransition ( CXmlSlideshow::img_struct *, CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
+  void createVITransition ( CXmlSlideshow::vid_struct *, CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
+  void createIVTransition ( CXmlSlideshow::img_struct *, CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
+  void createVVTransition ( CXmlSlideshow::vid_struct *, CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
+  void createFromImage    ( CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
+  void createFromVid      ( CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
 
-  void displayProgress  ( float   );
-  QString getHashName   ( QString );
+  void displayProgress    ( float   );
+  QString getHashName     ( QString );
 
 private:
   Render        *m_pParent;
